@@ -42,7 +42,7 @@ fi
 
 
 # Message show on the release page
-ACTION_LINK_TEXT="GitHub Action build logs: https://github.com/ksnip/ksnip/actions"
+ACTION_LINK_TEXT="Build logs: https://github.com/ksnip/ksnip/actions"
 BUILD_TIME_TEXT="Build Time: $(date +"%a, %d %b %Y %T")"
 UPLOADTOOL_BODY="${ACTION_LINK_TEXT}\n${BUILD_TIME_TEXT}"
 echo "UPLOADTOOL_BODY=$UPLOADTOOL_BODY" >> $GITHUB_ENV
\ No newline at end of file
