@@ -19,7 +19,8 @@
 
 #include "ScriptUploader.h"
 
-ScriptUploader::ScriptUploader() : mConfig(KsnipConfigProvider::instance())
+ScriptUploader::ScriptUploader(const QSharedPointer<IConfig> &config) :
+	mConfig(config)
 {
 	connect(&mProcessHandler, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &ScriptUploader::scriptFinished);
 	connect(&mProcessHandler, &QProcess::errorOccurred, this, &ScriptUploader::errorOccurred);
@@ -110,7 +111,7 @@ UploadStatus ScriptUploader::mapErrorTypeToStatus(QProcess::ProcessError errorTy
 		case QProcess::Crashed:
 			return UploadStatus::Crashed;
 		case QProcess::Timedout:
-			return UploadStatus::Timedout;
+			return UploadStatus::TimedOut;
 		case QProcess::ReadError:
 			return UploadStatus::ReadError;
 		case QProcess::WriteError:
