@@ -19,10 +19,12 @@
 
 #include "StandAloneBootstrapper.h"
 
-StandAloneBootstrapper::StandAloneBootstrapper() :
-	mImageGrabber(nullptr),
+StandAloneBootstrapper::StandAloneBootstrapper(DependencyInjector *dependencyInjector) :
 	mCommandLine(nullptr),
-	mMainWindow(nullptr)
+	mMainWindow(nullptr),
+	mCommandLineCaptureHandler(nullptr),
+	mLogger(dependencyInjector->get<ILogger>()),
+	mDependencyInjector(dependencyInjector)
 {
 
 }
@@ -36,7 +38,6 @@ int StandAloneBootstrapper::start(const QApplication &app)
 {
 	app.setQuitOnLastWindowClosed(false);
 
-	createImageGrabber();
 	createCommandLineParser(app);
 
 	if (isVersionRequested()) {
@@ -51,7 +52,41 @@ int StandAloneBootstrapper::start(const QApplication &app)
 		return startKsnipAndEditImage(app);
 	}
 
-	return startKsnipAndTakeCapture(app);
+	if (isCommandLineCaptureRequested()) {
+		return takeCaptureAndProcess(app);
+	}
+
+	return takeCaptureAndStartKsnip(app);
+}
+
+int StandAloneBootstrapper::takeCaptureAndProcess(const QApplication &app)
+{
+	connect(mCommandLineCaptureHandler.data(), &ICommandLineCaptureHandler::finished, this, &StandAloneBootstrapper::close);
+	connect(mCommandLineCaptureHandler.data(), &ICommandLineCaptureHandler::canceled, this, &StandAloneBootstrapper::close);
+
+	CommandLineCaptureParameter parameter(getCaptureMode(), getDelay(), getCaptureCursor());
+	parameter.isWithSave = getIsSave();
+	parameter.isWithUpload = getIsUpload();
+	parameter.savePath = getSavePath();
+
+	mCommandLineCaptureHandler->captureAndProcessScreenshot(parameter);
+
+	return app.exec();
+}
+
+bool StandAloneBootstrapper::getIsUpload() const
+{
+	return mCommandLine->isUploadSet();
+}
+
+bool StandAloneBootstrapper::getIsSave() const
+{
+	return mCommandLine->isSaveSet();
+}
+
+bool StandAloneBootstrapper::isCommandLineCaptureRequested() const
+{
+	return getIsSave() || getIsUpload();
 }
 
 bool StandAloneBootstrapper::isEditRequested() const
@@ -64,25 +99,23 @@ bool StandAloneBootstrapper::isVersionRequested() const
 	return mCommandLine->isVersionSet();
 }
 
-bool StandAloneBootstrapper::isStartedWithoutArguments() const
+bool StandAloneBootstrapper::isStartedWithoutArguments()
 {
 	auto arguments = QCoreApplication::arguments();
 	return arguments.count() <= 1;
 }
 
-int StandAloneBootstrapper::startKsnipAndTakeCapture(const QApplication &app)
+int StandAloneBootstrapper::takeCaptureAndStartKsnip(const QApplication &app)
 {
-	auto captureMode = getCaptureMode();
-	auto runMode = getRunMode();
-	auto captureCursor = getCaptureCursor();
-	auto delay = getDelay();
+	loadTranslations(app);
 
-	if(runMode != RunMode::CLI) {
-		loadTranslations(app);
-	}
+	connect(mCommandLineCaptureHandler.data(), &ICommandLineCaptureHandler::finished, this, &StandAloneBootstrapper::openMainWindow);
+	connect(mCommandLineCaptureHandler.data(), &ICommandLineCaptureHandler::canceled, this, &StandAloneBootstrapper::close);
+
+	CommandLineCaptureParameter parameter(getCaptureMode(), getDelay(), getCaptureCursor());
+
+	mCommandLineCaptureHandler->captureAndProcessScreenshot(parameter);
 
-	createMainWindow(runMode);
-	mMainWindow->captureScreenshot(captureMode, captureCursor, delay);
 	return app.exec();
 }
 
@@ -104,16 +137,16 @@ int StandAloneBootstrapper::getDelay() const
 	return delay * 1000;
 }
 
-RunMode StandAloneBootstrapper::getRunMode() const
-{
-	return getSave() ? RunMode::CLI : RunMode::Edit;
-}
-
 bool StandAloneBootstrapper::getSave() const
 {
 	return mCommandLine->isSaveSet();
 }
 
+QString StandAloneBootstrapper::getSavePath() const
+{
+	return mCommandLine->saveToPath();
+}
+
 CaptureModes StandAloneBootstrapper::getCaptureMode() const
 {
 	if (mCommandLine->isCaptureModeSet()) {
@@ -126,7 +159,6 @@ CaptureModes StandAloneBootstrapper::getCaptureMode() const
 
 int StandAloneBootstrapper::startKsnipAndEditImage(const QApplication &app)
 {
-	loadTranslations(app);
 	auto pathToImage = getImagePath();
 	auto pixmap = getPixmapFromCorrectSource(pathToImage);
 
@@ -134,11 +166,11 @@ int StandAloneBootstrapper::startKsnipAndEditImage(const QApplication &app)
 		qWarning("Unable to open image file %s.", qPrintable(pathToImage));
 		return 1;
 	} else {
-		createMainWindow(RunMode::Edit);
+		loadTranslations(app);
 		if(PathHelper::isPipePath(pathToImage)) {
-			mMainWindow->processImage(CaptureDto(pixmap));
+			openMainWindow(CaptureDto(pixmap));
 		} else {
-			mMainWindow->processImage(CaptureFromFileDto(pixmap, pathToImage));
+			openMainWindow(CaptureFromFileDto(pixmap, pathToImage));
 		}
 		return app.exec();
 	}
@@ -150,7 +182,7 @@ QPixmap StandAloneBootstrapper::getPixmapFromCorrectSource(const QString &pathTo
 		qInfo("Reading image from stdin.");
 		return getPixmapFromStdin();
 	} else {
-		return QPixmap(pathToImage);
+		return { pathToImage };
 	}
 }
 
@@ -176,7 +208,7 @@ QString StandAloneBootstrapper::getImagePath() const
 int StandAloneBootstrapper::startKsnip(const QApplication &app)
 {
 	loadTranslations(app);
-	createMainWindow(RunMode::GUI);
+	createMainWindow();
 	return app.exec();
 }
 
@@ -188,24 +220,39 @@ int StandAloneBootstrapper::showVersion()
 	return 0;
 }
 
-void StandAloneBootstrapper::createMainWindow(RunMode mode)
+void StandAloneBootstrapper::createMainWindow()
 {
 	Q_ASSERT(mMainWindow == nullptr);
 
-	mMainWindow = new MainWindow(mImageGrabber, mode);
+	DependencyInjectorBootstrapper::BootstrapGui(mDependencyInjector);
+
+	mMainWindow = new MainWindow(mDependencyInjector);
 }
 
 void StandAloneBootstrapper::createCommandLineParser(const QApplication &app)
 {
-	mCommandLine = new KsnipCommandLine (app, mImageGrabber->supportedCaptureModes());
-}
+	Q_ASSERT(mCommandLine == nullptr);
+	Q_ASSERT(mCommandLineCaptureHandler == nullptr);
 
-void StandAloneBootstrapper::createImageGrabber()
-{
-	mImageGrabber = ImageGrabberFactory::createImageGrabber();
+	DependencyInjectorBootstrapper::BootstrapCommandLine(mDependencyInjector);
+
+	mCommandLineCaptureHandler = mDependencyInjector->get<ICommandLineCaptureHandler>();
+	mCommandLine = new CommandLine (app, mCommandLineCaptureHandler->supportedCaptureModes());
 }
 
 void StandAloneBootstrapper::loadTranslations(const QApplication &app)
 {
-	TranslationLoader::load(app);
+	auto translationLoader = mDependencyInjector->get<ITranslationLoader>();
+	translationLoader->load(app);
+}
+
+void StandAloneBootstrapper::openMainWindow(const CaptureDto &captureDto)
+{
+	createMainWindow();
+	mMainWindow->processCapture(captureDto);
+}
+
+void StandAloneBootstrapper::close()
+{
+	QCoreApplication::quit();
 }
