@@ -21,40 +21,44 @@
 #define KSNIP_PLATFORMCHECKER_H
 
 #include <QString>
-#include "QFile"
-#include "QTextStream"
-#include "QRegularExpression"
+#include <QRegularExpression>
+#include <QSharedPointer>
 
-#include "CommandRunner.h"
+#include "IPlatformChecker.h"
+#include "ICommandRunner.h"
 #include "src/common/enum/Platform.h"
 #include "src/common/enum/Environment.h"
 #include "src/common/enum/PackageManager.h"
 
-class PlatformChecker
+class PlatformChecker : public IPlatformChecker
 {
 public:
-    static PlatformChecker *instance();
+	explicit PlatformChecker(const QSharedPointer<ICommandRunner> &commandRunner);
+	~PlatformChecker() override = default;
 
-    bool isX11() const;
-    bool isWayland() const;
-    bool isKde() const;
-    bool isGnome() const;
-    bool isSnap() const;
-    int gnomeVersion() const;
+    bool isX11() override;
+    bool isWayland() override;
+    bool isKde() override;
+    bool isGnome() override;
+    bool isSnap() override;
+    int gnomeVersion() override;
 
 private:
+	QSharedPointer<ICommandRunner> mCommandRunner;
     Platform mPlatform;
     Environment mEnvironment;
     PackageManager mPackageManager;
     int mGnomeVersion;
+	bool mIsPlatformChecked;
+	bool mIsEnvironmentChecked;
+	bool mIsPacketManagerChecked;
+	bool mIsGnomeVersionChecked;
 
     void checkPlatform();
     void checkEnvironment();
-    void checkCheckPackageManager();
-    bool outputContainsValue(const QString& output, const QString& value) const;
+    void checkPackageManager();
+    static bool outputContainsValue(const QString& output, const QString& value);
     void checkVersion();
-
-    PlatformChecker();
 };
 
 #endif // KSNIP_PLATFORMCHECKER_H
