@@ -20,14 +20,20 @@
 
 #include "MainWindow.h"
 
-MainWindow::MainWindow(AbstractImageGrabber *imageGrabber, RunMode mode) :
+#include <QDebug>
+
+MainWindow::MainWindow(DependencyInjector *dependencyInjector) :
 	QMainWindow(),
+	mDependencyInjector(dependencyInjector),
+	mConfig(mDependencyInjector->get<IConfig>()),
+	mImageGrabber(mDependencyInjector->get<IImageGrabber>()),
+	mPluginManager(mDependencyInjector->get<IPluginManager>()),
+	mTrayIcon(new TrayIcon(mConfig, mDependencyInjector->get<IIconLoader>(), this)),
+	mNotificationService(NotificationServiceFactory::create(mTrayIcon, mDependencyInjector->get<IPlatformChecker>(), mConfig)),
 	mToolBar(nullptr),
-	mImageGrabber(imageGrabber),
-	mServiceLocator(new ServiceLocator),
-	mMode(mode),
 	mImageAnnotator(new KImageAnnotatorAdapter),
 	mSaveAsAction(new QAction(this)),
+	mSaveAllAction(new QAction(this)),
 	mUploadAction(new QAction(this)),
 	mCopyAsDataUriAction(new QAction(this)),
 	mPrintAction(new QAction(this)),
@@ -48,36 +54,31 @@ MainWindow::MainWindow(AbstractImageGrabber *imageGrabber, RunMode mode) :
 	mPinAction(new QAction(this)),
 	mRemoveImageAction(new QAction(this)),
 	mModifyCanvasAction(new QAction(this)),
+	mCloseWindowAction(new QAction(this)),
+	mOcrAction(new QAction(this)),
+	mCutAction(new QAction(this)),
 	mMainLayout(layout()),
-	mConfig(KsnipConfigProvider::instance()),
 	mActionsMenu(new ActionsMenu(mConfig)),
-	mRecentImagesMenu(new RecentImagesMenu(mServiceLocator->recentImageService(), this)),
-	mClipboard(mServiceLocator->clipboard()),
+	mRecentImagesMenu(new RecentImagesMenu(mDependencyInjector->get<IRecentImageService>(), this)),
+	mClipboard(mDependencyInjector->get<IClipboard>()),
 	mCapturePrinter(new CapturePrinter(this)),
-	mGlobalHotKeyHandler(new GlobalHotKeyHandler(mImageGrabber->supportedCaptureModes())),
-	mTrayIcon(new TrayIcon(this)),
+	mGlobalHotKeyHandler(new GlobalHotKeyHandler(mImageGrabber->supportedCaptureModes(), mDependencyInjector->get<IPlatformChecker>(), mConfig)),
 	mDragAndDropProcessor(new DragAndDropProcessor(this)),
-	mUploaderProvider(new UploaderProvider),
+	mUploadHandler(mDependencyInjector->get<IUploadHandler>()),
 	mSessionManagerRequestedQuit(false),
-	mCaptureHandler(CaptureHandlerFactory::create(mImageAnnotator, NotificationServiceFactory::create(mTrayIcon), mServiceLocator, this)),
-	mPinWindowHandler(new PinWindowHandler(this)),
-	mVisibilityHandler(WidgetVisibilityHandlerFactory::create(this)),
-	mFileDialog(FileDialogAdapterFactory::create()),
+	mResizeOnNormalize(false),
+	mCaptureHandler(CaptureHandlerFactory::create(mImageAnnotator, mNotificationService, mDependencyInjector, this)),
+	mPinWindowHandler(mDependencyInjector->get<IPinWindowHandler>()),
+	mVisibilityHandler(WidgetVisibilityHandlerFactory::create(this, mDependencyInjector->get<IPlatformChecker>())),
+	mFileDialogService(mDependencyInjector->get<IFileDialogService>()),
 	mWindowResizer(new WindowResizer(this, mConfig, this)),
-	mActionProcessor(new ActionProcessor)
+	mActionProcessor(new ActionProcessor),
+	mSavePathProvider(mDependencyInjector->get<ISavePathProvider>()),
+	mOcrWindowHandler(mDependencyInjector->get<IOcrWindowHandler>()),
+	mDelayHandler(mDependencyInjector->get<IDelayHandler>())
 {
-	// When we run in CLI only mode we don't need to setup gui, but only need
-	// to connect imagegrabber signals to mainwindow slots to handle the
-	// feedback.
-	if (mMode == RunMode::CLI) {
-		connect(mImageGrabber, &AbstractImageGrabber::finished, this, &MainWindow::processInstantCapture);
-		connect(mImageGrabber, &AbstractImageGrabber::canceled, this, &MainWindow::close);
-		return;
-	}
-
 	initGui();
 
-	setWindowIcon(IconLoader::load(QLatin1String("ksnip")));
 	setPosition();
 
 	auto coreApplication = dynamic_cast<QApplication *>(QCoreApplication::instance());
@@ -88,20 +89,20 @@ MainWindow::MainWindow(AbstractImageGrabber *imageGrabber, RunMode mode) :
 	connect(mDragAndDropProcessor, &DragAndDropProcessor::fileDropped, this, &MainWindow::loadImageFromFile);
 	connect(mDragAndDropProcessor, &DragAndDropProcessor::imageDropped, this, &MainWindow::loadImageFromPixmap);
 
-	connect(mConfig, &KsnipConfig::annotatorConfigChanged, this, &MainWindow::setupImageAnnotator);
+	connect(mConfig.data(), &IConfig::annotatorConfigChanged, this, &MainWindow::setupImageAnnotator);
 
-	connect(mImageGrabber, &AbstractImageGrabber::finished, this, &MainWindow::processCapture);
-	connect(mImageGrabber, &AbstractImageGrabber::canceled, this, &MainWindow::captureCanceled);
+	connect(mImageGrabber.data(), &IImageGrabber::finished, this, &MainWindow::processCapture);
+	connect(mImageGrabber.data(), &IImageGrabber::canceled, this, &MainWindow::captureCanceled);
+	connect(mImageGrabber.data(), &IImageGrabber::canceled, mActionProcessor, &ActionProcessor::captureCanceled);
 
 	connect(mGlobalHotKeyHandler, &GlobalHotKeyHandler::captureTriggered, this, &MainWindow::triggerCapture);
 	connect(mGlobalHotKeyHandler, &GlobalHotKeyHandler::actionTriggered, this, &MainWindow::actionTriggered);
 
-	connect(mUploaderProvider, &UploaderProvider::finished, this, &MainWindow::uploadFinished);
+	connect(mUploadHandler.data(), &IUploadHandler::finished, this, &MainWindow::uploadFinished);
 
 	connect(mRecentImagesMenu, &RecentImagesMenu::openRecentSelected, this, &MainWindow::loadImageFromFile);
 
 	connect(this, &MainWindow::imageLoaded, mActionProcessor, &ActionProcessor::captureFinished);
-	connect(mImageGrabber, &AbstractImageGrabber::canceled, mActionProcessor, &ActionProcessor::captureCanceled);
 	connect(mActionProcessor, &ActionProcessor::triggerCapture, this, &MainWindow::capture);
 	connect(mActionProcessor, &ActionProcessor::triggerPinImage, mPinAction, &QAction::trigger);
 	connect(mActionProcessor, &ActionProcessor::triggerUpload, mUploadAction, &QAction::trigger);
@@ -120,72 +121,43 @@ MainWindow::MainWindow(AbstractImageGrabber *imageGrabber, RunMode mode) :
 
 MainWindow::~MainWindow()
 {
-    delete mImageAnnotator;
-    delete mUploadAction;
-    delete mCopyAsDataUriAction;
-    delete mPrintAction;
-    delete mPrintPreviewAction;
-    delete mQuitAction;
-    delete mCopyPathAction;
-    delete mRenameAction;
-    delete mOpenDirectoryAction;
-    delete mToggleDocksAction;
-    delete mSettingsAction;
-    delete mAboutAction;
-    delete mOpenImageAction;
-    delete mScaleAction;
-    delete mRotateAction;
-    delete mAddWatermarkAction;
-    delete mSaveAsAction;
-    delete mModifyCanvasAction;
-    delete mCapturePrinter;
-    delete mTrayIcon;
-    delete mDragAndDropProcessor;
-    delete mUploaderProvider;
-    delete mCaptureHandler;
-    delete mVisibilityHandler;
-    delete mFileDialog;
-    delete mWindowResizer;
-    delete mActionProcessor;
-    delete mActionsMenu;
+	delete mImageAnnotator;
+	delete mCapturePrinter;
+	delete mDragAndDropProcessor;
+	delete mCaptureHandler;
+	delete mVisibilityHandler;
+	delete mWindowResizer;
+	delete mActionProcessor;
+	delete mActionsMenu;
 }
 
 void MainWindow::handleGuiStartup()
 {
-	if (mMode == RunMode::GUI) {
-		if (mConfig->captureOnStartup()) {
-			triggerCapture(mConfig->captureMode());
-		} else if (mTrayIcon->isVisible() && mConfig->startMinimizedToTray()) {
-			showHidden();
-		} else {
-			showEmpty();
-		}
+	if (mConfig->captureOnStartup()) {
+		triggerCapture(mConfig->captureMode());
+	} else if (mTrayIcon->isVisible() && mConfig->startMinimizedToTray()) {
+		showHidden();
+	} else {
+		showEmpty();
 	}
 }
 
 void MainWindow::setPosition()
 {
 	auto position = mConfig->windowPosition();
-	auto screenGeometry = QApplication::desktop()->screenGeometry();
-	if(!screenGeometry.contains(position)) {
-		auto screenCenter = screenGeometry.center();
+	auto desktopGeometry = QApplication::desktop()->geometry();
+
+	if(!desktopGeometry.contains(position)) {
+		auto screenCenter = desktopGeometry.center();
 		auto mainWindowSize = size();
 		position = QPoint(screenCenter.x() - mainWindowSize.width() / 2, screenCenter.y() - mainWindowSize.height() / 2);
 	}
 	move(position);
 }
 
-void MainWindow::processInstantCapture(const CaptureDto &capture)
-{
-	mCaptureHandler->load(capture);
-	mCaptureHandler->save();
-	mImageAnnotator->close();
-	close();
-}
-
 void MainWindow::captureScreenshot(CaptureModes captureMode, bool captureCursor, int delay)
 {
-    mImageGrabber->grabImage(captureMode, captureCursor, delay);
+	mImageGrabber->grabImage(captureMode, captureCursor, delay);
 }
 
 void MainWindow::quit()
@@ -203,7 +175,7 @@ void MainWindow::processCapture(const CaptureDto &capture)
 	if (!capture.isValid()) {
 		auto title = tr("Unable to show image");
 		auto message = tr("No image provided but one was expected.");
-		NotifyOperation operation(mTrayIcon, title, message, NotificationTypes::Critical);
+		NotifyOperation operation(title, message, NotificationTypes::Critical, mNotificationService, mConfig);
 		operation.execute();
 		showEmpty();
 		return;
@@ -281,10 +253,10 @@ void MainWindow::showDefault()
 
 QMenu* MainWindow::createPopupMenu()
 {
-    // Filtering out the option to hide main toolbar which should no be allowed.
-    auto filteredMenu = QMainWindow::createPopupMenu();
-    filteredMenu->removeAction(mToolBar->toggleViewAction());
-    return filteredMenu;
+	// Filtering out the option to hide main toolbar which should no be allowed.
+	auto filteredMenu = QMainWindow::createPopupMenu();
+	filteredMenu->removeAction(mToolBar->toggleViewAction());
+	return filteredMenu;
 }
 
 QSize MainWindow::sizeHint() const
@@ -319,7 +291,10 @@ void MainWindow::closeEvent(QCloseEvent* event)
 void MainWindow::changeEvent(QEvent *event)
 {
 	if (event->type() == QEvent::WindowStateChange) {
-		if(isMinimized() && mTrayIcon->isVisible() && mConfig->minimizeToTray()) {
+		if(mResizeOnNormalize && !isMaximized()) {
+			mResizeOnNormalize = false;
+			resizeToContent();
+		} else if(isMinimized() && mTrayIcon->isVisible() && mConfig->minimizeToTray()) {
 			event->ignore();
 			mVisibilityHandler->hide();
 		}
@@ -348,27 +323,30 @@ void MainWindow::updateApplicationTitle()
 
 void MainWindow::setEnablements(bool enabled)
 {
-    mPrintAction->setEnabled(enabled);
-    mPrintPreviewAction->setEnabled(enabled);
-    mUploadAction->setEnabled(enabled);
-    mCopyAsDataUriAction->setEnabled(enabled);
-    mScaleAction->setEnabled(enabled);
+	mPrintAction->setEnabled(enabled);
+	mPrintPreviewAction->setEnabled(enabled);
+	mUploadAction->setEnabled(enabled);
+	mCopyAsDataUriAction->setEnabled(enabled);
+	mScaleAction->setEnabled(enabled);
 	mRotateAction->setEnabled(enabled);
-    mAddWatermarkAction->setEnabled(enabled);
-    mToolBar->setCopyActionEnabled(enabled);
-    mToolBar->setCropEnabled(enabled);
-    mSaveAsAction->setEnabled(enabled);
-    mPinAction->setEnabled(enabled);
-    mPasteEmbeddedAction->setEnabled(mClipboard->isPixmap() && mImageAnnotator->isVisible());
-    mRenameAction->setEnabled(enabled);
-    mModifyCanvasAction->setEnabled(enabled);
-    mActionProcessor->setPostProcessingEnabled(enabled);
+	mAddWatermarkAction->setEnabled(enabled);
+	mToolBar->setCopyActionEnabled(enabled);
+	mToolBar->setCropEnabled(enabled);
+	mSaveAsAction->setEnabled(enabled);
+	mSaveAllAction->setEnabled(enabled);
+	mPinAction->setEnabled(enabled);
+	mPasteEmbeddedAction->setEnabled(mClipboard->isPixmap() && mImageAnnotator->isVisible());
+	mRenameAction->setEnabled(enabled);
+	mModifyCanvasAction->setEnabled(enabled);
+	mCutAction->setEnabled(enabled);
+	mActionProcessor->setPostProcessingEnabled(enabled);
+	mOcrAction->setEnabled(mPluginManager->isAvailable(PluginType::Ocr) && enabled);
 }
 
 void MainWindow::loadSettings()
 {
-    mToolBar->selectCaptureMode(mConfig->captureMode());
-    mToolBar->setCaptureDelay(mConfig->captureDelay() / 1000);
+	mToolBar->selectCaptureMode(mConfig->captureMode());
+	mToolBar->setCaptureDelay(mConfig->captureDelay() / 1000);
 
 	if(mConfig->autoHideDocks()) {
 		toggleDocks();
@@ -388,8 +366,12 @@ void MainWindow::triggerCapture(CaptureModes captureMode)
 
 void MainWindow::capture(CaptureModes captureMode, bool captureCursor, int delay)
 {
+	auto isMainWindowVisible = !isMinimized();
+	auto adjustedDelay = mDelayHandler->getDelay(delay, isMainWindowVisible);
+
 	hideMainWindowIfRequired();
-	captureScreenshot(captureMode, captureCursor, delay);
+
+	captureScreenshot(captureMode, captureCursor, adjustedDelay);
 }
 
 void MainWindow::hideMainWindowIfRequired()
@@ -414,43 +396,56 @@ void MainWindow::toggleDocks()
 
 void MainWindow::initGui()
 {
-    mToolBar = new MainToolBar(mImageGrabber->supportedCaptureModes(), mImageAnnotator->undoAction(), mImageAnnotator->redoAction());
+	auto iconLoader = mDependencyInjector->get<IIconLoader>();
 
-    connect(mToolBar, &MainToolBar::captureModeSelected, this, &MainWindow::triggerCapture);
-    connect(mToolBar, &MainToolBar::saveActionTriggered, this, &MainWindow::saveClicked);
-    connect(mToolBar, &MainToolBar::copyActionTriggered, this, &MainWindow::copyCaptureToClipboard);
-    connect(mToolBar, &MainToolBar::captureDelayChanged, this, &MainWindow::captureDelayChanged);
-    connect(mToolBar, &MainToolBar::cropActionTriggered, mImageAnnotator, &IImageAnnotator::showCropper);
+	setWindowIcon(iconLoader->load(QLatin1String("ksnip")));
+
+	mToolBar = new MainToolBar(
+			mImageGrabber->supportedCaptureModes(),
+			mImageAnnotator->undoAction(),
+			mImageAnnotator->redoAction(),
+			iconLoader,
+			mDependencyInjector->get<IScaledSizeProvider>());
+
+	connect(mToolBar, &MainToolBar::captureModeSelected, this, &MainWindow::triggerCapture);
+	connect(mToolBar, &MainToolBar::saveActionTriggered, this, &MainWindow::saveClicked);
+	connect(mToolBar, &MainToolBar::copyActionTriggered, this, &MainWindow::copyCaptureToClipboard);
+	connect(mToolBar, &MainToolBar::captureDelayChanged, this, &MainWindow::captureDelayChanged);
+	connect(mToolBar, &MainToolBar::cropActionTriggered, mImageAnnotator, &IImageAnnotator::showCropper);
 
 	mSaveAsAction->setText(tr("Save As..."));
 	mSaveAsAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_S);
-	mSaveAsAction->setIcon(IconLoader::loadForTheme(QLatin1String("saveAs")));
+	mSaveAsAction->setIcon(iconLoader->loadForTheme(QLatin1String("saveAs")));
 	connect(mSaveAsAction, &QAction::triggered, this, &MainWindow::saveAsClicked);
 
-    mUploadAction->setText(tr("Upload"));
-    mUploadAction->setToolTip(tr("Upload triggerCapture to external source"));
-    mUploadAction->setShortcut(Qt::SHIFT + Qt::Key_U);
-    connect(mUploadAction, &QAction::triggered, this, &MainWindow::upload);
+	mSaveAllAction->setText(tr("Save All"));
+	mSaveAllAction->setIcon(iconLoader->loadForTheme(QLatin1String("save")));
+	connect(mSaveAllAction, &QAction::triggered, this, &MainWindow::saveAllClicked);
 
-    mCopyAsDataUriAction->setText(tr("Copy as data URI"));
-    mCopyAsDataUriAction->setToolTip(tr("Copy triggerCapture to system clipboard"));
-    connect(mCopyAsDataUriAction, &QAction::triggered, this, &MainWindow::copyAsDataUri);
+	mUploadAction->setText(tr("Upload"));
+	mUploadAction->setToolTip(tr("Upload triggerCapture to external source"));
+	mUploadAction->setShortcut(Qt::SHIFT + Qt::Key_U);
+	connect(mUploadAction, &QAction::triggered, this, &MainWindow::upload);
 
-    mPrintAction->setText(tr("Print"));
-    mPrintAction->setToolTip(tr("Opens printer dialog and provide option to print image"));
-    mPrintAction->setShortcut(Qt::CTRL + Qt::Key_P);
-    mPrintAction->setIcon(QIcon::fromTheme(QLatin1String("document-print")));
-    connect(mPrintAction, &QAction::triggered, this, &MainWindow::printClicked);
+	mCopyAsDataUriAction->setText(tr("Copy as data URI"));
+	mCopyAsDataUriAction->setToolTip(tr("Copy triggerCapture to system clipboard"));
+	connect(mCopyAsDataUriAction, &QAction::triggered, this, &MainWindow::copyAsDataUri);
 
-    mPrintPreviewAction->setText(tr("Print Preview"));
-    mPrintPreviewAction->setToolTip(tr("Opens Print Preview dialog where the image "
-                                       "orientation can be changed"));
-    mPrintPreviewAction->setIcon(QIcon::fromTheme(QLatin1String("document-print-preview")));
-    connect(mPrintPreviewAction, &QAction::triggered, this, &MainWindow::printPreviewClicked);
+	mPrintAction->setText(tr("Print"));
+	mPrintAction->setToolTip(tr("Opens printer dialog and provide option to print image"));
+	mPrintAction->setShortcut(Qt::CTRL + Qt::Key_P);
+	mPrintAction->setIcon(QIcon::fromTheme(QLatin1String("document-print")));
+	connect(mPrintAction, &QAction::triggered, this, &MainWindow::printClicked);
 
-    mScaleAction->setText(tr("Scale"));
-    mScaleAction->setToolTip(tr("Scale Image"));
-    mScaleAction->setShortcut(Qt::SHIFT + Qt::Key_S);
+	mPrintPreviewAction->setText(tr("Print Preview"));
+	mPrintPreviewAction->setToolTip(tr("Opens Print Preview dialog where the image "
+									   "orientation can be changed"));
+	mPrintPreviewAction->setIcon(QIcon::fromTheme(QLatin1String("document-print-preview")));
+	connect(mPrintPreviewAction, &QAction::triggered, this, &MainWindow::printPreviewClicked);
+
+	mScaleAction->setText(tr("Scale"));
+	mScaleAction->setToolTip(tr("Scale Image"));
+	mScaleAction->setShortcut(Qt::SHIFT + Qt::Key_S);
 	connect(mScaleAction, &QAction::triggered, this, &MainWindow::showScaleDialog);
 
 	mRotateAction->setText(tr("Rotate"));
@@ -463,10 +458,15 @@ void MainWindow::initGui()
 	mAddWatermarkAction->setShortcut(Qt::SHIFT + Qt::Key_W);
 	connect(mAddWatermarkAction, &QAction::triggered, this, &MainWindow::addWatermark);
 
-    mQuitAction->setText(tr("Quit"));
-    mQuitAction->setShortcut(Qt::CTRL + Qt::Key_Q);
-    mQuitAction->setIcon(QIcon::fromTheme(QLatin1String("application-exit")));
-    connect(mQuitAction, &QAction::triggered, this, &MainWindow::quit);
+	mQuitAction->setText(tr("Quit"));
+	mQuitAction->setShortcut(Qt::CTRL + Qt::Key_Q);
+	mQuitAction->setIcon(QIcon::fromTheme(QLatin1String("application-exit")));
+	connect(mQuitAction, &QAction::triggered, this, &MainWindow::quit);
+
+	mCloseWindowAction->setText(tr("Close Window"));
+	mCloseWindowAction->setShortcut(Qt::SHIFT + Qt::Key_Escape);
+	mCloseWindowAction->setIcon(QIcon::fromTheme(QLatin1String("window-close")));
+	connect(mCloseWindowAction, &QAction::triggered, this, &MainWindow::close);
 
 	mCopyPathAction->setText(tr("Copy Path"));
 	connect(mCopyPathAction, &QAction::triggered, mCaptureHandler, &ICaptureHandler::copyPath);
@@ -482,143 +482,154 @@ void MainWindow::initGui()
 	mToggleDocksAction->setShortcut(Qt::Key_Tab);
 	connect(mToggleDocksAction, &QAction::triggered, this, &MainWindow::toggleDocks);
 
-    mSettingsAction->setText(tr("Settings"));
-    mSettingsAction->setIcon(QIcon::fromTheme(QLatin1String("emblem-system")));
+	mSettingsAction->setText(tr("Settings"));
+	mSettingsAction->setIcon(QIcon::fromTheme(QLatin1String("emblem-system")));
 	mSettingsAction->setShortcut(Qt::ALT + Qt::Key_F7);
 	connect(mSettingsAction, &QAction::triggered, this, &MainWindow::showSettingsDialog);
 
-    mAboutAction->setText(tr("&About"));
-	mAboutAction->setIcon(IconLoader::load(QLatin1String("ksnip")));
+	mAboutAction->setText(tr("&About"));
+	mAboutAction->setIcon(iconLoader->load(QLatin1String("ksnip")));
 	connect(mAboutAction, &QAction::triggered, this, &MainWindow::showAboutDialog);
 
-    mOpenImageAction->setText(tr("Open"));
-    mOpenImageAction->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
-    mOpenImageAction->setShortcut(Qt::CTRL + Qt::Key_O);
-    connect(mOpenImageAction, &QAction::triggered, this, &MainWindow::showOpenImageDialog);
+	mOpenImageAction->setText(tr("Open"));
+	mOpenImageAction->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
+	mOpenImageAction->setShortcut(Qt::CTRL + Qt::Key_O);
+	connect(mOpenImageAction, &QAction::triggered, this, &MainWindow::showOpenImageDialog);
 
 	mRecentImagesMenu->setTitle(tr("Open &Recent"));
 	mRecentImagesMenu->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
 
 	mPasteAction->setText(tr("Paste"));
-	mPasteAction->setIcon(IconLoader::loadForTheme(QLatin1String("paste")));
+	mPasteAction->setIcon(iconLoader->loadForTheme(QLatin1String("paste")));
 	mPasteAction->setShortcut(Qt::CTRL + Qt::Key_V);
 	mPasteAction->setEnabled(mClipboard->isPixmap());
 	connect(mPasteAction, &QAction::triggered, this, &MainWindow::pasteFromClipboard);
-	connect(mClipboard, &ClipboardAdapter::changed, mPasteAction, &QAction::setEnabled);
+	connect(mClipboard.data(), &IClipboard::changed, mPasteAction, &QAction::setEnabled);
 
 	mPasteEmbeddedAction->setText(tr("Paste Embedded"));
-	mPasteEmbeddedAction->setIcon(IconLoader::loadForTheme(QLatin1String("pasteEmbedded")));
+	mPasteEmbeddedAction->setIcon(iconLoader->loadForTheme(QLatin1String("pasteEmbedded")));
 	mPasteEmbeddedAction->setShortcut(Qt::CTRL + Qt::SHIFT + Qt::Key_V);
 	mPasteEmbeddedAction->setEnabled(mClipboard->isPixmap() && mImageAnnotator->isVisible());
 	connect(mPasteEmbeddedAction, &QAction::triggered, this, &MainWindow::pasteEmbeddedFromClipboard);
-	connect(mClipboard, &ClipboardAdapter::changed, [this] (bool isPixmap){ mPasteEmbeddedAction->setEnabled(isPixmap && mImageAnnotator->isVisible()); });
+	connect(mClipboard.data(), &IClipboard::changed, [this] (bool isPixmap){ mPasteEmbeddedAction->setEnabled(isPixmap && mImageAnnotator->isVisible()); });
 
 	mPinAction->setText(tr("Pin"));
 	mPinAction->setToolTip(tr("Pin screenshot to foreground in frameless window"));
 	mPinAction->setShortcut(Qt::SHIFT + Qt::Key_P);
-	mPinAction->setIcon(IconLoader::loadForTheme(QLatin1String("pin")));
+	mPinAction->setIcon(iconLoader->loadForTheme(QLatin1String("pin")));
 	connect(mPinAction, &QAction::triggered, this, &MainWindow::showPinWindow);
 
 	mRemoveImageAction->setText(tr("Delete"));
-	mRemoveImageAction->setIcon(IconLoader::loadForTheme(QLatin1String("delete")));
+	mRemoveImageAction->setIcon(iconLoader->loadForTheme(QLatin1String("delete")));
 	connect(mRemoveImageAction, &QAction::triggered, mCaptureHandler, &ICaptureHandler::removeImage);
 
 	mModifyCanvasAction->setText(tr("Modify Canvas"));
 	connect(mModifyCanvasAction, &QAction::triggered, mImageAnnotator, &IImageAnnotator::showCanvasModifier);
 
+	mCutAction->setText(tr("Cut"));
+	mCutAction->setShortcut(Qt::SHIFT + Qt::Key_T);
+	connect(mCutAction, &QAction::triggered, mImageAnnotator, &IImageAnnotator::showCutter);
+
 	mActionsMenu->setTitle(tr("Actions"));
-	mActionsMenu->setIcon(IconLoader::loadForTheme(QLatin1String("action")));
+	mActionsMenu->setIcon(iconLoader->loadForTheme(QLatin1String("action")));
 	connect(mActionsMenu, &ActionsMenu::triggered, this, &MainWindow::actionTriggered);
 
+	mOcrAction->setText(tr("OCR"));
+	connect(mOcrAction, &QAction::triggered, this, &MainWindow::showOcrWindow);
+
 	auto menu = menuBar()->addMenu(tr("&File"));
-    menu->addAction(mToolBar->newCaptureAction());
+	menu->addAction(mToolBar->newCaptureAction());
 	menu->addSeparator();
-    menu->addMenu(mActionsMenu);
-    menu->addSeparator();
-    menu->addAction(mOpenImageAction);
-    menu->addMenu(mRecentImagesMenu);
-    menu->addAction(mToolBar->saveAction());
-    menu->addAction(mSaveAsAction);
-    menu->addAction(mUploadAction);
-    menu->addSeparator();
-    menu->addAction(mPrintAction);
-    menu->addAction(mPrintPreviewAction);
-    menu->addSeparator();
-    menu->addAction(mQuitAction);
-    menu = menuBar()->addMenu(tr("&Edit"));
-    menu->addAction(mToolBar->undoAction());
-    menu->addAction(mToolBar->redoAction());
-    menu->addSeparator();
-    menu->addAction(mToolBar->copyToClipboardAction());
-    menu->addAction(mCopyAsDataUriAction);
-    menu->addAction(mCopyPathAction);
-    menu->addAction(mRenameAction);
-    menu->addAction(mPasteAction);
-    menu->addAction(mPasteEmbeddedAction);
+	menu->addMenu(mActionsMenu);
 	menu->addSeparator();
-    menu->addAction(mToolBar->cropAction());
-    menu->addAction(mScaleAction);
-    menu->addAction(mRotateAction);
-    menu->addAction(mAddWatermarkAction);
+	menu->addAction(mOpenImageAction);
+	menu->addMenu(mRecentImagesMenu);
+	menu->addAction(mToolBar->saveAction());
+	menu->addAction(mSaveAsAction);
+	menu->addAction(mSaveAllAction);
+	menu->addAction(mUploadAction);
+	menu->addSeparator();
+	menu->addAction(mPrintAction);
+	menu->addAction(mPrintPreviewAction);
+	menu->addSeparator();
+	menu->addAction(mCloseWindowAction);
+	menu->addAction(mQuitAction);
+	menu = menuBar()->addMenu(tr("&Edit"));
+	menu->addAction(mToolBar->undoAction());
+	menu->addAction(mToolBar->redoAction());
+	menu->addSeparator();
+	menu->addAction(mToolBar->copyToClipboardAction());
+	menu->addAction(mCopyAsDataUriAction);
+	menu->addAction(mCopyPathAction);
+	menu->addAction(mRenameAction);
+	menu->addAction(mPasteAction);
+	menu->addAction(mPasteEmbeddedAction);
+	menu->addSeparator();
+	menu->addAction(mToolBar->cropAction());
+	menu->addAction(mScaleAction);
+	menu->addAction(mRotateAction);
+	menu->addAction(mCutAction);
+	menu->addAction(mAddWatermarkAction);
 	menu->addSeparator();
 	menu->addAction(mRemoveImageAction);
 	menu = menuBar()->addMenu(tr("&View"));
 	menu->addAction(mOpenDirectoryAction);
 	menu->addAction(mToggleDocksAction);
 	menu->addAction(mModifyCanvasAction);
-    menu = menuBar()->addMenu(tr("&Options"));
-    menu->addAction(mPinAction);
-    menu->addAction(mSettingsAction);
-    menu = menuBar()->addMenu(tr("&Help"));
-    menu->addAction(mAboutAction);
+	menu = menuBar()->addMenu(tr("&Options"));
+	menu->addAction(mPinAction);
+	menu->addAction(mOcrAction);
+	menu->addAction(mSettingsAction);
+	menu = menuBar()->addMenu(tr("&Help"));
+	menu->addAction(mAboutAction);
 
-    addToolBar(mToolBar);
+	addToolBar(mToolBar);
 
-    if(mConfig->useTrayIcon()) {
-	    connect(mTrayIcon, &TrayIcon::showEditorTriggered, [this](){ mVisibilityHandler->enforceVisible(); });
-	    mTrayIcon->setCaptureActions(mToolBar->captureActions());
-	    mTrayIcon->setOpenAction(mOpenImageAction);
-	    mTrayIcon->setSaveAction(mToolBar->saveAction());
-	    mTrayIcon->setPasteAction(mPasteAction);
-	    mTrayIcon->setCopyAction(mToolBar->copyToClipboardAction());
-	    mTrayIcon->setUploadAction(mUploadAction);
-	    mTrayIcon->setQuitAction(mQuitAction);
-	    mTrayIcon->setActionsMenu(mActionsMenu);
-	    mTrayIcon->setEnabled(true);
-    }
+	if(mConfig->useTrayIcon()) {
+		connect(mTrayIcon, &TrayIcon::showEditorTriggered, [this](){ mVisibilityHandler->enforceVisible(); });
+		mTrayIcon->setCaptureActions(mToolBar->captureActions());
+		mTrayIcon->setOpenAction(mOpenImageAction);
+		mTrayIcon->setSaveAction(mToolBar->saveAction());
+		mTrayIcon->setPasteAction(mPasteAction);
+		mTrayIcon->setCopyAction(mToolBar->copyToClipboardAction());
+		mTrayIcon->setUploadAction(mUploadAction);
+		mTrayIcon->setQuitAction(mQuitAction);
+		mTrayIcon->setActionsMenu(mActionsMenu);
+		mTrayIcon->setEnabled(true);
+	}
 
 	setCentralWidget(mImageAnnotator->widget());
 }
 
 void MainWindow::copyCaptureToClipboard()
 {
-    mCaptureHandler->copy();
+	mCaptureHandler->copy();
 }
 
 void MainWindow::upload()
 {
 	auto image = mCaptureHandler->image();
-	UploadOperation operation(image, mUploaderProvider->get());
+	UploadOperation operation(image, mUploadHandler, mConfig, mDependencyInjector->get<IMessageBoxService>());
 	operation.execute();
 }
 
 void MainWindow::copyAsDataUri()
 {
 	auto image = mCaptureHandler->image();
-	CopyAsDataUriOperation operation(image, mClipboard, mTrayIcon);
+	CopyAsDataUriOperation operation(image, mClipboard, mNotificationService, mConfig);
 	operation.execute();
 }
 
 void MainWindow::printClicked()
 {
-	auto savePath = mSavePathProvider.savePathWithFormat(QLatin1String("pdf"));
+	auto savePath = mSavePathProvider->savePathWithFormat(QLatin1String("pdf"));
 	auto image = mCaptureHandler->image();
 	mCapturePrinter->print(image, savePath);
 }
 
 void MainWindow::printPreviewClicked()
 {
-	auto savePath = mSavePathProvider.savePathWithFormat(QLatin1String("pdf"));
+	auto savePath = mSavePathProvider->savePathWithFormat(QLatin1String("pdf"));
 	auto image = mCaptureHandler->image();
 	mCapturePrinter->printPreview(image, savePath);
 }
@@ -626,9 +637,9 @@ void MainWindow::printPreviewClicked()
 void MainWindow::showOpenImageDialog()
 {
 	auto title = tr("Open Images");
-	auto directory = mSavePathProvider.saveDirectory();
-	auto filter = tr("Image Files (*.png *.jpg *.bmp)");
-	auto pathList = mFileDialog->getOpenFileNames(this, title, directory, filter);
+	auto directory = mSavePathProvider->saveDirectory();
+	auto filter = tr("Image Files") + FileDialogFilters::ImageFiles;
+	auto pathList = mFileDialogService->getOpenFileNames(this, title, directory, filter);
 
 	for (const auto &path : pathList) {
 		loadImageFromFile(path);
@@ -645,16 +656,17 @@ void MainWindow::setupImageAnnotator()
 	mImageAnnotator->setNumberToolSeedChangeUpdatesAllItems(mConfig->numberToolSeedChangeUpdatesAllItems());
 	mImageAnnotator->setStickers(mConfig->stickerPaths(), mConfig->useDefaultSticker());
 	mImageAnnotator->setCanvasColor(mConfig->canvasColor());
+	mImageAnnotator->setControlsWidgetVisible(mConfig->isControlsWidgetVisible());
 }
 
 void MainWindow::captureDelayChanged(int delay)
 {
-    mConfig->setCaptureDelay(delay * 1000);
+	mConfig->setCaptureDelay(delay * 1000);
 }
 
 void MainWindow::addWatermark()
 {
-	AddWatermarkOperation operation(mImageAnnotator);
+	AddWatermarkOperation operation(mImageAnnotator, mConfig);
 	operation.execute();
 }
 
@@ -668,7 +680,15 @@ void MainWindow::showDialog(const std::function<void ()>& showDialogMethod)
 void MainWindow::showSettingsDialog()
 {
 	showDialog([&](){
-		SettingsDialog settingsDialog(this, mImageGrabber->supportedCaptureModes());
+		SettingsDialog settingsDialog(
+				mImageGrabber->supportedCaptureModes(),
+				mConfig,
+				mDependencyInjector->get<IScaledSizeProvider>(),
+				mDependencyInjector->get<IDirectoryPathProvider>(),
+				mDependencyInjector->get<IFileDialogService>(),
+				mDependencyInjector->get<IPlatformChecker>(),
+				mDependencyInjector->get<IPluginFinder>(),
+				this);
 		settingsDialog.exec();
 	});
 }
@@ -723,9 +743,20 @@ void MainWindow::saveAsClicked()
 	mCaptureHandler->saveAs();
 }
 
+void MainWindow::saveAllClicked()
+{
+	mCaptureHandler->saveAll();
+}
+
 void MainWindow::loadImageFromFile(const QString &path)
 {
-	LoadImageFromFileOperation operation(this, path, mTrayIcon, mServiceLocator);
+	LoadImageFromFileOperation operation(
+			path,
+			this,
+			mNotificationService,
+			mDependencyInjector->get<IRecentImageService>(),
+			mDependencyInjector->get<IFileService>(),
+			mConfig);
 	operation.execute();
 }
 
@@ -751,7 +782,7 @@ void MainWindow::captureCanceled()
 
 void MainWindow::uploadFinished(const UploadResult &result)
 {
-	HandleUploadResultOperation handleUploadResponseOperation(result, mTrayIcon);
+	HandleUploadResultOperation handleUploadResponseOperation(result, mNotificationService, mClipboard, mDependencyInjector->get<IDesktopService>(), mConfig);
 	handleUploadResponseOperation.execute();
 }
 
@@ -759,6 +790,10 @@ void MainWindow::captureEmpty()
 {
 	setEnablements(false);
 	mWindowResizer->resetAndResize();
+
+	if (isWindowMaximized()) {
+		mResizeOnNormalize = true;
+	}
 }
 
 void MainWindow::showPinWindow()
@@ -788,3 +823,8 @@ void MainWindow::showAfterAction(bool minimized)
 
 	mWindowResizer->resize();
 }
+
+void MainWindow::showOcrWindow()
+{
+	mOcrWindowHandler->add(QPixmap::fromImage(mCaptureHandler->image()));
+}
