@@ -42,29 +42,31 @@
 #include "src/gui/captureHandler/CaptureHandlerFactory.h"
 #include "src/gui/captureHandler/ICaptureChangeListener.h"
 #include "src/gui/widgetVisibilityHandler/WidgetVisibilityHandlerFactory.h"
-#include "src/gui/pinWindow/PinWindowHandler.h"
-#include "src/gui/serviceLocator/ServiceLocator.h"
+#include "src/gui/modelessWindows/pinWindow/IPinWindowHandler.h"
+#include "src/gui/modelessWindows/ocrWindow/IOcrWindowHandler.h"
 #include "src/gui/RecentImagesMenu.h"
 #include "src/gui/dragAndDrop/DragAndDropProcessor.h"
 #include "src/gui/dragAndDrop/IDragContentProvider.h"
 #include "src/gui/windowResizer/IResizableWindow.h"
 #include "src/gui/windowResizer/WindowResizer.h"
 #include "src/widgets/MainToolBar.h"
-#include "src/backend/imageGrabber/AbstractImageGrabber.h"
-#include "src/backend/config/KsnipConfigProvider.h"
-#include "src/backend/uploader/UploaderProvider.h"
+#include "src/backend/uploader/UploadHandler.h"
 #include "src/backend/CapturePrinter.h"
-#include "src/common/loader/IconLoader.h"
-#include "src/common/enum/RunMode.h"
+#include "src/backend/imageGrabber/IImageGrabber.h"
 #include "src/common/provider/ApplicationTitleProvider.h"
 #include "src/common/dtos/CaptureFromFileDto.h"
-#include "src/common/adapter/fileDialog/FileDialogAdapterFactory.h"
+#include "src/common/adapter/fileDialog/IFileDialogService.h"
+#include "src/common/constants/FileDialogFilters.h"
+#include "src/common/handler/IDelayHandler.h"
+#include "src/dependencyInjector/DependencyInjector.h"
+#include "src/plugins/IPluginManager.h"
+
 
 class MainWindow : public QMainWindow, public ICaptureChangeListener, public IImageProcessor, public IResizableWindow, public IDragContentProvider
 {
     Q_OBJECT
 public:
-    explicit MainWindow(AbstractImageGrabber *imageGrabber, RunMode mode = RunMode::GUI);
+    explicit MainWindow(DependencyInjector *dependencyInjector);
     ~MainWindow() override;
     void showEmpty();
 	void showHidden();
@@ -90,57 +92,64 @@ protected:
     QSize sizeHint() const override;
 
 private:
-    AbstractImageGrabber *mImageGrabber;
-	IServiceLocator *mServiceLocator;
-    RunMode mMode;
-    bool mSessionManagerRequestedQuit;
-    QAction *mSaveAsAction;
-    QAction *mUploadAction;
-    QAction *mCopyAsDataUriAction;
-    QAction *mPrintAction;
-    QAction *mPrintPreviewAction;
-    QAction *mQuitAction;
-    QAction *mCopyPathAction;
-    QAction *mRenameAction;
-    QAction *mOpenDirectoryAction;
-    QAction *mToggleDocksAction;
-    QAction *mSettingsAction;
-    QAction *mAboutAction;
-    QAction *mOpenImageAction;
-    QAction *mScaleAction;
-    QAction *mRotateAction;
+	DependencyInjector *mDependencyInjector;
+	QSharedPointer<IConfig> mConfig;
+	QSharedPointer<IImageGrabber> mImageGrabber;
+	QSharedPointer<IPluginManager> mPluginManager;
+	TrayIcon *mTrayIcon;
+	QSharedPointer<INotificationService> mNotificationService;
+	bool mSessionManagerRequestedQuit;
+	bool mResizeOnNormalize;
+	QAction *mSaveAsAction;
+	QAction *mSaveAllAction;
+	QAction *mUploadAction;
+	QAction *mCopyAsDataUriAction;
+	QAction *mPrintAction;
+	QAction *mPrintPreviewAction;
+	QAction *mQuitAction;
+	QAction *mCopyPathAction;
+	QAction *mRenameAction;
+	QAction *mOpenDirectoryAction;
+	QAction *mToggleDocksAction;
+	QAction *mSettingsAction;
+	QAction *mAboutAction;
+	QAction *mOpenImageAction;
+	QAction *mScaleAction;
+	QAction *mRotateAction;
 	QAction *mAddWatermarkAction;
 	QAction *mPasteAction;
 	QAction *mPasteEmbeddedAction;
 	QAction *mPinAction;
 	QAction *mRemoveImageAction;
 	QAction *mModifyCanvasAction;
+	QAction *mCloseWindowAction;
+	QAction *mOcrAction;
+	QAction *mCutAction;
 	MainToolBar *mToolBar;
 	QLayout *mMainLayout;
-	KsnipConfig *mConfig;
 	ActionsMenu *mActionsMenu;
 	RecentImagesMenu *mRecentImagesMenu;
-	IClipboard *mClipboard;
+	QSharedPointer<IClipboard> mClipboard;
 	CapturePrinter *mCapturePrinter;
-    IImageAnnotator *mImageAnnotator;
-    SavePathProvider mSavePathProvider;
-    GlobalHotKeyHandler *mGlobalHotKeyHandler;
-    TrayIcon *mTrayIcon;
+	IImageAnnotator *mImageAnnotator;
+	QSharedPointer<ISavePathProvider> mSavePathProvider;
+	GlobalHotKeyHandler *mGlobalHotKeyHandler;
 	DragAndDropProcessor *mDragAndDropProcessor;
-	UploaderProvider *mUploaderProvider;
+	QSharedPointer<IUploadHandler> mUploadHandler;
 	ICaptureHandler *mCaptureHandler;
-	PinWindowHandler *mPinWindowHandler;
+	QSharedPointer<IPinWindowHandler> mPinWindowHandler;
 	WidgetVisibilityHandler *mVisibilityHandler;
-	IFileDialogAdapter *mFileDialog;
+	QSharedPointer<IFileDialogService> mFileDialogService;
 	WindowResizer *mWindowResizer;
 	ActionProcessor *mActionProcessor;
+	QSharedPointer<IOcrWindowHandler> mOcrWindowHandler;
+	QSharedPointer<IDelayHandler> mDelayHandler;
 
     void setEnablements(bool enabled);
     void loadSettings();
     void triggerCapture(CaptureModes captureMode);
     void capture(CaptureModes captureMode, bool captureCursor, int delay);
     void initGui();
-	void processInstantCapture(const CaptureDto &capture);
 	void showDialog(const std::function<void ()>& showDialogMethod);
 
 private slots:
@@ -166,6 +175,7 @@ private slots:
 	void handleGuiStartup();
 	void saveClicked();
 	void saveAsClicked();
+	void saveAllClicked();
 	void updateApplicationTitle();
 	void capturePostProcessing();
 	void loadImageFromFile(const QString &path);
@@ -177,6 +187,7 @@ private slots:
 	void toggleDocks();
 	void actionTriggered(const Action &action);
 	void showAfterAction(bool minimized);
+	void showOcrWindow();
 };
 
 #endif // KSNIP_MAINWINDOW_H
