@@ -21,19 +21,41 @@
 
 #include <utility>
 
-SaveOperation::SaveOperation(QWidget *parent, QImage image, bool isInstantSave, IToastService *toastService, IRecentImageService *recentImageService) :
+SaveOperation::SaveOperation(
+		QImage image,
+		bool isInstantSave,
+		const QSharedPointer<INotificationService> &notificationService,
+		const QSharedPointer<IRecentImageService> &recentImageService,
+		const QSharedPointer<IImageSaver> &imageSaver,
+		const QSharedPointer<ISavePathProvider> &savePathProvider,
+		const QSharedPointer<IFileDialogService> &fileDialogService,
+		const QSharedPointer<IConfig> &config,
+		QWidget *parent) :
 	mParent(parent),
 	mImage(std::move(image)),
 	mIsInstantSave(isInstantSave),
-	mToastService(toastService),
+	mNotificationService(notificationService),
 	mRecentImageService(recentImageService),
-	mConfig(KsnipConfigProvider::instance())
+	mImageSaver(imageSaver),
+	mSavePathProvider(savePathProvider),
+	mFileDialogService(fileDialogService),
+	mConfig(config)
 {
     Q_ASSERT(mParent != nullptr);
 }
 
-SaveOperation::SaveOperation(QWidget *parent, const QImage &image, bool isInstantSave, const QString &pathToImageSource, IToastService *toastService, IRecentImageService *recentImageService) :
-	SaveOperation(parent, image, isInstantSave, toastService, recentImageService)
+SaveOperation::SaveOperation(
+		const QImage &image,
+		bool isInstantSave,
+		const QString &pathToImageSource,
+		const QSharedPointer<INotificationService> &notificationService,
+		const QSharedPointer<IRecentImageService> &recentImageService,
+		const QSharedPointer<IImageSaver> &imageSaver,
+		const QSharedPointer<ISavePathProvider> &savePathProvider,
+		const QSharedPointer<IFileDialogService> &fileDialogService,
+		const QSharedPointer<IConfig> &config,
+		QWidget *parent) :
+	SaveOperation(image, isInstantSave, notificationService, recentImageService, imageSaver, savePathProvider, fileDialogService, config, parent)
 {
 	mPathToImageSource = pathToImageSource;
 }
@@ -44,9 +66,8 @@ SaveResultDto SaveOperation::execute()
 
 	if(!mIsInstantSave){
 		auto title = tr("Save As");
-		auto filter = tr("Images") + QLatin1String(" (*.png *.gif *.jpg);;") + tr("All Files") + QLatin1String("(*)");
-		auto fileDialogAdapter = FileDialogAdapterFactory::create();
-		auto selectedSavePath = fileDialogAdapter->getSavePath(mParent, title, path, filter);
+		auto filter = tr("Image Files") + FileDialogFilters::ImageFiles + tr("All Files") + FileDialogFilters::AllFiles;
+		auto selectedSavePath = mFileDialogService->getSavePath(mParent, title, path, filter);
 
 		if (selectedSavePath.isNull()) {
 			return SaveResultDto(false, path);
@@ -75,22 +96,22 @@ void SaveOperation::updateSaveDirectoryIfRequired(const QString &path, const Sav
 
 QString SaveOperation::getSavePath() const
 {
-	return PathHelper::isPathValid(mPathToImageSource) ? mPathToImageSource : mSavePathProvider.savePath();
+	return PathHelper::isPathValid(mPathToImageSource) ? mPathToImageSource : mSavePathProvider->savePath();
 }
 
 SaveResultDto SaveOperation::save(const QString &path)
 {
-	auto successful = mImageSaver.save(mImage, path);
+	auto successful = mImageSaver->save(mImage, path);
 	if(successful) {
-		notify(tr("Image Saved"), tr("Saved to"), path, NotificationTypes::Information);
+		notify(tr("Image Saved"), tr("Saved to %1").arg(path), path, NotificationTypes::Information);
 	} else {
-		notify(tr("Saving Image Failed"), tr("Failed to save image to"), path, NotificationTypes::Critical);
+		notify(tr("Saving Image Failed"), tr("Failed to save image to %1").arg(path), path, NotificationTypes::Critical);
 	}
 	return SaveResultDto(successful, path);
 }
 
 void SaveOperation::notify(const QString &title, const QString &message, const QString &path, NotificationTypes notificationType) const
 {
-	NotifyOperation operation(mToastService, title, message + QLatin1String(" ") + path, path, notificationType);
+	NotifyOperation operation(title, message, path, notificationType, mNotificationService, mConfig);
 	operation.execute();
 }
