@@ -19,8 +19,8 @@
 
 #include "ApplicationSettings.h"
 
-ApplicationSettings::ApplicationSettings(KsnipConfig *ksnipConfig) :
-	mConfig(ksnipConfig),
+ApplicationSettings::ApplicationSettings(const QSharedPointer<IConfig> &config) :
+	mConfig(config),
 	mAutoCopyToClipboardNewCapturesCheckbox(new QCheckBox(this)),
 	mRememberPositionCheckbox(new QCheckBox(this)),
 	mCaptureOnStartupCheckbox(new QCheckBox(this)),
@@ -29,6 +29,7 @@ ApplicationSettings::ApplicationSettings(KsnipConfig *ksnipConfig) :
 	mUseSingleInstanceCheckBox(new QCheckBox(this)),
 	mAutoHideDocksCheckBox(new QCheckBox(this)),
 	mAutoResizeToContentCheckBox(new QCheckBox(this)),
+	mEnableDebugging(new QCheckBox(this)),
 	mApplicationStyleLabel(new QLabel(this)),
 	mResizeToContentDelayLabel(new QLabel(this)),
 	mApplicationStyleCombobox(new QComboBox(this)),
@@ -67,6 +68,10 @@ void ApplicationSettings::initGui()
 	mAutoResizeToContentCheckBox->setText(tr("Auto resize to content"));
 	mAutoResizeToContentCheckBox->setToolTip(tr("Automatically resize Main Window to fit content image."));
 
+	mEnableDebugging->setText(tr("Enable Debugging"));
+	mEnableDebugging->setToolTip(tr("Enables debug output written to the console.\n"
+									   "Change requires ksnip restart to take effect."));
+
 	mResizeToContentDelayLabel->setText(tr("Resize to content delay") + QLatin1String(":"));
 	mResizeToContentDelayLabel->setToolTip(tr("Resizing to content is delay to allow the Window Manager to receive\n"
 										   		 "the new content. In case that the Main Windows is not adjusted correctly\n"
@@ -74,6 +79,7 @@ void ApplicationSettings::initGui()
 
 	mResizeToContentDelaySpinBox->setSuffix(QLatin1String("ms"));
 	mResizeToContentDelaySpinBox->setToolTip(mResizeToContentDelayLabel->toolTip());
+	mResizeToContentDelaySpinBox->setSingleStep(10);
 
 	connect(mUseTabsCheckbox, &QCheckBox::stateChanged, this, &ApplicationSettings::useTabsChanged);
 
@@ -95,11 +101,13 @@ void ApplicationSettings::initGui()
 	mLayout->addWidget(mUseSingleInstanceCheckBox, 5, 0, 1, 4);
 	mLayout->addWidget(mAutoHideDocksCheckBox, 6, 0, 1, 4);
 	mLayout->addWidget(mAutoResizeToContentCheckBox, 7, 0, 1, 4);
-	mLayout->addWidget(mResizeToContentDelayLabel, 8, 0, 1, 2);
-	mLayout->addWidget(mResizeToContentDelaySpinBox, 8, 2, Qt::AlignLeft);
+	mLayout->addWidget(mEnableDebugging, 8, 0, 1, 4);
 	mLayout->setRowMinimumHeight(9, 15);
-	mLayout->addWidget(mApplicationStyleLabel, 10, 0, 1, 2);
-	mLayout->addWidget(mApplicationStyleCombobox, 10, 2, Qt::AlignLeft);
+	mLayout->addWidget(mResizeToContentDelayLabel, 10, 0, 1, 2);
+	mLayout->addWidget(mResizeToContentDelaySpinBox, 10, 2, Qt::AlignLeft);
+	mLayout->setRowMinimumHeight(11, 15);
+	mLayout->addWidget(mApplicationStyleLabel, 12, 0, 1, 2);
+	mLayout->addWidget(mApplicationStyleCombobox, 12, 2, Qt::AlignLeft);
 
 	setTitle(tr("Application Settings"));
 	setLayout(mLayout);
@@ -115,6 +123,7 @@ void ApplicationSettings::loadConfig()
 	mUseSingleInstanceCheckBox->setChecked(mConfig->useSingleInstance());
 	mAutoHideDocksCheckBox->setChecked(mConfig->autoHideDocks());
 	mAutoResizeToContentCheckBox->setChecked(mConfig->autoResizeToContent());
+	mEnableDebugging->setChecked(mConfig->isDebugEnabled());
 	mResizeToContentDelaySpinBox->setValue(mConfig->resizeToContentDelay());
 	mApplicationStyleCombobox->setCurrentText(mConfig->applicationStyle());
 
@@ -131,6 +140,7 @@ void ApplicationSettings::saveSettings()
 	mConfig->setAutoHideTabs(mAutoHideTabsCheckbox->isChecked());
 	mConfig->setAutoHideDocks(mAutoHideDocksCheckBox->isChecked());
 	mConfig->setAutoResizeToContent(mAutoResizeToContentCheckBox->isChecked());
+	mConfig->setIsDebugEnabled(mEnableDebugging->isChecked());
 	mConfig->setResizeToContentDelay(mResizeToContentDelaySpinBox->value());
 	mConfig->setApplicationStyle(mApplicationStyleCombobox->currentText());
 }
