@@ -29,7 +29,7 @@
     </message>
     <message>
         <source>Contact</source>
-        <translation type="unfinished"></translation>
+        <translation>Kontakt</translation>
     </message>
 </context>
 <context>
@@ -40,7 +40,7 @@
     </message>
     <message>
         <source>Screenshot and Annotation Tool</source>
-        <translation type="unfinished"></translation>
+        <translation>Aplikace pro zachycení snímku obrazovky a tvorbu popisků</translation>
     </message>
 </context>
 <context>
@@ -71,7 +71,8 @@
     </message>
     <message>
         <source>s</source>
-        <translation type="unfinished">s</translation>
+        <extracomment>The small letter s stands for seconds.</extracomment>
+        <translation>s</translation>
     </message>
     <message>
         <source>Capture Mode</source>
@@ -79,7 +80,7 @@
     </message>
     <message>
         <source>Show image in Pin Window</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobraz obrázek v samostatném okně</translation>
     </message>
     <message>
         <source>Copy image to Clipboard</source>
@@ -99,7 +100,7 @@
     </message>
     <message>
         <source>Hide Main Window</source>
-        <translation type="unfinished"></translation>
+        <translation>Skryj hlavní okno</translation>
     </message>
 </context>
 <context>
@@ -188,12 +189,13 @@ Změna barvy ovlivní pouze nové oblasti anotací.</translation>
     </message>
     <message>
         <source>Select Item after drawing</source>
-        <translation type="unfinished"></translation>
+        <translation>Po kreslení vyber prvek</translation>
     </message>
     <message>
         <source>With this option enabled the item gets selected after
 being created, allowing changing settings.</source>
-        <translation type="unfinished"></translation>
+        <translation>S výběrem této volby získá prvek okamžité vybrání poté,
+co je vytvořen. A zpřístupní možnost editace prvku.</translation>
     </message>
 </context>
 <context>
@@ -272,6 +274,26 @@ Viditelnost doků lze přepínat pomocí klávesy Tabulátor.</translation>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Automaticky změnit velikost hlavního okna podle velikosti obrázku.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Povolit ladění aplikace</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Povolit režim ladění do okna konzole.
+Pro změnu je nutné restartovat ksnip.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -321,7 +343,7 @@ Viditelnost doků lze přepínat pomocí klávesy Tabulátor.</translation>
     <message>
         <source>The capture %1%2%3 has been modified.
 Do you want to save it?</source>
-        <translation>Zachycen í% 1% 2% 3 bylo upraveno.
+        <translation>Zachycení %1 %2 %3 bylo upraveno.
 Chcete změny uložit?</translation>
     </message>
 </context>
@@ -364,31 +386,19 @@ Chcete změny uložit?</translation>
     <name>ContactTab</name>
     <message>
         <source>Community</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation type="unfinished"></translation>
+        <translation>Komunita</translation>
     </message>
     <message>
         <source>Bug Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>Nahlášení chyb</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation type="unfinished">Použijte prosím </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Pokud máte obecné otázky, nápady nebo si jen chcete povídat o ksnip,&lt;br/&gt;prosím, připojte se na náš %1 nebo náš %2 server.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation type="unfinished"> pro hlášení chyb.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Prosím použijte %1 pro nahlašování chyb.</translation>
     </message>
 </context>
 <context>
@@ -425,14 +435,6 @@ Chcete pokračovat?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>tady</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Je také možné, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Dary jsou vždy vítány</translation>
@@ -442,16 +444,20 @@ Chcete pokračovat?</translation>
         <translation>Sponzorský dar</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Staňte se sponzorem GitHub</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip je neziskový copyleft volný softwarový projekt a &lt;br/&gt; stále má nějaké výdaje, které je třeba pokrýt,&lt;br/&gt;jako domény nebo hardware pro podporu více platforem.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip je neziskový softwarový projekt copylefted libre a &lt;br/&gt; má však stále určité náklady, které je třeba pokrýt, &lt;br/&gt; jedná se o náklady na doménu nebo náklady na hardware pro podporu mezi platformami.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Pokud chcete pomoct nebo jen chcete ocenit práci, kterou děláme,&lt;br/&gt;tím, že zaplatíte vývojářům pivo nebo kávu, můžete tak učinit %1zde%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Pokud chcete pomoci nebo jen &lt;br/&gt; ocenit práci &lt;br/&gt; vývojářů kávou či pivem, můžete to udělat</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Stát se GitHub sponzorem?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Také možnost, %1zde%2.</translation>
     </message>
 </context>
 <context>
@@ -492,24 +498,35 @@ Chcete pokračovat?</translation>
         <translation>Portál snímků obrazovky</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Vynutit anonymní nahrání.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Url</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished">Uživatelské jméno</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Heslo</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Nahrání na FTP</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Odeslání proběhlo úspěšně</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Nahrávací skript </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> úspěšně dokončen.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Odesláno do</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Nelze uložit dočasný obrázek pro nahrání.</translation>
@@ -538,10 +555,6 @@ Chcete pokračovat?</translation>
         <source>Web error, check console output.</source>
         <translation>Chyba webu, zkontrolujte výstup konzoly.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Neznámá chyba procesu.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Nahrání se nezdařilo</translation>
@@ -550,6 +563,30 @@ Chcete pokračovat?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>Skript zapisoval do StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>Byl úspěšně dokončen FTP přenos.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Neznámá chyba.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Chyba připojení.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Chyba v přístupových oprávnění.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -615,14 +652,6 @@ na snímku obrazovky.</translation>
         <source>Image Grabber</source>
         <translation>Snímkování</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Vynutit obecný snímek obrazovky Wayland</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Škálování obecných snímků obrazovky Wayland</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -664,6 +693,14 @@ Změna tohoto nastavení se projeví po restartu ksnip.</translation>
 when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Vynutit snímek přes Wayland Generic (xdg-desktop-portal)</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -809,6 +846,7 @@ a zachycením obrazovky.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -922,10 +960,6 @@ a zachycením obrazovky.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Pomoc</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Soubory obrázků (*. png *. jpg *. bmp)</translation>
-    </message>
     <message>
         <source>Save As...</source>
         <translation>Uložit jako...</translation>
@@ -1014,6 +1048,14 @@ a zachycením obrazovky.</translation>
         <source>Rotate Image</source>
         <translation>Otočit Obrázek</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished">Akce</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1081,18 +1123,10 @@ a zachycením obrazovky.</translation>
         <source>Image Renamed</source>
         <translation>Obrázek byl přejmenován</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Obrázek byl úspěšně přejmenován na </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Přejmenování obrázku se nezdařilo</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Nepodařilo se přejmenovat obrázek na </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Přejmenovat obrázek</translation>
@@ -1101,6 +1135,14 @@ a zachycením obrazovky.</translation>
         <source>New filename:</source>
         <translation>Nový název souboru:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1108,10 +1150,6 @@ a zachycením obrazovky.</translation>
         <source>Save As</source>
         <translation>Uložit jako</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Obrázky</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Všechny soubory</translation>
@@ -1120,17 +1158,21 @@ a zachycením obrazovky.</translation>
         <source>Image Saved</source>
         <translation>Obrázek uložen</translation>
     </message>
-    <message>
-        <source>Saved to</source>
-        <translation>Uložen do</translation>
-    </message>
     <message>
         <source>Saving Image Failed</source>
         <translation>Ukládání obrázku selhalo</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Nepodařilo se uložit obrázek do</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1283,7 +1325,7 @@ Když je vynechán, zkopíruje se vše.</translation>
     </message>
     <message>
         <source>Uploader</source>
-        <translation>Uploader</translation>
+        <translation>Nahrání</translation>
     </message>
     <message>
         <source>Script Uploader</source>
@@ -1313,6 +1355,10 @@ Když je vynechán, zkopíruje se vše.</translation>
         <source>Actions</source>
         <translation>Akce</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished">Nahrání na FTP</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1569,10 +1615,6 @@ pokud ji správce oken sytému podporuje. Změna vyžaduje restart.</translation
         <source>Tray Icon Settings</source>
         <translation>Nastavení ikony v oznamovací oblasti</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Zobrazit oznámení ikony v oznamovací oblasti</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Používat službu oznámení dané platformy</translation>
@@ -1583,6 +1625,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Pokud je možnost povolená, ksnip se pokusí používat službu oznámení dané platformy, pokud existuje.
 Změna vyžaduje restart pro projevení.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1591,12 +1637,8 @@ Změna vyžaduje restart pro projevení.</translation>
         <translation>Vybrat obrázek</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Obrázky</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Všechny soubory</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1638,7 +1680,11 @@ Změna vyžaduje restart pro projevení.</translation>
     </message>
     <message>
         <source>Uploader</source>
-        <translation>Uploader</translation>
+        <translation>Nahrání</translation>
+    </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
