@@ -71,7 +71,8 @@
     </message>
     <message>
         <source>s</source>
-        <translation type="unfinished">δ</translation>
+        <extracomment>The small letter s stands for seconds.</extracomment>
+        <translation>δ</translation>
     </message>
     <message>
         <source>Capture Mode</source>
@@ -79,7 +80,7 @@
     </message>
     <message>
         <source>Show image in Pin Window</source>
-        <translation type="unfinished"></translation>
+        <translation>Προβολή της εικόνας σε καρφιτσωμένο παράθυρο</translation>
     </message>
     <message>
         <source>Copy image to Clipboard</source>
@@ -91,7 +92,7 @@
     </message>
     <message>
         <source>Open image parent directory</source>
-        <translation type="unfinished"></translation>
+        <translation>Άνοιγμα του γονικού καταλόγου της εικόνας</translation>
     </message>
     <message>
         <source>Save image</source>
@@ -166,31 +167,35 @@ make them more smooth.</source>
     </message>
     <message>
         <source>Number Tool Seed change updates all Number Items</source>
-        <translation type="unfinished"></translation>
+        <translation>Μια αλλαγή στον αρχικό αριθμό αλλάζει όλα τα αριθμημένα αντικείμενα</translation>
     </message>
     <message>
         <source>Disabling this option causes changes of the number tool
 seed to affect only new items but not existing items.
 Disabling this option allows having duplicate numbers.</source>
-        <translation type="unfinished"></translation>
+        <translation>Απενεργοποιώντας αυτήν την επιλογή, οι αλλαγές στον αρχικό αριθμό
+επηρεάζουν μόνον τα νέα αντικείμενα και όχι τα υπάρχοντα.
+Η απενεργοποίηση της επιλογής επιτρέπει διπλότυπους αριθμούς.</translation>
     </message>
     <message>
         <source>Canvas Color</source>
-        <translation type="unfinished"></translation>
+        <translation>Χρώμα του καμβά</translation>
     </message>
     <message>
         <source>Default Canvas background color for annotation area.
 Changing color affects only new annotation areas.</source>
-        <translation type="unfinished"></translation>
+        <translation>Το προκαθορισμένο χρώμα παρασκηνίου του καμβά για την περιοχή σχολιασμού.
+Η αλλαγή του χρώματος επηρεάζει μόνον τις νέες περιοχές σχολιασμού.</translation>
     </message>
     <message>
         <source>Select Item after drawing</source>
-        <translation type="unfinished"></translation>
+        <translation>Επιλογή του αντικειμένου μετά τον σχεδιασμό</translation>
     </message>
     <message>
         <source>With this option enabled the item gets selected after
 being created, allowing changing settings.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αν αυτή η επιλογή είναι ενεργοποιημένη, το αντικείμενο επιλέγεται αμέσως
+μετά την δημιουργία του και επιτρέπει την επεξεργασία των παραμέτρων.</translation>
     </message>
 </context>
 <context>
@@ -253,19 +258,39 @@ a new start of all instances.</source>
     </message>
     <message>
         <source>Auto hide Docks</source>
-        <translation type="unfinished"></translation>
+        <translation>Αυτόματη απόκρυψη αποβάθρων</translation>
     </message>
     <message>
         <source>On startup hide Toolbar and Annotation Settings.
 Docks visibility can be toggled with the Tab Key.</source>
-        <translation type="unfinished"></translation>
+        <translation>Απόκρυψη της εργαλειοθήκης και των ρυθμίσεων σχολιασμού κατά την εκκίνηση.
+Χρησιμοποιήστε το πλήκτρο Tab για εναλλαγή της ορατότητας των αποβάθρων.</translation>
     </message>
     <message>
         <source>Auto resize to content</source>
-        <translation type="unfinished"></translation>
+        <translation>Αυτόματη κλιμάκωση βάσει του περιεχομένου</translation>
     </message>
     <message>
         <source>Automatically resize Main Window to fit content image.</source>
+        <translation>Αυτόματη αλλαγή μεγέθους του κυρίως παραθύρου για προσαρμογή στο περιεχόμενο της εικόνας.</translation>
+    </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -305,7 +330,7 @@ Docks visibility can be toggled with the Tab Key.</source>
     </message>
     <message>
         <source>The Authors:</source>
-        <translation type="unfinished"></translation>
+        <translation>Οι δημιουργοί:</translation>
     </message>
 </context>
 <context>
@@ -362,40 +387,28 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation>Κοινότητα</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> εξυπηρετητή.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Αναφορές σφαλμάτων</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Παρακαλώ χρησιμοποιήστε το </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> για αναφορά σφαλμάτων.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>CopyAsDataUriOperation</name>
     <message>
         <source>Failed to copy to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Αποτυχία αντιγραφής στο πρόχειρο</translation>
     </message>
     <message>
         <source>Failed to copy to clipboard as base64 encoded image.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αποτυχία αντιγραφής στο πρόχειρο ως εικόνα κωδικοποιημένη σε base64.</translation>
     </message>
     <message>
         <source>Copied to clipboard</source>
@@ -403,7 +416,7 @@ Do you want to save it?</source>
     </message>
     <message>
         <source>Copied to clipboard as base64 encoded image.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αντιγραφή στο πρόχειρο ως εικόνα κωδικοποιημένη σε base64.</translation>
     </message>
 </context>
 <context>
@@ -421,14 +434,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>εδώ</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Και αυτό γίνεται, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Οι δωρεές είναι ευπρόσδεκτες</translation>
@@ -438,23 +443,27 @@ Do you want to continue?</source>
         <translation>Δωρεά</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Γίνετε χορηγός στο GitHub</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>Το ksnip είναι ένα μη κερδοσκοπικό λογισμικό ελευθέρων πνευματικών δικαιωμάτων, και&lt;br/&gt;εντούτοις έχει κάποια έξοδα που πρέπει να καλυφθούν,&lt;br/&gt;όπως τα έξοδα τομέα ή τα έξοδα για την υποστήριξη σε ανεξαρτήτως πλατύβαθρου υλικό.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Αν θέλετε να βοηθήσετε ή απλώς &lt;br/&gt;να εκτιμήσετε την εργασία&lt;br/&gt; προσφέροντας στους δημιουργούς έναν ζύθο ή καφέ, μπορείτε να το κάνετε έστω κι&apos; έτσι</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>EmptyActionSettingTab</name>
     <message>
         <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
-        <translation type="unfinished"></translation>
+        <translation>Προσθήκη νέων ενεργειών με το πλήκτρο &quot;Προσθήκη&quot; της καρτέλας.</translation>
     </message>
 </context>
 <context>
@@ -488,24 +497,35 @@ Do you want to continue?</source>
         <translation>Πύλη στιγμιότυπου</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished">Όνομα χρήστη</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Επιτυχής αποστολή</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Μακροεντολή αποστολής </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> ολοκληρώθηκε με επιτυχία.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Αποστολή σε</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Αδύνατη η προσωρινή αποθήκευση της εικόνας για αποστολή.</translation>
@@ -534,10 +554,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation>Σφάλμα ιστού, ελέγξτε την έξοδο του τερματικού.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Άγνωστο σφάλμα της διεργασίας.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Αποτυχία αποστολής</translation>
@@ -546,6 +562,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation>Η μακροεντολή έγγραψε στο StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -592,7 +632,8 @@ Do you want to continue?</source>
     <message>
         <source>HotKeys are currently supported only for Windows and X11.
 Disabling this option makes also the action shortcuts ksnip only.</source>
-        <translation type="unfinished"></translation>
+        <translation>Οι συντομεύσεις υποστηρίζονται προς το παρόν μόνο για Windows και X11.
+Απενεργοποιώντας αυτήν την επιλογή οι συντομεύσεις θα έχουν ισχύ μόνο στο ksnip.</translation>
     </message>
 </context>
 <context>
@@ -611,24 +652,17 @@ screenshots.</source>
         <source>Image Grabber</source>
         <translation>Σύλληψη εικόνας</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Εξαναγκασμός στιγμιότυπου με γενικό Wayland</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Κλιμάκωση στιγμιότυπων γενικού Wayland</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
 differently. Enabling this option will
 determine the current screen scaling and
 apply that to the screenshot in ksnip.</source>
-        <translation>Η ενσωμάτωση σε γενικό Wayland που χρησιμοποιεί XDG-DESKTOP-PORTAL
-διαχειρίζεται την κλιμάκωση της εικόνας διαφορετικά. 
-Η ενεργοποίηση αυτής της επιλογής θα προσδιορίσει την τρέχουσα
-κλιμάκωση της εικόνας και θα την εφαρμόσει στην στο στιγμιότυπο στο ksnip.</translation>
+        <translation>Η ενσωμάτωση σε γενικό Wayland που χρησιμοποιεί
+XDG-DESKTOP-PORTAL διαχειρίζεται την κλιμάκωση
+της εικόνας διαφορετικά. Η ενεργοποίηση αυτής της επιλογής
+θα προσδιορίσει την τρέχουσα κλιμάκωση της εικόνας
+και θα την εφαρμόσει στην στο στιγμιότυπο στο ksnip.</translation>
     </message>
     <message>
         <source>GNOME and KDE Plasma support their own Wayland
@@ -636,11 +670,10 @@ and the Generic XDG-DESKTOP-PORTAL screenshots.
 Enabling this option will force KDE Plasma and
 GNOME to use the XDG-DESKTOP-PORTAL screenshots.
 Change in this option require a ksnip restart.</source>
-        <translation>Το GNOME και το KDE Plasma υποστηρίζουν τα δικά τους
-Wayland και γενικού XDG-DESKTOP-PORTAL στιγμιότυπα.
-Ενεργοποιώντας αυτήν την επιλογή θα εξαναγκάσει
-το KDE Plasma και το GNOME να χρησιμοποιήσουν
-τα στιγμιότυπα XDG-DESKTOP-PORTAL.
+        <translation>Το GNOME και το KDE Plasma υποστηρίζουν τα δικά τους Wayland
+και γενικού XDG-DESKTOP-PORTAL στιγμιότυπα. Ενεργοποιώντας
+αυτήν την επιλογή θα εξαναγκάσει το KDE Plasma και το GNOME
+να χρησιμοποιήσουν τα στιγμιότυπα XDG-DESKTOP-PORTAL.
 Η αλλαγή της επιλογής αυτής απαιτεί την επανεκκίνηση του ksnip.</translation>
     </message>
     <message>
@@ -658,6 +691,15 @@ Wayland και γενικού XDG-DESKTOP-PORTAL στιγμιότυπα.
     <message>
         <source>Show Main Window after capturing a new screenshot
 when the Main Window was hidden or minimize.</source>
+        <translation>Εμφάνιση του κύριου παραθύρου μετά την σύλληψη ενός στιγμιότυπου
+όταν το κύριο παράθυρο είναι καταχωνιασμένο ή ελαχιστοποιημένο.</translation>
+    </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -772,22 +814,23 @@ when the Main Window was hidden or minimize.</source>
     <message>
         <source>Base url that will be used for communication with Imgur.
 Changing requires restart.</source>
-        <translation>Το βασικό url που θα χρησιμοποιηθεί για την επικοινωνία με το Imgur. Για να ληφθεί υπόψιν η αλλαγή απαιτείται επανεκκίνηση.</translation>
+        <translation>Το βασικό url που θα χρησιμοποιηθεί για την επικοινωνία με το Imgur.
+Για να ληφθεί υπόψιν η αλλαγή απαιτείται επανεκκίνηση.</translation>
     </message>
     <message>
         <source>Clear Token</source>
-        <translation type="unfinished"></translation>
+        <translation>Εκκαθάριση αδειοδοτικού</translation>
     </message>
 </context>
 <context>
     <name>LoadImageFromFileOperation</name>
     <message>
         <source>Unable to open image</source>
-        <translation type="unfinished"></translation>
+        <translation>Αδύνατο το άνοιγμα της εικόνας</translation>
     </message>
     <message>
         <source>Unable to open image from path %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Αδύνατο το άνοιγμα της εικόνας από την διαδρομή %1</translation>
     </message>
 </context>
 <context>
@@ -799,10 +842,12 @@ Changing requires restart.</source>
     <message>
         <source>Delay in seconds between triggering
 and capturing screenshot.</source>
-        <translation>Καθυστέρηση σε δευτερόλεπτα μεταξύ της ενεργοποίησης και της σύλληψης του στιγμιότυπου.</translation>
+        <translation>Καθυστέρηση σε δευτερόλεπτα μεταξύ της
+ενεργοποίησης και της σύλληψης του στιγμιότυπου.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>δ</translation>
     </message>
     <message>
@@ -900,10 +945,6 @@ and capturing screenshot.</source>
         <source>&amp;Help</source>
         <translation>&amp;Βοήθεια</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Αρχεία εικόνας (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Προσθήκη υδατογραφήματος</translation>
@@ -978,12 +1019,11 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Copy as data URI</source>
-        <translation type="unfinished"></translation>
+        <translation>Αντιγραφή ως URI δεδομένων</translation>
     </message>
     <message>
         <source>Open &amp;Recent</source>
-        <translation type="unfinished">Άνοιγμα
-πρόσφατου</translation>
+        <translation>Άνοιγμα &amp;πρόσφατου</translation>
     </message>
     <message>
         <source>Modify Canvas</source>
@@ -991,11 +1031,11 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Upload triggerCapture to external source</source>
-        <translation type="unfinished"></translation>
+        <translation>Αποστολή της σύλληψης του ενεργοποιητή προς μια εξωτερική πηγή</translation>
     </message>
     <message>
         <source>Copy triggerCapture to system clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Αντιγραφή της σύλληψης του ενεργοποιητή στο πρόχειρο του συστήματος</translation>
     </message>
     <message>
         <source>Scale Image</source>
@@ -1009,6 +1049,14 @@ and capturing screenshot.</source>
         <source>Rotate Image</source>
         <translation>Περιστροφή εικόνας</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished">Ενέργειες</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1076,18 +1124,10 @@ and capturing screenshot.</source>
         <source>Image Renamed</source>
         <translation>Η εικόνα μετονομάστηκε</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Η εικόνα μετονομάστηκε επιτυχώς σε </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Η μετονομασία της εικόνας απέτυχε</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Αποτυχία μετονομασίας της εικόνας σε </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Μετονομασία της εικόνας</translation>
@@ -1096,6 +1136,14 @@ and capturing screenshot.</source>
         <source>New filename:</source>
         <translation>Νέο όνομα αρχείου:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1103,10 +1151,6 @@ and capturing screenshot.</source>
         <source>Save As</source>
         <translation>Αποθήκευση ως</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Εικόνες</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Όλα τα αρχεία</translation>
@@ -1120,12 +1164,16 @@ and capturing screenshot.</source>
         <translation>Η αποθήκευση της εικόνας απέτυχε</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Αποθηκεύτηκε στο</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Αποτυχία αποθήκευσης της εικόνας στο</translation>
+        <source>Saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1145,7 +1193,8 @@ and capturing screenshot.</source>
     <message>
         <source>When enabled will overwrite the save directory stored in settings
 with the latest save directory, for every save.</source>
-        <translation>Όταν είναι ενεργοποιημένο απομνημονεύεται ο τελευταία χρησιμοποιούμενος κατάλογος για χρήση στις επόμενες αποθηκεύσεις.</translation>
+        <translation>Όταν είναι ενεργοποιημένο απομνημονεύεται ο τελευταία
+χρησιμοποιούμενος κατάλογος για χρήση στις επόμενες αποθηκεύσεις.</translation>
     </message>
     <message>
         <source>Capture save location and filename</source>
@@ -1205,7 +1254,8 @@ Not all image formats support the full range, JPEG does.</source>
     <message>
         <source>Path to script that will be called for uploading. During upload the script will be called
 with the path to a temporary png file as a single argument.</source>
-        <translation>Η διαδρομή της μακροεντολής που θα εκτελεστεί για την αποστολή. Κατά την αποστολή η μακροεντολή θα εκτελεστεί με μοναδικό όρισμα την διαδρομή ενός προσωρινού αρχείου png.</translation>
+        <translation>Η διαδρομή της μακροεντολής που θα εκτελεστεί για την αποστολή.
+Κατά την αποστολή η μακροεντολή θα εκτελεστεί με μοναδικό όρισμα την διαδρομή ενός προσωρινού αρχείου png.</translation>
     </message>
     <message>
         <source>Browse</source>
@@ -1306,55 +1356,59 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation>Ενέργειες</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
     <message>
         <source>Resize selected rect using the handles or move it by dragging the selection.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αλλαγή μεγέθους του επιλεγμένου ορθογωνίου χρησιμοποιώντας τις λαβές ή μετακίνηση με σύρσιμο της επιλογής.</translation>
     </message>
     <message>
         <source>Use arrow keys to move the selection.</source>
-        <translation type="unfinished"></translation>
+        <translation>Χρησιμοποιήστε τα βελάκια για να μετακινήσετε την επιλογή.</translation>
     </message>
     <message>
         <source>Use arrow keys while pressing CTRL to move top left handle.</source>
-        <translation type="unfinished"></translation>
+        <translation>Χρησιμοποιήστε τα βελάκια κρατώντας πατημένο το πλήκτρο CTRL για να μετακινήσετε την πάνω αριστερά λαβή.</translation>
     </message>
     <message>
         <source>Use arrow keys while pressing ALT to move bottom right handle.</source>
-        <translation type="unfinished"></translation>
+        <translation>Χρησιμοποιήστε τα βελάκια κρατώντας πατημένο το πλήκτρο ALT για να μετακινήσετε την κάτω δεξιά λαβή.</translation>
     </message>
     <message>
         <source>Confirm selection by pressing ENTER/RETURN or abort by pressing ESC.</source>
-        <translation type="unfinished"></translation>
+        <translation>Επιβεβαιώστε την επιλογή πιέζοντας ENTER/RETURN ή εγκατάλειψη με ESC.</translation>
     </message>
     <message>
         <source>This message can be disabled via settings.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αυτό το μήνυμα μπορεί να απενεργοποιηθεί από τις ρυθμίσεις.</translation>
     </message>
 </context>
 <context>
     <name>SnippingAreaSelectorInfoText</name>
     <message>
         <source>Click and Drag to select a rectangular area or press ESC to quit.</source>
-        <translation type="unfinished"></translation>
+        <translation>Κλικ και σύρσιμο για να επιλέξετε μια ορθογώνια περιοχή ή πιέστε ESC για εγκατάλειψη.</translation>
     </message>
     <message>
         <source>Hold CTRL pressed to resize selection after selecting.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αφού πραγματοποιήσετε την επιλογή, κρατήστε πατημένο το CTRL για να αλλάξετε το μέγεθός της.</translation>
     </message>
     <message>
         <source>Hold CTRL pressed to prevent resizing after selecting.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αφού πραγματοποιήσετε την επιλογή, κρατήστε πατημένο το CTRL για να αποτρέψετε την αλλαγή του μεγέθους της.</translation>
     </message>
     <message>
         <source>Operation will be canceled after 60 sec when no selection made.</source>
-        <translation type="unfinished"></translation>
+        <translation>Η ενέργεια θα ακυρωθεί μετά από 60 δευτ. αν δεν πραγματοποιηθεί κάποια επιλογή.</translation>
     </message>
     <message>
         <source>This message can be disabled via settings.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αυτό το μήνυμα μπορεί να απενεργοποιηθεί από τις ρυθμίσεις.</translation>
     </message>
 </context>
 <context>
@@ -1372,7 +1426,14 @@ snipping area is shown and with the option disabled
 the delay happens after the snipping area is shown.
 This feature is always disabled for Wayland and always
 enabled for MacOs.</source>
-        <translation>Όταν είναι ενεργοποιημένο, το παρασκήνιο θα είναι παγωμένο κατά την επιλογή της ορθογώνιας περιοχής. Επίσης αλλάζει την συμπεριφορά των στιγμιότυπων με καθυστέρηση: η καθυστέρηση λαμβάνει χώρα πριν την εμφάνιση της περιοχής σύλληψης ενώ όταν είναι απενεργοποιημένο η καθυστέρηση λαμβάνει χώρα μετά την εμφάνιση της περιοχής σύλληψης. Αυτό το χαρακτηριστικό είναι απενεργοποιημένο για τον εξυπηρετητή Wayland και πάντα ενεργοποιημένο για το MacOs.</translation>
+        <translation>Όταν είναι ενεργοποιημένο, το παρασκήνιο θα είναι παγωμένο
+κατά την επιλογή της ορθογώνιας περιοχής. Επίσης αλλάζει
+την συμπεριφορά των στιγμιότυπων με καθυστέρηση: η καθυστέρηση λαμβάνει χώρα πριν
+την εμφάνιση της περιοχής σύλληψης ενώ όταν είναι
+απενεργοποιημένο η καθυστέρηση λαμβάνει χώρα μετά την εμφάνιση
+της περιοχής σύλληψης. Αυτό το χαρακτηριστικό είναι
+απενεργοποιημένο για τον εξυπηρετητή Wayland
+και πάντα ενεργοποιημένο για το MacOs.</translation>
     </message>
     <message>
         <source>Show magnifying glass on snipping area</source>
@@ -1382,7 +1443,9 @@ enabled for MacOs.</source>
         <source>Show a magnifying glass which zooms into
 the background image. This option only works
 with &apos;Freeze Image while snipping&apos; enabled.</source>
-        <translation>Εμφανίζει έναν μεγεθυντικό φακό ο οποίος εστιάζει στην εικόνα του παρασκηνίου. Αυτή η επιλογή λειτουργεί μόνο όταν το &quot;πάγωμα της οθόνης κατά την σύλληψη&quot; είναι ενεργοποιημένο.</translation>
+        <translation>Εμφανίζει έναν μεγεθυντικό φακό ο οποίος εστιάζει
+στην εικόνα του παρασκηνίου. Αυτή η επιλογή λειτουργεί μόνο όταν
+το &quot;πάγωμα της οθόνης κατά την σύλληψη&quot; είναι ενεργοποιημένο.</translation>
     </message>
     <message>
         <source>Show Snipping Area rulers</source>
@@ -1391,7 +1454,8 @@ with &apos;Freeze Image while snipping&apos; enabled.</source>
     <message>
         <source>Horizontal and vertical lines going from
 desktop edges to cursor on snipping area.</source>
-        <translation>Οριζόντιες και κάθετες γραμμές από τις άκρες της επιφάνειας εργασίας μέχρι τον δρομέα στην περιοχή της σύλληψης.</translation>
+        <translation>Οριζόντιες και κάθετες γραμμές από τις άκρες της επιφάνειας
+εργασίας μέχρι τον δρομέα στην περιοχή της σύλληψης.</translation>
     </message>
     <message>
         <source>Show Snipping Area position and size info</source>
@@ -1402,26 +1466,28 @@ desktop edges to cursor on snipping area.</source>
 is shown, when the mouse button is pressed,
 the size of the select area is shown left
 and above from the captured area.</source>
-        <translation>Όταν το αριστερό κλικ του ποντικιού δεν είναι πιεσμένο, εμφανίζεται η θέση. Όταν το κλικ του ποντικιού είναι πατημένο, το μέγεθος της επιλεγμένης περιοχής εμφανίζεται στα αριστερά και κάτω από την περιοχή σύλληψης.</translation>
+        <translation>Όταν το αριστερό κλικ του ποντικιού δεν είναι πιεσμένο, εμφανίζεται η θέση.
+Όταν το κλικ του ποντικιού είναι πατημένο,
+το μέγεθος της επιλεγμένης περιοχής εμφανίζεται στα
+αριστερά και κάτω από την περιοχή σύλληψης.</translation>
     </message>
     <message>
         <source>Allow resizing rect area selection by default</source>
-        <translation type="unfinished"></translation>
+        <translation>Να επιτρέπεται η αλλαγή μεγέθους της ορθογώνιας περιοχής επιλογής εξ ορισμού</translation>
     </message>
     <message>
         <source>When enabled will, after selecting a rect
 area, allow resizing the selection. When
 done resizing the selection can be confirmed
 by pressing return.</source>
-        <translation>Όταν είναι ενεργοποιημένο και αφού έχει
-επιλεγεί μια ορθογώνια περιοχή, επιτρέπει
-την αλλαγή μεγέθους της επιλογής.
+        <translation>Όταν είναι ενεργοποιημένο και αφού έχει επιλεγεί μια
+ορθογώνια περιοχή, επιτρέπει την αλλαγή μεγέθους της επιλογής.
 Μετά το πέρας της ενέργειας επιβεβαιώστε
 πιέζοντας το πλήκτρο Enter.</translation>
     </message>
     <message>
         <source>Show Snipping Area info text</source>
-        <translation type="unfinished"></translation>
+        <translation>Εμφάνιση του κειμένου πληροφοριών στην περιοχή σύλληψης</translation>
     </message>
     <message>
         <source>Snipping Area cursor color</source>
@@ -1441,25 +1507,27 @@ by pressing return.</source>
     </message>
     <message>
         <source>Snipping Area</source>
-        <translation type="unfinished"></translation>
+        <translation>Περιοχή σύλληψης</translation>
     </message>
     <message>
         <source>Snipping Area adorner color</source>
-        <translation type="unfinished"></translation>
+        <translation>Χρώμα διακόσμησης της περιοχής σύλληψης</translation>
     </message>
     <message>
         <source>Sets the color of all adorner elements
 on the snipping area.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ορίζει το χρώμα όλων των αντικειμένων διακόσμησης
+στην περιοχή σύλληψης.</translation>
     </message>
     <message>
         <source>Snipping Area Transparency</source>
-        <translation type="unfinished"></translation>
+        <translation>Διαφάνεια της περιοχής σύλληψης</translation>
     </message>
     <message>
         <source>Alpha for not selected region on snipping area.
 Smaller number is more transparent.</source>
-        <translation type="unfinished"></translation>
+        <translation>Άλφα για το με επιλεγμένο τμήμα της περιοχής σύλληψης.
+Με μικρότερη τιμή αποκτάτε περισσότερη διαφάνεια.</translation>
     </message>
 </context>
 <context>
@@ -1513,7 +1581,8 @@ Smaller number is more transparent.</source>
     <message>
         <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
 Change requires restart.</source>
-        <translation>Όταν είναι ενεργοποιημένο προστίθεται ένα εικονίδιο στο πλαίσιο συστήματος αν υποστηρίζεται από τον διαχειριστή παραθύρων του λειτουργικού συστήματος. Για να ληφθούν υπόψιν οι αλλαγές, απαιτείται επανεκκίνηση.</translation>
+        <translation>Όταν είναι ενεργοποιημένο προστίθεται ένα εικονίδιο στο πλαίσιο συστήματος αν υποστηρίζεται από τον
+διαχειριστή παραθύρων του λειτουργικού συστήματος. Για να ληφθούν υπόψιν οι αλλαγές, απαιτείται επανεκκίνηση.</translation>
     </message>
     <message>
         <source>Minimize to Tray</source>
@@ -1533,31 +1602,32 @@ Change requires restart.</source>
     </message>
     <message>
         <source>Capture</source>
-        <translation type="unfinished">Σύλληψη</translation>
+        <translation>Σύλληψη</translation>
     </message>
     <message>
         <source>Default Tray Icon action</source>
-        <translation type="unfinished"></translation>
+        <translation>Προκαθορισμένη ενέργεια του εικονιδίου στο πλαίσιο συστήματος</translation>
     </message>
     <message>
         <source>Default Action that is triggered by left clicking the tray icon.</source>
-        <translation type="unfinished"></translation>
+        <translation>Η προκαθορισμένη ενέργεια που προκαλείται με αριστερό κλικ στο εικονίδιο του πλαισίου συστήματος.</translation>
     </message>
     <message>
         <source>Tray Icon Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Ρυθμίσεις του εικονιδίου του πλαισίου συστήματος</translation>
     </message>
     <message>
         <source>Use platform specific notification service</source>
-        <translation type="unfinished"></translation>
+        <translation>Χρήση μιας ειδικής υπηρεσίας ειδοποιήσεων του πλατύβαθρου</translation>
     </message>
     <message>
         <source>When enabled will use try to use platform specific notification
 service when such exists. Change requires restart to take effect.</source>
+        <translation>Όταν είναι ενεργοποιημένο, θα γίνει προσπάθεια χρήσης της ειδικής υπηρεσίας ειδοποιήσεων του πλατύβαθρου,
+εφόσον υπάρχει μία. Για να λάβει χώρα η αλλαγή αυτής της ρύθμισης απαιτείται επανεκκίνηση.</translation>
+    </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1568,12 +1638,8 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Επιλογή εικόνας</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Εικόνες</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Όλα τα αρχεία</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1617,6 +1683,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation>Αποστολέας</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
@@ -1641,7 +1711,7 @@ service when such exists. Change requires restart to take effect.</source>
     </message>
     <message>
         <source>Update</source>
-        <translation type="unfinished">Ενημέρωση</translation>
+        <translation>Ενημέρωση</translation>
     </message>
     <message>
         <source>Rotate Watermark</source>
