@@ -29,7 +29,7 @@
     </message>
     <message>
         <source>Contact</source>
-        <translation type="unfinished"></translation>
+        <translation>Contacto</translation>
     </message>
 </context>
 <context>
@@ -40,7 +40,7 @@
     </message>
     <message>
         <source>Screenshot and Annotation Tool</source>
-        <translation type="unfinished"></translation>
+        <translation>Herramienta de Captura de Pantalla y Anotación</translation>
     </message>
 </context>
 <context>
@@ -55,7 +55,7 @@
     </message>
     <message>
         <source>Clear</source>
-        <translation type="unfinished">Limpiar</translation>
+        <translation>Limpiar</translation>
     </message>
     <message>
         <source>Take Capture</source>
@@ -71,7 +71,8 @@
     </message>
     <message>
         <source>s</source>
-        <translation type="unfinished">s</translation>
+        <extracomment>The small letter s stands for seconds.</extracomment>
+        <translation>s</translation>
     </message>
     <message>
         <source>Capture Mode</source>
@@ -99,14 +100,14 @@
     </message>
     <message>
         <source>Hide Main Window</source>
-        <translation type="unfinished"></translation>
+        <translation>Ocultar la Ventana Principal</translation>
     </message>
 </context>
 <context>
     <name>ActionsSettings</name>
     <message>
         <source>Add</source>
-        <translation type="unfinished">Añadir</translation>
+        <translation>Añadir</translation>
     </message>
     <message>
         <source>Actions Settings</source>
@@ -162,7 +163,7 @@ más suaves.</translation>
     </message>
     <message>
         <source>Switch to Select Tool after drawing Item</source>
-        <translation>Cambiar a la herramienta de selección después de dibujar un elemento</translation>
+        <translation>Cambiar a Selección de Herramienta después de dibujar Item</translation>
     </message>
     <message>
         <source>Number Tool Seed change updates all Number Items</source>
@@ -188,12 +189,13 @@ El cambio de color afecta solo a las áreas de anotación nuevas.</translation>
     </message>
     <message>
         <source>Select Item after drawing</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleccionar Elemento tras dibujar</translation>
     </message>
     <message>
         <source>With this option enabled the item gets selected after
 being created, allowing changing settings.</source>
-        <translation type="unfinished"></translation>
+        <translation>Con esta opción seleccionada, los elementos se seleccionan
+después de ser creados, permitiendo cambiar la configuración.</translation>
     </message>
 </context>
 <context>
@@ -256,22 +258,44 @@ un nuevo inicio de todas las instancias.</translation>
     </message>
     <message>
         <source>Auto hide Docks</source>
-        <translation type="unfinished">Ocultar automáticamente los Docks</translation>
+        <translation>Ocultar automáticamente los Docks</translation>
     </message>
     <message>
         <source>On startup hide Toolbar and Annotation Settings.
 Docks visibility can be toggled with the Tab Key.</source>
-        <translation type="unfinished">Al inicio ocultar la barra de herramientar y las opciones de comentarios.
-La visibilidad del Dock puede ser alternada con el tabulador.</translation>
+        <translation>Al inicio ocultar la barra de herramientas y las opciones de comentarios.
+Se puede alternar la visibilidad del Dock con el tabulador.</translation>
     </message>
     <message>
         <source>Auto resize to content</source>
-        <translation>Cambio de tamaño automático al contenido</translation>
+        <translation>Cambiar de tamaño automáticamente al contenido</translation>
     </message>
     <message>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Cambie automáticamente el tamaño de la ventana principal para que se ajuste a la imagen del contenido.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Activar depuración</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Activa la salida de depuración en consola.
+Este cambio require reiniciar ksnip.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished">Redimensionar al retraso del contenido</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Cambiar el tamaño al contenido es un retraso para permitir que el Administrador de ventanas reciba
+el nuevo contenido. En caso de que la ventana principal no esté correctamente ajustada
+al nuevo contenido, aumentar este retraso podría mejorar el comportamiento.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -321,8 +345,8 @@ La visibilidad del Dock puede ser alternada con el tabulador.</translation>
     <message>
         <source>The capture %1%2%3 has been modified.
 Do you want to save it?</source>
-        <translation>Se ha modificado la captura %1%2%3.
-¿Quiere guardarla?</translation>
+        <translation>La captura %1%2%3 ha sido modificada
+¿Desea guardar?</translation>
     </message>
 </context>
 <context>
@@ -364,31 +388,19 @@ Do you want to save it?</source>
     <name>ContactTab</name>
     <message>
         <source>Community</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation type="unfinished"></translation>
+        <translation>Comunidad</translation>
     </message>
     <message>
         <source>Bug Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>Reporte de errores</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation type="unfinished">Utilice </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Si tiene preguntas generales, ideas o simplemente quiere hablar sobre ksnip,&lt;br/&gt;únase a nuestro %1 o nuestro %2 servidor.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation type="unfinished"> para informar de defectos.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Utilice %1 para informar errores.</translation>
     </message>
 </context>
 <context>
@@ -425,14 +437,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>aquí</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>También es posible, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Las donaciones son siempre bienvenidas</translation>
@@ -442,16 +446,20 @@ Do you want to continue?</source>
         <translation>Donación</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Convertirse en patrocinador en GitHub</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip es un proyecto de software libre copyleft no rentable, y&lt;br/&gt;todavía tiene algunos costos que deben cubrirse,&lt;br/&gt;como costos de dominio o costos de hardware para el soporte multiplataforma.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip es un projecto de software libre, y&lt;br/&gt;aún tiene algunos costos que necesitan ser cubiertos,&lt;br/&gt;como costos de dominios o hardware para soporte multi plataforma.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Si desea ayudar o simplemente desea apreciar el trabajo que se está realizando&lt;br/&gt;invitando a los desarrolladores a tomar una cerveza o un café, puede hacerlo %1aquí%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Si quieres ayudar o solo&lt;br/&gt;quieres apreciar el trabajo que se está haciendo&lt;br/&gt;invitando a los desarrolladores a una cerveza o un café, puede hacerlo</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>¿Convertirse en patrocinador de GitHub?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>También es posible, %1aquí%2.</translation>
     </message>
 </context>
 <context>
@@ -465,31 +473,54 @@ Do you want to continue?</source>
     <name>EnumTranslator</name>
     <message>
         <source>Rectangular Area</source>
-        <translation type="unfinished">Área rectangular</translation>
+        <translation>Área rectangular</translation>
     </message>
     <message>
         <source>Last Rectangular Area</source>
-        <translation type="unfinished">Última área rectangular</translation>
+        <translation>Última área rectangular</translation>
     </message>
     <message>
         <source>Full Screen (All Monitors)</source>
-        <translation type="unfinished">Pantalla completa (todos los monitores)</translation>
+        <translation>Pantalla completa (todos los monitores)</translation>
     </message>
     <message>
         <source>Current Screen</source>
-        <translation type="unfinished">Pantalla actual</translation>
+        <translation>Pantalla actual</translation>
     </message>
     <message>
         <source>Active Window</source>
-        <translation type="unfinished">Ventana activa</translation>
+        <translation>Ventana activa</translation>
     </message>
     <message>
         <source>Window Under Cursor</source>
-        <translation type="unfinished">Ventana bajo el puntero</translation>
+        <translation>Ventana bajo el puntero</translation>
     </message>
     <message>
         <source>Screenshot Portal</source>
-        <translation type="unfinished">Portal de capturas</translation>
+        <translation>Portal de capturas</translation>
+    </message>
+</context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Forzar subida anónima.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Url</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Usuario</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Clave</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Cargador FTP</translation>
     </message>
 </context>
 <context>
@@ -498,18 +529,6 @@ Do you want to continue?</source>
         <source>Upload Successful</source>
         <translation>Subida con éxito</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Secuencia de carga </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> finalizado exitosamente.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Subido a</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Incapaz de guardar temporalmente la imagen para subir.</translation>
@@ -538,17 +557,37 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation>Error Web, revise la salida en la consola.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Proceso con error desconocido.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Subida fallida</translation>
     </message>
     <message>
         <source>Script wrote to StdErr.</source>
-        <translation>Secuencia transferida a la salida estándar de errores.</translation>
+        <translation>El script escribió en StdErr.</translation>
+    </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>Carga FTP finalizada con éxito.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Error desconocido.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Error de conexión.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Error de permiso.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>El script de carga %1 finalizó correctamente.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Subido a %1</translation>
     </message>
 </context>
 <context>
@@ -616,14 +655,6 @@ las capturas de pantalla.</translation>
         <source>Image Grabber</source>
         <translation>Capturador de imágenes</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Forzar captura de pantalla genérica de Wayland</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Escalar capturas de pantalla genéricas de Wayland</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -663,7 +694,16 @@ El cambio en esta opción requiere un reinicio de ksnip.</translation>
     <message>
         <source>Show Main Window after capturing a new screenshot
 when the Main Window was hidden or minimize.</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar ventana principal después de capturar una nueva captura de pantalla
+cuando la ventana principal estaba oculta o minimizada.</translation>
+    </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Forzar Genérico Wayland (xdg-desktop-portal) Captura de pantalla</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Escala Genérica Wayland (xdg-desktop-portal) Captura de pantalla</translation>
     </message>
 </context>
 <context>
@@ -810,6 +850,7 @@ y la captura de pantalla.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -907,10 +948,6 @@ y la captura de pantalla.</translation>
         <source>&amp;Help</source>
         <translation>Ay&amp;uda</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Archivos de imagen (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Añadir marca de agua</translation>
@@ -941,7 +978,7 @@ y la captura de pantalla.</translation>
     </message>
     <message>
         <source>Pin</source>
-        <translation>Anclar</translation>
+        <translation type="unfinished">Anclar</translation>
     </message>
     <message>
         <source>Pin screenshot to foreground in frameless window</source>
@@ -1005,15 +1042,23 @@ y la captura de pantalla.</translation>
     </message>
     <message>
         <source>Scale Image</source>
-        <translation type="unfinished"></translation>
+        <translation>Escalar Imagen</translation>
     </message>
     <message>
         <source>Rotate</source>
-        <translation type="unfinished"></translation>
+        <translation>Girar</translation>
     </message>
     <message>
         <source>Rotate Image</source>
-        <translation type="unfinished"></translation>
+        <translation>Girar imagen</translation>
+    </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished">Acciones</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Archivos de Imagen</translation>
     </message>
 </context>
 <context>
@@ -1066,14 +1111,14 @@ y la captura de pantalla.</translation>
     </message>
     <message>
         <source>Close All</source>
-        <translation>Cerrar todo</translation>
+        <translation>Cerrar todos</translation>
     </message>
 </context>
 <context>
     <name>PinWindowHandler</name>
     <message>
         <source>Pin Window %1</source>
-        <translation>Anclar ventana %1</translation>
+        <translation>Fijar ventana %1</translation>
     </message>
 </context>
 <context>
@@ -1082,18 +1127,10 @@ y la captura de pantalla.</translation>
         <source>Image Renamed</source>
         <translation>Imagen renombrada</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Imagen renombrada exitosamente a </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Fallo al renombrar la imagen</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Falli al renombrar la imagen a </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Renombrar imagen</translation>
@@ -1102,6 +1139,14 @@ y la captura de pantalla.</translation>
         <source>New filename:</source>
         <translation>Nuevo nombre de archivo:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Imagen renombrada correctamente a %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Error al cambiar el nombre de la imagen a %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1109,10 +1154,6 @@ y la captura de pantalla.</translation>
         <source>Save As</source>
         <translation>Guardar como</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Imágenes</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Todos los archivos</translation>
@@ -1126,12 +1167,16 @@ y la captura de pantalla.</translation>
         <translation>No se pudo guardar la imagen</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Guardado en</translation>
+        <source>Image Files</source>
+        <translation>Archivos de Imagen</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>No se pudo guardar la imagen en</translation>
+        <source>Saved to %1</source>
+        <translation>Salvado a %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Error al guardar la imagen en %1</translation>
     </message>
 </context>
 <context>
@@ -1315,6 +1360,10 @@ Cuando se omite, se copia todo.</translation>
         <source>Actions</source>
         <translation>Acciones</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Cargador FTP</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1460,7 +1509,7 @@ by pressing return.</source>
     </message>
     <message>
         <source>Snipping Area adorner color</source>
-        <translation type="unfinished"></translation>
+        <translation>Color del recuadro de recorte</translation>
     </message>
     <message>
         <source>Sets the color of all adorner elements
@@ -1469,7 +1518,7 @@ on the snipping area.</source>
     </message>
     <message>
         <source>Snipping Area Transparency</source>
-        <translation type="unfinished"></translation>
+        <translation>Transparencia del area de recorte</translation>
     </message>
     <message>
         <source>Alpha for not selected region on snipping area.
@@ -1505,7 +1554,7 @@ Smaller number is more transparent.</source>
     </message>
     <message>
         <source>Remove</source>
-        <translation>Quitar</translation>
+        <translation>Remover</translation>
     </message>
     <message>
         <source>Add Stickers</source>
@@ -1553,29 +1602,29 @@ El cambio requiere que se reinicie.</translation>
     </message>
     <message>
         <source>Default Tray Icon action</source>
-        <translation type="unfinished"></translation>
+        <translation>Acción por defecto del icono de bandeja</translation>
     </message>
     <message>
         <source>Default Action that is triggered by left clicking the tray icon.</source>
-        <translation type="unfinished"></translation>
+        <translation>Acción por defecto de clic izquierdo en el icono de la bandeja</translation>
     </message>
     <message>
         <source>Tray Icon Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Configuración del icono de bandeja</translation>
     </message>
     <message>
         <source>Use platform specific notification service</source>
-        <translation type="unfinished"></translation>
+        <translation>Utilice el servicio de notificación específico de la plataforma</translation>
     </message>
     <message>
         <source>When enabled will use try to use platform specific notification
 service when such exists. Change requires restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1584,12 +1633,8 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Seleccionar imagen</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Imágenes</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Todos los archivos</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1633,6 +1678,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation>Subir imagen</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
