@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ Kaien ikusgarritasuna Tab teklarekin txandakatu daiteke.</translation>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Aldatu automatikoki leiho nagusiaren tamaina edukiaren irudira doitzeko.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Gaitu arazketa</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Arazte-irteera gaitzen du kontsolan idatzita.
+Ksnip berrabiarazi behar da eragina izateko.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Edukira doitzeko atzerapena</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Edukira doitzeko atzerapena Leiho-kudeatzaileari eduki berria jaso ahal izateko
+atzerapena da. Leiho nagusia eduki berrira behar bezala doitzen ez bada,
+atzerapen hori handitzeak portaera hobe dezake.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Nahi duzu gordetzea?</translation>
         <source>Community</source>
         <translation>Komunitatea</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Galdera orokorrak edo ideiak badituzu, nahiz Ksnip-en gainean hitz egiteko,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>mesedez sartu gure </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> zerbitzaria.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Erroreen txostenak</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Erabili </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Galdera orokorrak edo ideiak badituzu edo ksnip-i buruz hitz egin nahi baduzu,&lt;br/&gt;sartu gure %1 edo %2 zerbitzarian.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> erroreen berri emateko.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Erabili %1 akatsen berri emateko.</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Jarraitu nahi duzu?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>hemen</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Izan liteke ere, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Diru-laguntzak beti dira ongi etorriak</translation>
@@ -443,16 +446,20 @@ Jarraitu nahi duzu?</translation>
         <translation>Dohaintza</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Bihurtu GitHub-en babeslea</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip irabazi asmorik gabeko copyleft libreko software proiektu bat da, eta&lt;br/&gt;oraindik estali beharreko kostu batzuk ditu,&lt;br/&gt;esaterako, domeinu-kostuak edo hardware-kostuak plataforma anitzeko zerbitzua emateko.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>Ksnip irabazi asmorik gabeko software libreko proektua da, eta &lt;br/&gt;oraindik estali gabeko kostu batzuk ditu&lt;br/&gt;, hala nola plataforma anitzen sustengua emateko behar diren domeinuaren eta hardwarearen kostuak.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Garatzaileei garagardo bat edo kafe bat gonbidatuz lagundu nahi baduzu edo besterik gabe eskertu nahi baduzu egiten ari den lana&lt;br/&gt;, %1 hemen%2 egin dezakezu.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Lagundu nahi bagaituzu edo &lt;br/&gt;egindako lana saritu nahi baduzu&lt;br/&gt; garatzaileak garagardo bat edo kafe batera gonbidatuz, egin dezakezu</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Githuben babeslea izan nahi duzu?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Hori ere posible da, %1hemen%2.</translation>
     </message>
 </context>
 <context>
@@ -493,24 +500,35 @@ Jarraitu nahi duzu?</translation>
         <translation>Pantaila argazkien ataria</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Behartu karga anonimoa.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Url</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Erabiltzaile-izena</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Pasahitza</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP kargatzailea</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Karga ongi burutu da</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Kargarako scripta </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> behar bezala burutu da.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Kargatuta hona</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Ezin izan da irudia behin behinean gorde kargatzeko.</translation>
@@ -539,10 +557,6 @@ Jarraitu nahi duzu?</translation>
         <source>Web error, check console output.</source>
         <translation>Web errorea, begiratu kontsolaren irteera.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Prozesuaren errore ezezaguna.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Kargak huts egin du</translation>
@@ -551,6 +565,30 @@ Jarraitu nahi duzu?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>StdErr-ra bidalitako scripta.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>FTP karga behar bezala burutu da.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Errore ezezaguna</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Konexio errorea.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Baimen errorea.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>% 1 script-aren karga behar bezala amaitu da.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>%1-era kargatu da</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ ikusiko da.</translation>
         <source>Image Grabber</source>
         <translation>Irudien kapturatzailea</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Behartu Wayland-en pantaila generikoa</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Eskalatu Wayland-en pantaila-argazki generikoak</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Erakutsi leiho nagusia pantaila argazki berri bat egin ondoren
 leiho nagusia ezkutuan edo minimizatuta dagoenean.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Behartu Generic Wayland (xdg-desktop-portal) pantaila-argazkia</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Eskalatu Generic Wayland (xdg-desktop-portal) pantaila-argazkia</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -812,6 +850,7 @@ eta pantaila-argazkiaren artean.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -925,10 +964,6 @@ eta pantaila-argazkiaren artean.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Laguntza</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Irudi-fitxategiak (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Save As...</source>
         <translation>Gorde honela...</translation>
@@ -1017,6 +1052,14 @@ eta pantaila-argazkiaren artean.</translation>
         <source>Rotate Image</source>
         <translation>Biratu irudia</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Ekintzak</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Irudi fitxategiak</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ eta pantaila-argazkiaren artean.</translation>
         <source>Image Renamed</source>
         <translation>Irudia berrizendatua</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Irudia behar bezala berrizendatu da horrela </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Irudiaren berrizendatzeak huts egin du</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Huts egin du horrela berrizendatzen </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Berrizendatu irudia</translation>
@@ -1104,6 +1139,14 @@ eta pantaila-argazkiaren artean.</translation>
         <source>New filename:</source>
         <translation>Fitxategi-izen berria:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Irudiari %1 izen berria ezarri zaio</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Ezin izan da %1 izena ezarri irudiari</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ eta pantaila-argazkiaren artean.</translation>
         <source>Save As</source>
         <translation>Gorde honela</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Irudiak</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Fitxategi guztiak</translation>
@@ -1123,17 +1162,21 @@ eta pantaila-argazkiaren artean.</translation>
         <source>Image Saved</source>
         <translation>Irudia gorde da</translation>
     </message>
-    <message>
-        <source>Saved to</source>
-        <translation>Hemen gordea</translation>
-    </message>
     <message>
         <source>Saving Image Failed</source>
         <translation>Irudiaren gordetzeak huts egin du</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Huts egin du irudia hona gordetzean</translation>
+        <source>Image Files</source>
+        <translation>Irudi fitxategiak</translation>
+    </message>
+    <message>
+        <source>Saved to %1</source>
+        <translation>%1 izenarekin gorde da</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Ezin izan da %1 izenarekin gorde</translation>
     </message>
 </context>
 <context>
@@ -1316,6 +1359,10 @@ Ez badago, dena kopiatzen da.</translation>
         <source>Actions</source>
         <translation>Ekintzak</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP kargatzailea</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1572,10 +1619,6 @@ Aldaketak berrabiaraztea eskatzen du.</translation>
         <source>Tray Icon Settings</source>
         <translation>Erretiluko ikonoaren ezarpenak</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Erakutsi erretiluko ikonoaren jakinarazpenak</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Erabili plataformaren berariazko jakinarazpen zerbitzua</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Aktibatuta dagoenean saiatuko da plataformaren berariazko jakinarazpen
 zerbitzua erabiltzen baldin badago. Aldaketak berrabiaraztea eskatzen du eragina izateko.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Bistaratu erretiluko ikonoaren jakinarazpenak</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,12 +1641,8 @@ zerbitzua erabiltzen baldin badago. Aldaketak berrabiaraztea eskatzen du eragina
         <translation>Aukeratu irudia</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Irudiak</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Fitxategi guztiak</translation>
+        <source>Image Files</source>
+        <translation>Irudi fitxategiak</translation>
     </message>
 </context>
 <context>
@@ -1643,6 +1686,10 @@ zerbitzua erabiltzen baldin badago. Aldaketak berrabiaraztea eskatzen du eragina
         <source>Uploader</source>
         <translation>Kargagailua</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
