@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -261,6 +262,25 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -354,29 +374,17 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation type="unfinished">خواهشمندیم استفاده کنید </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation type="unfinished"> گزارش اشکالات.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -412,14 +420,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation type="unfinished"></translation>
@@ -429,15 +429,19 @@ Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
+        <source>Become a GitHub Sponsor?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -479,24 +483,35 @@ Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation type="unfinished"></translation>
@@ -525,10 +540,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation type="unfinished"></translation>
@@ -537,6 +548,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -601,14 +636,6 @@ screenshots.</source>
         <source>Image Grabber</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -642,6 +669,14 @@ Change in this option require a ksnip restart.</source>
 when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -785,6 +820,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -882,10 +918,6 @@ and capturing screenshot.</source>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation type="unfinished"></translation>
@@ -990,6 +1022,14 @@ and capturing screenshot.</source>
         <source>Rotate Image</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1057,18 +1097,10 @@ and capturing screenshot.</source>
         <source>Image Renamed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation type="unfinished"></translation>
@@ -1077,6 +1109,14 @@ and capturing screenshot.</source>
         <source>New filename:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1084,10 +1124,6 @@ and capturing screenshot.</source>
         <source>Save As</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation type="unfinished"></translation>
@@ -1101,11 +1137,15 @@ and capturing screenshot.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Saved to</source>
+        <source>Image Files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
+        <source>Saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1281,6 +1321,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1518,10 +1562,6 @@ Change requires restart.</source>
         <source>Tray Icon Settings</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation type="unfinished"></translation>
@@ -1531,6 +1571,10 @@ Change requires restart.</source>
 service when such exists. Change requires restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1539,11 +1583,7 @@ service when such exists. Change requires restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Files</source>
+        <source>Image Files</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1588,6 +1628,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
