@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ Valikon näkyvyyttä voidaan vaihtaa sarkaimella.</translation>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Muuttaa pääikkunan kokoa automaattisesti kuvaan sopivaksi.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Ota virheenkorjaus käyttöön</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Ottaa käyttöön konsoliin kirjoitettavan debug-listauksen.
+Muutos vaatii ksnipin käynnistyksen tullakseen voimaan.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Muuta kokoa sisällön viiveen mukaan</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Sisällön koon muuttaminen viivästyy, jotta Ikkunanhallinta voi vastaanottaa
+uutta sisältöä. Jos pääikkunaa ei ole säädetty oikein uuteen sisältöön,
+viiveen lisääminen saattaa parantaa toimintaa.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Haluatko tallentaa sen?</translation>
         <source>Community</source>
         <translation>Yhteisö</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Jos sinulla on kysymyksiä, ideoita tai haluat vain keskustella ksnipistä,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>liity meidän </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> palvelin.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Virheraportit</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Ole hyvä ja käytä </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Jos sinulla on kysymyksiä, ideoita tai haluat vain puhua ksnipistä,&lt;br/&gt;liity %1 tai %2-palvelimelle.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> raportoi virheistä.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Ilmoita virheistä %1 toiminnolla.</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Haluatko jatkaa?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>täällä</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Mahdollista myös, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Lahjoitukset ovat aina tervetulleita</translation>
@@ -443,16 +446,20 @@ Haluatko jatkaa?</translation>
         <translation>Lahjoitus</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Ryhdy GitHub-sponsoriksi</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip on voittoa tavoittelematon ohjelmaisto projekti. &lt;br/&gt;Silti joitakin kustannuksia on katettava,&lt;br/&gt; kuten verkkotunnus ja laitteistokulua alustojen välisen tuen testaamisesi.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip on voittoa tavoittelematon ohjelmaisto projekti. &lt;br/&gt;Silti joitakin kustannuksia on katettava,&lt;br/&gt; kuten verkkotunnus ja laitteistokulu alustojen välisen tuen testaamisesi.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Jos haluat auttaa tai vain arvostaa tehtyä työtä&lt;br/&gt; tarjoamalla kehittäjille oluen tai kahvin, voit tehdä sen %1 täällä %2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Jos haluat auttaa tai&lt;br/&gt;vain arvostaa tehtyä työtä,&lt;br/&gt;voit tehdä sen tarjoamalla kehittäjille oluen tai kahvin</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Ryhdy GitHub-sponsoriksi?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Mahdollista myös, %1 täällä %2.</translation>
     </message>
 </context>
 <context>
@@ -493,24 +500,35 @@ Haluatko jatkaa?</translation>
         <translation>Ruudunkaappaus portaali</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Pakota anonyymi lataus.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Url</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Käyttäjätunnus</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Salasana</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP-lataaja</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Lataaminen onnistui</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Lataamisen skripti </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> valmistunut onnistuneesti.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Ladattu kohteeseen</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Väliaikaista kuvaa ei voi tallentaa lähetettäväksi.</translation>
@@ -539,10 +557,6 @@ Haluatko jatkaa?</translation>
         <source>Web error, check console output.</source>
         <translation>Verkkovirhe, tarkista konsolin tulos.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Tuntematon prosessivirhe.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Lataaminen epäonnistui</translation>
@@ -551,6 +565,30 @@ Haluatko jatkaa?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>Skriptin kirjoitti StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>FTP-lataus päättyi onnistuneesti.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Tuntematon virhe.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Yhteysvirhe.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Käyttöoikeusvirhe.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>Scriptin %1  lataus päättyi onnistuneesti.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Ladattu %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ kaappauksissa.</translation>
         <source>Image Grabber</source>
         <translation>Kuvan kaappaaja</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Pakota Wayland ruudunkaappaus</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Skaalaa Wayland ruudunkaappaukset</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Näytä pääikkuna kaappauksen ottamisen jälkeen kun
 pääikkuna oli piilotettu tai minimoitu.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Pakota Wayland (xdg-desktop-portal) ruudunkaappaus</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Skaalaa Wayland (xdg-desktop-portal) ruudunkaappaus</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -812,6 +850,7 @@ ottamisen välillä.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -909,10 +948,6 @@ ottamisen välillä.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Ohje</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Kuvatiedostot (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Lisää vesileima</translation>
@@ -1017,6 +1052,14 @@ ottamisen välillä.</translation>
         <source>Rotate Image</source>
         <translation>Pyöritä kuvaa</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Toimet</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Kuvatiedostot</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ ottamisen välillä.</translation>
         <source>Image Renamed</source>
         <translation>Kuva nimetty</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Kuvan nimeäminen uudelleen onnistui </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Kuvan nimeäminen epäonnistui</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Kuvan nimeäminen uudelleen epäonnistui </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Nimeä kuva uudelleen</translation>
@@ -1104,6 +1139,14 @@ ottamisen välillä.</translation>
         <source>New filename:</source>
         <translation>Uusi tiedostonimi:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Kuvan nimi muutettiin onnistuneesti muotoon %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Kuvan nimeäminen muotoon %1 epäonnistui</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ ottamisen välillä.</translation>
         <source>Save As</source>
         <translation>Tallenna nimellä</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Kuvat</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Kaikki tiedostot</translation>
@@ -1128,12 +1167,16 @@ ottamisen välillä.</translation>
         <translation>Kuvan tallentaminen epäonnistui</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Tallennettu kohteeseen</translation>
+        <source>Image Files</source>
+        <translation>Kuvatiedostot</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Kuvan tallennus epäonnistui kohteeseen</translation>
+        <source>Saved to %1</source>
+        <translation>Tallennettu %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Kuvan tallentaminen %1 epäonnistui</translation>
     </message>
 </context>
 <context>
@@ -1316,6 +1359,10 @@ Kun kaikki jätetään pois, kaikki kopioidaan.</translation>
         <source>Actions</source>
         <translation>Toimet</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP-lataaja</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1572,10 +1619,6 @@ Muutos vaatii käynnistämisen uudelleen.</translation>
         <source>Tray Icon Settings</source>
         <translation>Alavalikon kuvakkeen asetukset</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Näytä alavalikon kuvakkeen ilmoitukset</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Käytä alustakohtaista ilmoituspalvelua</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Kun asetus on käytössä, se yrittää käyttää alustakohtaista ilmoitusta,
 palvelua, jos sellainen on olemassa. Vaatii käynnistyksen uudelleen.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Näytä alavalikon kuvakkeen ilmoitukset</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,12 +1641,8 @@ palvelua, jos sellainen on olemassa. Vaatii käynnistyksen uudelleen.</translati
         <translation>Valitse kuva</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Kuvat</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Kaikki tiedostot</translation>
+        <source>Image Files</source>
+        <translation>Kuvatiedostot</translation>
     </message>
 </context>
 <context>
@@ -1643,6 +1686,10 @@ palvelua, jos sellainen on olemassa. Vaatii käynnistyksen uudelleen.</translati
         <source>Uploader</source>
         <translation>Lataaja</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
