@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ La visibilité du panneau d’outils peut être basculée avec la touche TAB.</t
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Redimensionner automatiquement la fenêtre principale pour l&apos;adapter à l&apos;image du contenu.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Activer le débogage</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Active la sortie de débogage écrite sur la console.
+Le changement nécessite le redémarrage de ksnip pour prendre effet.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Redimensionnement en fonction du retard du contenu</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Le redimensionnement du contenu est retardé pour permettre au gestionnaire de fenêtres de recevoir le nouveau contenu.
+le nouveau contenu. Dans le cas où la fenêtre principale n&apos;est pas ajustée correctement au nouveau contenu, l&apos;augmentation de ce délai peut améliorer le comportement.
+au nouveau contenu, l&apos;augmentation de ce délai peut améliorer le comportement.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Voulez-vous l&apos;enregistrer?</translation>
         <source>Community</source>
         <translation>Communauté</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Si vous avez des questions générales, des idées ou si vous voulez simplement parler de ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>veuillez rejoindre notre </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> serveur.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Signalements d&apos;erreurs</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Veuillez utiliser </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Si vous avez des questions générales, des idées ou si vous voulez simplement parler de ksnip,&lt;br/&gt;veuillez rejoindre notre %1 ou notre %2 serveur.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> pour signaler des erreurs.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Veuillez utiliser %1 pour signaler les bogues.</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Voulez-vous continuer?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>ici</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>C&apos;est par </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Les dons sont toujours les bienvenus</translation>
@@ -443,16 +446,20 @@ Voulez-vous continuer?</translation>
         <translation>Dons</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Devenir un Sponsor sur GitHub</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip est un projet de logiciel libre copylefté non rentable, et &lt;br/&gt;a toujours certains coûts qui doivent être couverts,&lt;br/&gt;comme les coûts de domaine ou les coûts de matériel pour la prise en charge multiplateforme.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip est un projet de logiciel libre, copyleft, sans but lucratif, &lt;br/&gt;et a quand même certains coûts, par exemple les coûts de domaine &lt;br/&gt;ou les coûts de matériel pour la prise en charge multiplateforme.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Si vous voulez aider ou simplement apprécier le travail accompli&lt;br/&gt;en offrant aux développeurs une bière ou un café, vous pouvez le faire %1here%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Si vous voulez aider, ou simplement &lt;br/&gt;être reconnaissant de ce travail&lt;br/&gt;, en payant aux développeurs une bière ou un café : c&apos;est possible</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Devenir un sponsor de GitHub?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Également possible, %1here%2.</translation>
     </message>
 </context>
 <context>
@@ -493,24 +500,35 @@ Voulez-vous continuer?</translation>
         <translation>Portail de capture d&apos;écran</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Forcer le téléversement anonyme.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Nom d&apos;utilisateur</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Mot de passe</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Téléverseur FTP</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Téléversement réussi</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Téléverser un script </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> terminé avec succès.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Téléversé vers</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Impossible de sauvegarder une image temporaire pour le téléversement.</translation>
@@ -539,10 +557,6 @@ Voulez-vous continuer?</translation>
         <source>Web error, check console output.</source>
         <translation>Erreur Web, vérifier la sortie de la console.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Erreur de traitement inconnue.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Échec de téléversement</translation>
@@ -551,6 +565,30 @@ Voulez-vous continuer?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>Le script a écrit sur StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>Le téléversement FTP s&apos;est terminé avec succès.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Erreur inconnue.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Erreur de connexion.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Erreur d&apos;autorisation.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>Le script de téléversement %1 s&apos;est terminé avec succès.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Téléversé sur %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ les captures d’écran.</translation>
         <source>Image Grabber</source>
         <translation>Captureur d&apos;image</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Captures Wayland Force Generic</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Captures Wayland Scale Generic</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Afficher la fenêtre principale après avoir créé une nouvelle capture d&apos;écran
 lorsque la fenêtre principale a été masquée ou réduite.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Capture d&apos;écran de Force Generic Wayland (xdg-desktop-portal)</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Captures d&apos;écran de Scale Generic Wayland (xdg-desktop-portal)</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -812,6 +850,7 @@ et la capture de l&apos;écran.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -909,10 +948,6 @@ et la capture de l&apos;écran.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Fichier d&apos;images (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Ajouter un filigrane</translation>
@@ -1017,6 +1052,14 @@ et la capture de l&apos;écran.</translation>
         <source>Rotate Image</source>
         <translation>Pivoter l&apos;image</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Actions</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Fichiers d&apos;images</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ et la capture de l&apos;écran.</translation>
         <source>Image Renamed</source>
         <translation>Image renommée</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Image renommée avec succès en </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Échec du renommage de l&apos;image</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Échec du renommage de l&apos;image en </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Renommer l&apos;image</translation>
@@ -1104,6 +1139,14 @@ et la capture de l&apos;écran.</translation>
         <source>New filename:</source>
         <translation>Nouveau nom de fichier :</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>L&apos;image a été renommée avec succès en %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Échec du renommage de l&apos;image en %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ et la capture de l&apos;écran.</translation>
         <source>Save As</source>
         <translation>Enregistrer sous</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Images</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Tous les fichiers</translation>
@@ -1128,12 +1167,16 @@ et la capture de l&apos;écran.</translation>
         <translation>Échec de la sauvegarde de l&apos;image</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Enregistré sous</translation>
+        <source>Image Files</source>
+        <translation>Fichiers d&apos;images</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Impossible de d’enregistrer l’image sous</translation>
+        <source>Saved to %1</source>
+        <translation>Enregistré dans %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Échec de la sauvegarde de l&apos;image dans %1</translation>
     </message>
 </context>
 <context>
@@ -1317,6 +1360,10 @@ copiées dans le presse-papier. Si aucun filtre n&apos;est défini, toutes les l
         <source>Actions</source>
         <translation>Actions</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Téléverseur FTP</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1572,10 +1619,6 @@ Le changement nécessite un redémarrage.</translation>
         <source>Tray Icon Settings</source>
         <translation>Paramètres de l’icône de la barre des tâches</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Afficher les notifications de l’icône de la barre d’outils</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Utiliser un service de notification spécifique à la plateforme</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Lorsque cette option est activée, elle essaiera d&apos;utiliser un service de notification spécifique à la plateforme lorsqu&apos;il existe.
 spécifique à la plateforme lorsqu&apos;il existe. Le changement nécessite un redémarrage pour prendre effet.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Afficher les notifications de l&apos;icône de la barre d&apos;état système</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,12 +1641,8 @@ spécifique à la plateforme lorsqu&apos;il existe. Le changement nécessite un
         <translation>Sélectionner l&apos;image</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Images</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Tous les fichiers</translation>
+        <source>Image Files</source>
+        <translation>Fichiers d&apos;images</translation>
     </message>
 </context>
 <context>
@@ -1643,6 +1686,10 @@ spécifique à la plateforme lorsqu&apos;il existe. Le changement nécessite un
         <source>Uploader</source>
         <translation>Envoi sur un serveur</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
