@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ Vidljivost ploča može se promijeniti pomoću tipke tabulatora.</translation>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Automatski prilagodi veličinu glavnog prozora veličini slike sadržaja.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Aktiviraj ispravljanje grešaka</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Aktivira rezultat ispravljanje grešaka ispisan u konzoli.
+Promjena zahtijeva ponovno pokretanje ksnip-a da bi stupilo na snagu.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Promijeni veličinu na kašnjenje sadržaja</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Mijenjanje veličine sadržaja je odgoda kako bi se upravljaču prozora omogućilo primanje
+novog sadržaja. U slučaju da glavni prozori nisu pravilno podešeni
+na novi sadržaj, povećanje ovog kašnjenja moglo bi poboljšati ponašanje.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation>Zajednica</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Ako imaš opća pitanja, ideje ili ako samo želiš razgovarati o ksnipu,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>pridruži se našem </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> serveru.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Prijave grešaka</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Koristi </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Ako imaš opća pitanja, ideje ili ako jednostavno želiš razgovarati o ksnipu,&lt;br/&gt;, pridruži se našem %1 ili našem %2 poslužitelju.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> za prijavljivanje grešaka.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Za prijavu grešaka koristi %1.</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>ovdje</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Također moguće, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Donacije su uvijek dobrodošle</translation>
@@ -443,16 +446,20 @@ Do you want to continue?</source>
         <translation>Donacija</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Postani GitHub sponzor</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip je neprofitabilan copyleft projekt slobodnog softvera i&lt;br/&gt;još uvijek ima neke troškove koje treba pokriti,&lt;br/&gt;poput troškova domene ili troškova hardvera za višeplatformsku podršku.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip je neprofitni projekt softvera otvorenog koda,&lt;br/&gt;ima troškove koje treba pokriti,&lt;br/&gt;poput troškova za domenu ili hardverskih troškova za podršku raznih platformi.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Ako želiš pomoći ili ako samo želiš cijeniti obavljeni posao&lt;br/&gt;slobodno počastiti programere pivom ili kavom %1ovdje%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Ako želiš pomoći ili ako se samo&lt;br/&gt;želiš zahvaliti&lt;br/&gt;, počasti programere pivom ili kavom. To možeš učiniti</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Želiš postati GitHub sponzor?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Također moguće %1ovdje%2.</translation>
     </message>
 </context>
 <context>
@@ -493,24 +500,35 @@ Do you want to continue?</source>
         <translation>Portal slika ekrana</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Prisili anoniman prijenos.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Korisničko ime</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Lozinka</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP prenositelj</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Prijenos je uspio</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Prenesi skripta </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> uspješno završeno.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Preneseno u</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Nije moguće spremiti privremenu sliku za prijenos.</translation>
@@ -539,10 +557,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation>Web-greška. Pregledaj rezultat u konzoli.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Nepoznata greška u postupku.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Prijenos nije uspio</translation>
@@ -551,6 +565,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation>Skripta je zapisala u standardnu grešku (StdErr).</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>FTP prijenos je uspješno završen.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Nepoznata greška.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Greška u vezi.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Greška u dozvoli.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>Prijenos skripta %1 uspješno završen.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Preneseno na %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ slikama ekrana.</translation>
         <source>Image Grabber</source>
         <translation>Snimanje slika</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Prisili generičku Wayland sliku ekrana</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Skaliraj generičke Wayland slike ekrana</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Prikaži glavni prozor nakon snimanja nove snimke ekrana
 kad je glavni prozor bio skriven ili smanjen.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Prisili generičku wayland (xdg-desktop-portal) snimku ekrana</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Promijeni veličinu generičke wayland (xdg-desktop-portal) snimke ekrana</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -812,6 +850,7 @@ okidanja i snimanja slike ekrana.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -909,10 +948,6 @@ okidanja i snimanja slike ekrana.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Pomoć</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Slikovne datoteke (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Dodaj vodeni žig</translation>
@@ -1017,6 +1052,14 @@ okidanja i snimanja slike ekrana.</translation>
         <source>Rotate Image</source>
         <translation>Okreni sliku</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Radnje</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Datoteke slika</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ okidanja i snimanja slike ekrana.</translation>
         <source>Image Renamed</source>
         <translation>Slika je preimenovana</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Slika je uspješno preimenovana u </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Neuspjelo preimenovanje slike</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Neuspjelo preimenovanje slike u </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Preimenuj sliku</translation>
@@ -1104,6 +1139,14 @@ okidanja i snimanja slike ekrana.</translation>
         <source>New filename:</source>
         <translation>Novo ime datoteke:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Slika uspješno preimenovana u %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Neuspjelo preimenovanje slike u %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ okidanja i snimanja slike ekrana.</translation>
         <source>Save As</source>
         <translation>Spremi kao</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Slike</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Sve datoteke</translation>
@@ -1128,12 +1167,16 @@ okidanja i snimanja slike ekrana.</translation>
         <translation>Spremanje slike neuspjelo</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Spremljeno u</translation>
+        <source>Image Files</source>
+        <translation>Datoteke slika</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Neuspjelo spremanje slike u</translation>
+        <source>Saved to %1</source>
+        <translation>Spremljeno u %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Neuspjelo spremanje slike u %1</translation>
     </message>
 </context>
 <context>
@@ -1317,6 +1360,10 @@ RegEx izrazom. Ako se izostavi, kopira se sve.</translation>
         <source>Actions</source>
         <translation>Radnje</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP prenositelj</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1571,10 +1618,6 @@ Promjena zahtijeva ponovno pokretanje programa.</translation>
         <source>Tray Icon Settings</source>
         <translation>Postavke ikone u programskoj traci</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Prikaži obavijesti u programskoj traci</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Koristi uslugu obavještavanja platforme</translation>
@@ -1585,6 +1628,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Kad je aktivirano, pokušat će koristiti uslugu obavještavanja platforme
 kad postoji. Zahtijeva ponovno pokretanje kako bi se promjena primijenila.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Prikaži obavijesti trake ikona</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1593,12 +1640,8 @@ kad postoji. Zahtijeva ponovno pokretanje kako bi se promjena primijenila.</tran
         <translation>Odaberi sliku</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Slike</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Sve datoteke</translation>
+        <source>Image Files</source>
+        <translation>Datoteke slika</translation>
     </message>
 </context>
 <context>
@@ -1642,6 +1685,10 @@ kad postoji. Zahtijeva ponovno pokretanje kako bi se promjena primijenila.</tran
         <source>Uploader</source>
         <translation>Prijenos</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
