@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>mp</translation>
     </message>
     <message>
@@ -265,6 +266,25 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -358,29 +378,17 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation type="unfinished">Kérlek használd </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation type="unfinished"> a hiba jelentéséhez.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -416,14 +424,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>ide</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Lehetséges </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Az adományokat mindig szívesen fogadjuk</translation>
@@ -433,15 +433,19 @@ Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
+        <source>Become a GitHub Sponsor?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -483,24 +487,35 @@ Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished">Felhasználónév</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation type="unfinished">Sikeres feltöltés</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation type="unfinished">Feltöltés ide</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation type="unfinished"></translation>
@@ -529,10 +544,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation type="unfinished"></translation>
@@ -541,6 +552,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -606,14 +641,6 @@ a képernyőképen.</translation>
         <source>Image Grabber</source>
         <translation>Képlopás</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -647,6 +674,14 @@ Change in this option require a ksnip restart.</source>
 when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -791,6 +826,7 @@ másodpercben megadva.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>mp</translation>
     </message>
     <message>
@@ -888,10 +924,6 @@ másodpercben megadva.</translation>
         <source>&amp;Help</source>
         <translation>Súgó</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Képfájlok (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Vízjel hozzáadása</translation>
@@ -996,6 +1028,14 @@ másodpercben megadva.</translation>
         <source>Rotate Image</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1063,18 +1103,10 @@ másodpercben megadva.</translation>
         <source>Image Renamed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation type="unfinished"></translation>
@@ -1083,6 +1115,14 @@ másodpercben megadva.</translation>
         <source>New filename:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1090,10 +1130,6 @@ másodpercben megadva.</translation>
         <source>Save As</source>
         <translation>Mentés másként</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Képek</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Minden fájl</translation>
@@ -1107,12 +1143,16 @@ másodpercben megadva.</translation>
         <translation>Kép mentése nem sikerült</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Mentés helye</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Kép mentése nem sikerült ide</translation>
+        <source>Saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1287,6 +1327,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1528,10 +1572,6 @@ A változtatás érvenyesítéséhez újra kell indítani a programot.</translat
         <source>Tray Icon Settings</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation type="unfinished"></translation>
@@ -1541,6 +1581,10 @@ A változtatás érvenyesítéséhez újra kell indítani a programot.</translat
 service when such exists. Change requires restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1549,12 +1593,8 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Kép kiválasztása</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Képek</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Minden fájl</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1598,6 +1638,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
