@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ La visibilità dei dock può essere attivata o disattivata con il tasto Tab.</tr
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Ridimensiona automaticamente la finestra principale per adattarla all&apos;immagine del contenuto.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Abilita il debug</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Abilita l&apos;output di debug scritto nella console.
+La modifica richiede il riavvio di ksnip per avere effetto.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Ridimensiona al ritardo del contenuto</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Il ridimensionamento al contenuto è un ritardo per consentire a Window Manager di ricevere
+il nuovo contenuto. Nel caso in cui la finestra principale non sia regolata correttamente
+al nuovo contenuto, aumentare questo ritardo potrebbe migliorare il comportamento.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Vuoi salvarla?</translation>
         <source>Community</source>
         <translation>Comunità</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Se hai domande generali, idee o vuoi semplicemente parlare di ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>per favore unisciti al nostro </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> server.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Segnalazioni di bug</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Si prega di utilizzare </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Se hai domande generali, idee o semplicemente vuoi parlare di ksnip,&lt;br/&gt;unisciti al nostro server %1 o %2.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> per segnalare bug.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Si prega di utilizzare %1 per segnalare gli errori.</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Vuoi continuare?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>qui</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Anche possibile, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Le donazioni sono sempre ben accette</translation>
@@ -443,16 +446,20 @@ Vuoi continuare?</translation>
         <translation>Donazione</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Diventa uno sponsor GitHub</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip è un progetto non redditizio di software libero con copyleft, e&lt;br/&gt;ha ancora alcuni costi che devono essere coperti,&lt;br/&gt;come i costi del dominio o i costi dell&apos;hardware per il supporto multipiattaforma.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip è un progetto software libero con copyleft no-profit e&lt;br/&gt;ha ancora alcuni costi che devono essere coperti,&lt;br/&gt;come i costi del dominio o i costi hardware per il supporto multipiattaforma.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Se vuoi aiutare o semplicemente apprezzare il lavoro che viene fatto&lt;br/&gt; offrendo agli sviluppatori una birra o un caffè, puoi farlo %1here%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Se vuoi aiutare o semplicemente&lt;br/&gt;apprezzi il lavoro svolto&lt;br/&gt;offri agli sviluppatori una birra o un caffè, puoi farlo</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Diventare uno sponsor di GitHub?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Anche possibile, %1here%2.</translation>
     </message>
 </context>
 <context>
@@ -493,24 +500,35 @@ Vuoi continuare?</translation>
         <translation>Portale schermate</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Forza il caricamento anonimo.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Nome utente</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Password</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Uploader FTP</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Il caricamento è andato a buon fine</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Carica script </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> terminato con successo.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Caricato su</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Impossibile salvare l&apos;immagine temporanea per il caricamento.</translation>
@@ -539,10 +557,6 @@ Vuoi continuare?</translation>
         <source>Web error, check console output.</source>
         <translation>Errore Web, controlla l&apos;output della console.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Errore di processo sconosciuto.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Caricamento fallito</translation>
@@ -551,6 +565,30 @@ Vuoi continuare?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>Lo script ha scritto su StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>Caricamento FTP terminato con successo.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Errore sconosciuto.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Errore di connessione.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Errore di autorizzazione.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>Caricamento dello script %1 terminato con successo.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Caricato su %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ screenshot.</translation>
         <source>Image Grabber</source>
         <translation>Acquisizione di immagini</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Forza screenshot Wayland generico</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Ridimensiona gli screenshot generici di Wayland</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Mostra la finestra principale dopo aver catturato un nuovo screenshot
 quando la finestra principale era nascosta o ridotta a icona.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Schermata di Force Generic Wayland (xdg-desktop-portal)</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Schermate di Scale Generic Wayland (xdg-desktop-portal)</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -812,6 +850,7 @@ e cattura screenshot.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -925,10 +964,6 @@ e cattura screenshot.</translation>
         <source>&amp;Help</source>
         <translation>Aiuto</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>File immagine (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Save As...</source>
         <translation>Salva Come...</translation>
@@ -1017,6 +1052,14 @@ e cattura screenshot.</translation>
         <source>Rotate Image</source>
         <translation>Ruota immagine</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Azioni</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>File immagine</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ e cattura screenshot.</translation>
         <source>Image Renamed</source>
         <translation>Immagine rinominata</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Immagine rinominata con successo in </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Rinomina immagine non riuscita</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Impossibile rinominare l&apos;immagine in </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Rinomina immagine</translation>
@@ -1104,6 +1139,14 @@ e cattura screenshot.</translation>
         <source>New filename:</source>
         <translation>Nuovo nome file:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Immagine rinominata con successo in %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Impossibile rinominare l&apos;immagine in %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ e cattura screenshot.</translation>
         <source>Save As</source>
         <translation>Salva Come</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Immagini</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Tutti i FIle</translation>
@@ -1123,17 +1162,21 @@ e cattura screenshot.</translation>
         <source>Image Saved</source>
         <translation>Immagine Salvata</translation>
     </message>
-    <message>
-        <source>Saved to</source>
-        <translation>Salvato in</translation>
-    </message>
     <message>
         <source>Saving Image Failed</source>
         <translation>Salvataggio Immagine Fallito</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Salvataggio Immagine fallito in</translation>
+        <source>Image Files</source>
+        <translation>File immagine</translation>
+    </message>
+    <message>
+        <source>Saved to %1</source>
+        <translation>Salvato in %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Impossibile salvare l&apos;immagine in %1</translation>
     </message>
 </context>
 <context>
@@ -1316,6 +1359,10 @@ copiato negli appunti. Se non è definito alcun filtro, verranno copiate tutte l
         <source>Actions</source>
         <translation>Azioni</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Uploader FTP</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1572,10 +1619,6 @@ La modifica richiede il riavvio.</translation>
         <source>Tray Icon Settings</source>
         <translation>Impostazioni dell&apos;icona della barra delle applicazioni</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Mostra notifiche dall&apos;icona della barra degli strumenti</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Utilizza il servizio di notifica specifico della piattaforma</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Quando abilitato, proverà ad utilizzare la notifica specifica del servizio 
 della piattaforma quando questa esiste. La modifica richiede il riavvio per avere effetto.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Visualizza notifiche dell&apos;icona della barra delle applicazioni</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,12 +1641,8 @@ della piattaforma quando questa esiste. La modifica richiede il riavvio per aver
         <translation>Seleziona immagine</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Immagini</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Tutti i FIle</translation>
+        <source>Image Files</source>
+        <translation>File immagine</translation>
     </message>
 </context>
 <context>
@@ -1643,6 +1686,10 @@ della piattaforma quando questa esiste. La modifica richiede il riavvio per aver
         <source>Uploader</source>
         <translation>Caricamento</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
