@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation type="unfinished">秒</translation>
     </message>
     <message>
@@ -267,6 +268,25 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -361,29 +381,17 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation type="unfinished">バグ報告は </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation type="unfinished"> で受け付けています。</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -420,14 +428,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>こちらからお願いします</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>スポンサーになっていただける場合は </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>寄付はいつでも大歓迎です</translation>
@@ -437,16 +437,20 @@ Do you want to continue?</source>
         <translation>寄付</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>GitHub スポンサーになる</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip は非営利でコピーレフトの自由なソフトウェアプロジェクトですが、&lt;br/&gt;ドメインやクロスプラットフォームのサポートのためのハードウェアなどに&lt;br/&gt;費用がかかっています。</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>開発者をビールやコーヒーで支援していただける場合は</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -487,24 +491,35 @@ Do you want to continue?</source>
         <translation type="unfinished">Screenshot Portal</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished">ユーザー名</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>アップロードに成功しました</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>アップロードスクリプト </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> が正常に終了しました。</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>アップロード先:</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>アップロードするための一時画像を保存できません。</translation>
@@ -533,10 +548,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation>ウェブのエラーです。コンソールの出力を確認してください。</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>プロセスの不明なエラーです。</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>アップロードに失敗しました</translation>
@@ -545,6 +556,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation>スクリプトが StdErr に書き込みました。</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -610,14 +645,6 @@ screenshots.</source>
         <source>Image Grabber</source>
         <translation>画像取得</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -651,6 +678,14 @@ Change in this option require a ksnip restart.</source>
 when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -796,6 +831,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>秒</translation>
     </message>
     <message>
@@ -909,10 +945,6 @@ and capturing screenshot.</source>
         <source>&amp;Help</source>
         <translation>ヘルプ(&amp;H)</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>画像ファイル (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Save As...</source>
         <translation>名前を付けて保存...</translation>
@@ -1001,6 +1033,14 @@ and capturing screenshot.</source>
         <source>Rotate Image</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1068,18 +1108,10 @@ and capturing screenshot.</source>
         <source>Image Renamed</source>
         <translation>画像の名前を変更しました</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>次の名前に変更しました: </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>画像の名前を変更できませんでした</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>次の名前に変更できませんでした: </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>画像の名前を変更</translation>
@@ -1088,6 +1120,14 @@ and capturing screenshot.</source>
         <source>New filename:</source>
         <translation>新しいファイル名:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1095,10 +1135,6 @@ and capturing screenshot.</source>
         <source>Save As</source>
         <translation>名前を付けて保存</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>画像</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>すべてのファイル</translation>
@@ -1107,17 +1143,21 @@ and capturing screenshot.</source>
         <source>Image Saved</source>
         <translation>画像を保存しました</translation>
     </message>
-    <message>
-        <source>Saved to</source>
-        <translation>保存先:</translation>
-    </message>
     <message>
         <source>Saving Image Failed</source>
         <translation>画像の保存に失敗しました</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>失敗した保存先:</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1300,6 +1340,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1547,10 +1591,6 @@ Change requires restart.</source>
         <source>Tray Icon Settings</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation type="unfinished"></translation>
@@ -1560,6 +1600,10 @@ Change requires restart.</source>
 service when such exists. Change requires restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1568,12 +1612,8 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>画像を選択</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>画像</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>すべてのファイル</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1617,6 +1657,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation>アップローダー</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
