@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ Ze kunnen dan worden getoond/verborgen met de Tab-toets.</translation>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Pas de afmetingen van het hoofdvenster automatisch aan aan de schermfoto.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Foutopsporing inschakelen</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Schrijft foutopsporingsinformatie weg naar een terminalvenster.
+Herstart ksnip om de wijziging toe te passen.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Wachttijd alvorens te herschalen naar inhoud</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>De wachttijd omtrent herschalen naar inhoud geldt voor de vensterbeheerder.
+Als het hoofdvenster niet goed wordt aangepast aan de nieuwe inhoud,
+dan kan deze wachttijd het gedrag verbeteren.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Wil je deze opslaan?</translation>
         <source>Community</source>
         <translation>Gemeenschap</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Als je algemene vragen of ideeën hebt of gewoon even wilt praten over ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>breng dan eens een bezoekje aan onze </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> server.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Bugmeldingen</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Gebruik </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Als je vragen hebt, ideeën wilt delen of gewoon even een praatje wilt maken, &lt;br/&gt;neem dan deel aan onze %1- of %2-server.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> om bugs te melden.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Meld bugs op %1.</translation>
     </message>
 </context>
 <context>
@@ -420,20 +431,12 @@ Wil je deze opslaan?</translation>
     <message>
         <source>The item &apos;%1&apos; will be deleted.
 Do you want to continue?</source>
-        <translation>&apos;%1&apos; wordt verwijderd.
+        <translation>‘%1’ wordt verwijderd.
 Weet je zeker dat je wilt doorgaan?</translation>
     </message>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>hier</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Je kunt ook </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Donaties zijn altijd welkom</translation>
@@ -443,23 +446,27 @@ Weet je zeker dat je wilt doorgaan?</translation>
         <translation>Doneren</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>GitHub-sponsor worden</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip is een vrij softwareproject zonder winstoogmerk. Er zijn echter&lt;br/&gt;kosten die moeten worden gedekt,&lt;br/&gt;zoals domeinnaamkosten en hardware voor platform-onafhankelijke ondersteuning.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip is een vrijesoftwareproject zonder winstoogmerk, maar&lt;br/&gt;maakt desondanks kosten,&lt;br/&gt;zoals domeinnaam- en hardwarekosten (voor platform-onafhankelijke ondersteuning).</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Als je wilt helpen of je waardering wilt tonen&lt;br/&gt;door de ontwikkelaars te trakteren op een biertje of kopje koffie, dan kan dat via %1deze pagina%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Als je wilt helpen of gewoon&lt;br/&gt;je waardering voor ons harde werk wilt tonen,&lt;br/&gt;dan kun je ons trakteren op een biertje of kopje koffie</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>GitHub-sponsor worden?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Dat kan ook, namelijk via %1deze pagina%2.</translation>
     </message>
 </context>
 <context>
     <name>EmptyActionSettingTab</name>
     <message>
         <source>Add new actions by pressing the &apos;Add&apos; tab button.</source>
-        <translation>Voeg nieuwe acties toe door de knop &apos;Toevoegen&apos; aan te klikken.</translation>
+        <translation>Voeg nieuwe acties toe door de knop ‘Toevoegen’ aan te klikken.</translation>
     </message>
 </context>
 <context>
@@ -493,31 +500,42 @@ Weet je zeker dat je wilt doorgaan?</translation>
         <translation>Schermfotoportaal</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Dwing anoniem uploaden af.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Gebruikersnaam</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Wachtwoord</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP-upload</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Schermfoto geüpload</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Het uploadscript </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> is uitgevoerd.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Geüpload naar</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>De tijdelijke schermfoto, nodig voor het uploaden, kan niet worden opgeslagen.</translation>
     </message>
     <message>
         <source>Unable to start process, check path and permissions.</source>
-        <translation>Het proces kan niet worden gestart. Controleer het pad en de toegangsrechten.</translation>
+        <translation>Het proces kan niet worden gestart. Controleer de locatie en toegangsrechten.</translation>
     </message>
     <message>
         <source>Process crashed</source>
@@ -539,10 +557,6 @@ Weet je zeker dat je wilt doorgaan?</translation>
         <source>Web error, check console output.</source>
         <translation>Netwerkfout. Controleer de opdrachtvensteruitvoer.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Onbekende procesfout.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Uploaden mislukt</translation>
@@ -551,6 +565,30 @@ Weet je zeker dat je wilt doorgaan?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>Het script is weggeschreven naar StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>De ftp-upload is afgerond.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Onbekende fout.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Verbindingsfout.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Rechtenfout.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>‘%1’ is uitgevoerd.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Geüpload naar %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ schermfoto&apos;s.</translation>
         <source>Image Grabber</source>
         <translation>Vastleggen</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Algemene Wayland-schermfoto afdwingen</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Grootte van algemene Wayland-schermfoto&apos;s aanpassen</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Toon het hoofdvenster na het maken van een schermfoto als
 het hoofdvenster verborgen of geminimaliseerd is.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Algemene Wayland (xdg-desktop-portal)-schermfoto afdwingen</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Algemene Wayland (xdg-desktop-portal)-schermfoto&apos;s schalen</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -795,7 +833,7 @@ Herstart om de wijzigingen toe te passen.</translation>
     </message>
     <message>
         <source>Unable to open image from path %1</source>
-        <translation>De schermfoto uit het pad &apos;%1&apos; kan niet worden geopend</translation>
+        <translation>De schermfoto uit ‘%1’ kan niet worden geopend</translation>
     </message>
 </context>
 <context>
@@ -812,6 +850,7 @@ van een schermfoto, in seconden.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -909,10 +948,6 @@ van een schermfoto, in seconden.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Hulp</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Afbeeldingsbestanden (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Watermerk toevoegen</translation>
@@ -931,7 +966,7 @@ van een schermfoto, in seconden.</translation>
     </message>
     <message>
         <source>Save As...</source>
-        <translation>Opslaan als...</translation>
+        <translation>Opslaan als…</translation>
     </message>
     <message>
         <source>Paste</source>
@@ -955,7 +990,7 @@ van een schermfoto, in seconden.</translation>
     </message>
     <message>
         <source>Copy Path</source>
-        <translation>Pad kopiëren</translation>
+        <translation>Locatie kopiëren</translation>
     </message>
     <message>
         <source>Open Directory</source>
@@ -1017,6 +1052,14 @@ van een schermfoto, in seconden.</translation>
         <source>Rotate Image</source>
         <translation>Foto draaien</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Acties</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Afbeeldingsbestanden</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1038,7 +1081,7 @@ van een schermfoto, in seconden.</translation>
     </message>
     <message>
         <source>Copy Path</source>
-        <translation>Pad kopiëren</translation>
+        <translation>Locatie kopiëren</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -1084,18 +1127,10 @@ van een schermfoto, in seconden.</translation>
         <source>Image Renamed</source>
         <translation>De fotonaam is gewijzigd</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>De nieuwe fotonaam is </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Naamswijziging mislukt</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>De fotonaam kan niet worden gewijzigd in </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Fotonaam wijzigen</translation>
@@ -1104,6 +1139,14 @@ van een schermfoto, in seconden.</translation>
         <source>New filename:</source>
         <translation>Nieuwe bestandsnaam:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>De afbeeldingsnaam is gewijzigd in ‘%1’</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>De naam van ‘%1’ kan niet worden gewijzigd</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ van een schermfoto, in seconden.</translation>
         <source>Save As</source>
         <translation>Opslaan als</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Schermfoto&apos;s</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Alle bestanden</translation>
@@ -1128,19 +1167,23 @@ van een schermfoto, in seconden.</translation>
         <translation>Kan schermfoto niet opslaan</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Opgeslagen in</translation>
+        <source>Image Files</source>
+        <translation>Afbeeldingsbestanden</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Kan schermfoto niet opslaan in</translation>
+        <source>Saved to %1</source>
+        <translation>Opgeslagen in %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>De afbeelding kan niet worden opgeslagen in %1</translation>
     </message>
 </context>
 <context>
     <name>SaverSettings</name>
     <message>
         <source>Automatically save new captures to default location</source>
-        <translation>Nieuwe schermfoto&apos;s automatisch opslaan in standaardlocatie</translation>
+        <translation>Nieuwe schermfoto&apos;s automatisch opslaan op standaardlocatie</translation>
     </message>
     <message>
         <source>Prompt to save before discarding unsaved changes</source>
@@ -1167,7 +1210,7 @@ Filename can contain following wildcards:
 - Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
         <translation>Ondersteunde bestandsformaten: JPG, PNG en BMP. Als je geen formaat opgeeft, dan wordt PNG gebruikt.
 De bestandsnaam mag de volgende jokertekens bevatten:
-- $Y, $M, $D voor datum, $h, $m, $s voor tijd, of $T voor tijd in de opmaak &apos;uummss&apos;.
+- $Y, $M, $D voor datum, $h, $m, $s voor tijd, of $T voor tijd in de opmaak ‘uummss’.
 - Gebruik # voor optelling. Voorbeeld: #### geeft 0001, met als opvolger 0002.</translation>
     </message>
     <message>
@@ -1214,8 +1257,8 @@ hoge compressie. Niet alle formaten ondersteunen det volledige bereik, maar jpeg
     <message>
         <source>Path to script that will be called for uploading. During upload the script will be called
 with the path to a temporary png file as a single argument.</source>
-        <translation>Pad naar het script dat moet worden gebruikt bij het uploaden. Tijdens het uploaden
-wordt dit script aangeroepen op het pad van de tijdelijke png.</translation>
+        <translation>Locatie van het script dat moet worden gebruikt bij het uploaden. Tijdens het uploaden
+wordt dit script aangeroepen op de locatie van de tijdelijke png.</translation>
     </message>
     <message>
         <source>Browse</source>
@@ -1236,7 +1279,7 @@ wordt dit script aangeroepen op het pad van de tijdelijke png.</translation>
     <message>
         <source>Marks the upload as failed when script writes to StdErr.
 Without this setting errors in the script will be unnoticed.</source>
-        <translation>Markeert de upload als &apos;mislukt&apos; als het script wordt weggeschreven naar StdErr.
+        <translation>Markeert de upload als ‘mislukt’ als het script wordt weggeschreven naar StdErr.
 Schakel uit om scriptfouten te negeren.</translation>
     </message>
     <message>
@@ -1316,6 +1359,10 @@ Sla over om álles te kopiëren.</translation>
         <source>Actions</source>
         <translation>Acties</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP-upload</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1401,7 +1448,7 @@ the background image. This option only works
 with &apos;Freeze Image while snipping&apos; enabled.</source>
         <translation>Toont een vergrootglas om in te zoomen op de
 achtergrondafbeelding. Deze optie werkt alleen als
-&apos;Schermfoto bevriezen tijdens vastleggen&apos; is ingeschakeld.</translation>
+‘Schermfoto bevriezen tijdens vastleggen’ is ingeschakeld.</translation>
     </message>
     <message>
         <source>Show Snipping Area rulers</source>
@@ -1572,10 +1619,6 @@ Herstart om de wijziging toe te passen.</translation>
         <source>Tray Icon Settings</source>
         <translation>Systeemvakinstellingen</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Systeemvakmeldingen tonen</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Systeemmeldingen tonen</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Schakel in om, indien mogelijk, systeemmeldingen te tonen.
 Herstart KSnip om de wijziging toe te passen.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Systeemvakmeldingen tonen</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,12 +1641,8 @@ Herstart KSnip om de wijziging toe te passen.</translation>
         <translation>Foto kiezen</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Afbeeldingen</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Alle bestanden</translation>
+        <source>Image Files</source>
+        <translation>Afbeeldingsbestanden</translation>
     </message>
 </context>
 <context>
@@ -1643,6 +1686,10 @@ Herstart KSnip om de wijziging toe te passen.</translation>
         <source>Uploader</source>
         <translation>Uploader</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
