@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation type="unfinished">s</translation>
     </message>
     <message>
@@ -265,6 +266,25 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -358,29 +378,17 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation type="unfinished">Bruk </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation type="unfinished"> for å innrapportere feil.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -421,29 +429,25 @@ Do you want to continue?</source>
         <source>Donation</source>
         <translation>Donasjon</translation>
     </message>
-    <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Bli en GitHub-sponsor</translation>
-    </message>
-    <message>
-        <source>here</source>
-        <translation>her</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Også mulig, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Donasjoner er alltid velkomne</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip er et ikke-profitabelt ;) gemenhetslig fritt programvareprosjekt, som &lt;br/&gt;likevel har kostnader som må dekkes,&lt;br/&gt;som domene- eller maskinvarekostnader for multiplattformsstøtte.</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Hvis du ønsker å hjelpe, eller bare&lt;br/&gt;vil verdsette arbeidet som gjøres&lt;br/&gt;ved å spandere øl eller kaffe på utviklerne, kan du gjøre dette</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Become a GitHub Sponsor?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -484,24 +488,35 @@ Do you want to continue?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished">Brukernavn</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Opplastet</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Last opp skript </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation type="unfinished">Opplastet til</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation type="unfinished"></translation>
@@ -530,10 +545,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation type="unfinished"></translation>
@@ -542,6 +553,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -607,14 +642,6 @@ skjermavbildninger.</translation>
         <source>Image Grabber</source>
         <translation type="unfinished">Bildehenter</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -648,6 +675,14 @@ Change in this option require a ksnip restart.</source>
 when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -792,6 +827,7 @@ og avbildning av skjerm.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -889,10 +925,6 @@ og avbildning av skjerm.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Hjelp</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Bildefiler (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Legg til vannmerke</translation>
@@ -997,6 +1029,14 @@ og avbildning av skjerm.</translation>
         <source>Rotate Image</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1064,18 +1104,10 @@ og avbildning av skjerm.</translation>
         <source>Image Renamed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Gi bilde nytt navn</translation>
@@ -1084,6 +1116,14 @@ og avbildning av skjerm.</translation>
         <source>New filename:</source>
         <translation>Nytt filnavn:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1091,10 +1131,6 @@ og avbildning av skjerm.</translation>
         <source>Save As</source>
         <translation type="unfinished">Lagre som</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation type="unfinished">Bilder</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation type="unfinished">Alle filer</translation>
@@ -1108,12 +1144,16 @@ og avbildning av skjerm.</translation>
         <translation type="unfinished">Kunne ikke lagre bilde</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Lagret i</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Klarte ikke å lagre bilde i</translation>
+        <source>Saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1288,6 +1328,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1528,10 +1572,6 @@ Change requires restart.</source>
         <source>Tray Icon Settings</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation type="unfinished"></translation>
@@ -1541,6 +1581,10 @@ Change requires restart.</source>
 service when such exists. Change requires restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1549,12 +1593,8 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Velg bilde</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation type="unfinished">Bilder</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation type="unfinished">Alle filer</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1598,6 +1638,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation>Opplaster</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
