@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ Widoczność doków można przełączać za pomocą klawisza Tab.</translation>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Automatyczna zmiana rozmiaru okna głównego w celu dopasowania do zawartości obrazu.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Włącz debugowanie</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Włącza debugowanie danych wyjściowych zapisanych w konsoli.
+Zmiana wymaga ponownego uruchomienia ksnip.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Zmiana rozmiaru do opóźnienia zawartości</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Zmiana rozmiaru zawartości jest opóźnione, aby umożliwić menedżerowi okien odebranie
+nowej zawartości. W przypadku, gdy główne okno nie jest poprawnie dostosowane
+do nowej zawartości, zwiększenie tego opóźnienia może poprawić zachowanie.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Chcesz go zapisać?</translation>
         <source>Community</source>
         <translation>Społeczność</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Jeśli masz ogólne pytania, pomysły lub po prostu chcesz porozmawiać o ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>dołącz do nas na </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> server.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Zgłaszanie błędów</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Użyj </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Jeśli masz ogólne pytania, pomysły lub po prostu chcesz porozmawiać o ksnip,&lt;br/&gt;dołącz do naszego serwera %1 lub %2.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> do raportowania błędów.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Użyj %1, aby zgłosić błędy.</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Czy chcesz kontynuować?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>tutaj</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Możesz także, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Darowizny są zawsze mile widziane</translation>
@@ -443,16 +446,20 @@ Czy chcesz kontynuować?</translation>
         <translation>Wspomóż</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Zostań Sponsorem GitHub</translation>
-    </message>
-    <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
         <translation>ksnip jest niedochodowym projektem wolnego oprogramowania objętego licencją typu copylefted &lt;br/&gt; i nadal ma pewne koszty, które trzeba pokryć, takie jak koszty domeny lub koszty sprzętu&lt;br/&gt; do obsługi wielu platform.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Jeśli chcesz pomóc lub chcesz docenić wykonywaną pracę&lt;br/&gt; polegającą na poczęstowaniu programistów piwem lub kawą, możesz to zrobić</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Jeśli chcesz pomóc lub po prostu chcesz docenić wykonywaną pracę&lt;br/&gt;, częstując programistów piwem lub kawą, możesz to zrobić %1tutaj%2.</translation>
+    </message>
+    <message>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Czy możesz być sponsorem GitHub?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Możliwe również, %1tutaj%2.</translation>
     </message>
 </context>
 <context>
@@ -493,24 +500,35 @@ Czy chcesz kontynuować?</translation>
         <translation>Portal zrzutu ekranu</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Wymuś anonimowe wysyłanie.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Adres URL</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Nazwa użytkownika</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Hasło</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Przesyłanie FTP</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Przesyłanie zakończone pomyślnie</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Prześlij skrypt </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> zakończone pomyślnie.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Przesłane do</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Nie można zapisać tymczasowego obrazu do przesłania.</translation>
@@ -539,10 +557,6 @@ Czy chcesz kontynuować?</translation>
         <source>Web error, check console output.</source>
         <translation>Błąd sieciowy, sprawdź dane wyjściowe konsoli.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Nieznany błąd procesu.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Przesyłanie nie powiodło się</translation>
@@ -551,6 +565,30 @@ Czy chcesz kontynuować?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>Skrypt wysłany do StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>Przesyłanie FTP zakończyło się pomyślnie.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Nieznany błąd.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Błąd połączenia.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Błąd uprawnień.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>Przesyłanie skryptu %1 zakończone pomyślnie.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Przesłano do %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ na zrzutach ekranu.</translation>
         <source>Image Grabber</source>
         <translation>Przechwyć obraz</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Wymuś rodzajowy zrzut ekranu Wayland</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Skaluj rodzajowy zrzut ekranu z Wayland</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -664,9 +694,17 @@ Zmiana tej opcji wymaga ponownego uruchomienia ksnip.</translation>
     <message>
         <source>Show Main Window after capturing a new screenshot
 when the Main Window was hidden or minimize.</source>
-        <translation>Pokaż Główne okno po zrobieniu nowego zrzutu ekranu
+        <translation>Pokaż okno główne po zrobieniu nowego zrzutu ekranu
 kiedy główne okno było ukryte lub zminimalizowane.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation type="unfinished">Zrzut ekranu Force Generic Wayland (xdg-desktop-portal)</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Skaluj ogólne zrzuty ekranu Wayland (xdg-desktop-portal)</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -812,6 +850,7 @@ i wykonaniem zrzutu ekranu.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -909,10 +948,6 @@ i wykonaniem zrzutu ekranu.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Pomoc</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Pliki obrazów (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Dodaj znak wodny</translation>
@@ -1017,6 +1052,14 @@ i wykonaniem zrzutu ekranu.</translation>
         <source>Rotate Image</source>
         <translation>Obróć obraz</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Działania</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Pliki obrazów</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ i wykonaniem zrzutu ekranu.</translation>
         <source>Image Renamed</source>
         <translation>Zmieniono nazwę obrazu</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Pomyślnie zmieniono nazwę obrazu na </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Zmiana nazwy obrazu nie powiodła się</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Nie udało się zmienić nazwy obrazu na </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Zmień nazwę obrazu</translation>
@@ -1104,6 +1139,14 @@ i wykonaniem zrzutu ekranu.</translation>
         <source>New filename:</source>
         <translation>Nowa nazwa pliku:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Pomyślnie zmieniono nazwę obrazu na %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Nie można zmienić nazwy obrazu na %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ i wykonaniem zrzutu ekranu.</translation>
         <source>Save As</source>
         <translation>Zapisz jako</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Obrazy</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Wszystkie Pliki</translation>
@@ -1128,12 +1167,16 @@ i wykonaniem zrzutu ekranu.</translation>
         <translation>Zapisywanie obrazu nie powiodło się</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Zapisano w</translation>
+        <source>Image Files</source>
+        <translation>Pliki obrazów</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Nie udało się zapisać obrazu w</translation>
+        <source>Saved to %1</source>
+        <translation>Zapisano w %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Nie udało się zapisać obrazu w %1</translation>
     </message>
 </context>
 <context>
@@ -1316,6 +1359,10 @@ W przypadku pominięcia wszystko jest kopiowane.</translation>
         <source>Actions</source>
         <translation>Działania</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Program do przesyłania FTP</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1572,10 +1619,6 @@ Zmiana wymaga ponownego uruchomienia.</translation>
         <source>Tray Icon Settings</source>
         <translation>Ustawienia ikony zasobnika</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Wyświetlaj powiadomienia o ikonach na pasku zadań</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Skorzystaj z usługi powiadomień specyficznej dla platformy</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Gdy włączone, będzie próbował używać powiadomień specyficznych dla platformy
 jeśli taka istnieje. Zmiana wymaga ponownego uruchomienia, aby zaczęła obowiązywać.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Wyświetl ikony powiadomień w zasobniku</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,12 +1641,8 @@ jeśli taka istnieje. Zmiana wymaga ponownego uruchomienia, aby zaczęła obowi
         <translation>Wybierz obraz</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Obrazy</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Wszystkie Pliki</translation>
+        <source>Image Files</source>
+        <translation>Pliki obrazów</translation>
     </message>
 </context>
 <context>
@@ -1643,6 +1686,10 @@ jeśli taka istnieje. Zmiana wymaga ponownego uruchomienia, aby zaczęła obowi
         <source>Uploader</source>
         <translation>Przesyłanie</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
