@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ A visibilidade das Docks pode ser alternada com a tecla Tab.</translation>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Redimensionar automaticamente a janela principal para se ajustar a imagem.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Ativar depuração</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Ativa a saída de depuração gravada no console.
+A mudança requer o reinício do ksnip para ter efeito.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Atraso para redimensionar conteúdo</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Atraso para redimensionar conteúdo permite que o gestor de janelas receba 
+um novo conteúdo, caso a janela principal não esteja ajustada corretamente
+ ao novo conteúdo, aumentar esse atraso pode melhorar o comportamento.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Deseja salvá-la?</translation>
         <source>Community</source>
         <translation>Comunidade</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Se tiver questões gerais, ideias ou apenas desjea falar acerca do ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>por favor entre no nosso </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> servidor.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Registo de Problemas</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Por favor, utilize o </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Se tiver dúvidas gerais, idéias ou apenas quiser falar sobre o ksnip, &lt;br/&gt; por favor entre em nosso servidor% 1 ou% 2.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> para reportar problemas.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Por favor, use %1 para relatar bugs.</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Deseja continuar?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>aqui</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Também é possível, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Doações são sempre bem-vindas</translation>
@@ -443,16 +446,20 @@ Deseja continuar?</translation>
         <translation>Doação</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Torne-se um patrocinador do GitHub</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip é um projeto de software copyleft livre sem fins lucrativos e &lt;br/&gt; ainda tem alguns custos que precisam ser cobertos, &lt;br/&gt; como custos de domínio ou custos de hardware para suporte de plataforma cruzada.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>Ksnip é um projeto de software livre sem fins lucrativos com copyleft e &lt;br/&gt;ainda tem alguns custos que precisam ser cobertos,&lt;br/&gt;como custos de domínio ou custos de hardware para suporte multiplataforma.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Se quiser ajudar ou apenas apreciar o trabalho que está sendo feito &lt;br/&gt; oferecendo uma cerveja ou café aos programadores, pode fazer isso% 1aqui% 2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Se quiser ajudar ou apenas&lt;br/&gt;apreciar o trabalho que está a ser feito&lt;br/&gt;a oferecer uma cerveja ou café aos programadores, pode fazê-lo</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Tornar-se um patrocinador do GitHub?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Também é possível, %1aqui%2.</translation>
     </message>
 </context>
 <context>
@@ -493,24 +500,35 @@ Deseja continuar?</translation>
         <translation>Portal de captura do ecrã</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Forçar envio anônimo.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Url</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Nome de utilizador</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Palavra-passe</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Enviador FTP</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Upload bem sucedido</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Upload script </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> terminou com sucesso.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Upado para</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Não foi possível salvar a imagem temporária para upload.</translation>
@@ -539,10 +557,6 @@ Deseja continuar?</translation>
         <source>Web error, check console output.</source>
         <translation>Erro na Web, verifique a saída do console.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Erro desconhecido.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Falha no upload</translation>
@@ -551,6 +565,30 @@ Deseja continuar?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>Script escrito para StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>FTP Envio concluído com sucesso.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Erro desconhecido.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Erro de conexão.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Erro de permissão.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>O script de envio %1 foi concluído com sucesso.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Enviado para %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ capturas de ecrã.</translation>
         <source>Image Grabber</source>
         <translation>Captura de Imagem</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Forçar captura do ecrã genérico para Wayland</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Captura com escala genérica para Wayland</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Mostrar a Janela Principal após uma nova captura
 quando a Janela Principal foi escondida ou minimizada.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Forçar Wayland genérico (xdg-desktop-portal) capturar de ecrã</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Escalar Wayland genérico (xdg-desktop-portal) para capturas de ecrã</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -812,6 +850,7 @@ e captura de ecrã.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -909,10 +948,6 @@ e captura de ecrã.</translation>
         <source>&amp;Help</source>
         <translation>Aj&amp;uda</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Ficheiros de imagem (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Adicionar marca d&apos;água</translation>
@@ -1017,6 +1052,14 @@ e captura de ecrã.</translation>
         <source>Rotate Image</source>
         <translation>Rotacionar Imagem</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Ações</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Ficheiros de imagem</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ e captura de ecrã.</translation>
         <source>Image Renamed</source>
         <translation>Imagem Renomeada</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Imagem renomeada com sucesso </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Falhou ao renomear imagem</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Falhou ao renomear imagem para </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Renomear imagem</translation>
@@ -1104,6 +1139,14 @@ e captura de ecrã.</translation>
         <source>New filename:</source>
         <translation>Novo nome do ficheiro:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Imagem renomeada com sucesso para %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Falha ao mudar o nome da imagem para %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ e captura de ecrã.</translation>
         <source>Save As</source>
         <translation>Salvar como</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Imagens</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Todos os ficheiros</translation>
@@ -1128,12 +1167,16 @@ e captura de ecrã.</translation>
         <translation>Falha ao salvar imagem</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Salvo em</translation>
+        <source>Image Files</source>
+        <translation>Ficheiros de imagem</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Falha ao salvar a imagem em</translation>
+        <source>Saved to %1</source>
+        <translation>Salvo em %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Falha ao gravar a imagem em %1</translation>
     </message>
 </context>
 <context>
@@ -1316,6 +1359,10 @@ Quando omitido, tudo é copiado.</translation>
         <source>Actions</source>
         <translation>Ações</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Enviador de FTP</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1572,10 +1619,6 @@ A mudança requer reinicialização.</translation>
         <source>Tray Icon Settings</source>
         <translation>Configurações do ícone da bandeja</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Exibir notificações na bandeja</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Usar o serviço de notificação específico da plataforma</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Quando ativado, tentará usar o serviço de notificação específico da plataforma,
 quando tal existir. A mudança requer reinicialização para ter efeito.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Exibir notificações do ícone da bandeja</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,12 +1641,8 @@ quando tal existir. A mudança requer reinicialização para ter efeito.</transl
         <translation>Selecione uma imagem</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Imagens</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Todos os ficheiros</translation>
+        <source>Image Files</source>
+        <translation>Ficheiros de imagem</translation>
     </message>
 </context>
 <context>
@@ -1643,6 +1686,10 @@ quando tal existir. A mudança requer reinicialização para ter efeito.</transl
         <source>Uploader</source>
         <translation>Enviador</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
