@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -261,6 +262,25 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Redimensionează automat fereastra principală să se potrivească cu conținutul.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -355,29 +375,17 @@ Doriți să o salvați?</translation>
         <source>Community</source>
         <translation>Comunitate</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Dacă aveți întrebări generale, idei sau vreți doar să discutați despre ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>alăturați-vă </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> serverului nostru.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Rapoarte de defecte</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Folosiți </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> pentru a raporta erori.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -414,14 +422,6 @@ Doriți să continuați?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>aici</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Donațiile sunt binevenite mereu</translation>
@@ -431,15 +431,19 @@ Doriți să continuați?</translation>
         <translation>Donație</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Deveniți sponsor pe GitHub</translation>
-    </message>
-    <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Become a GitHub Sponsor?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -481,24 +485,35 @@ Doriți să continuați?</translation>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished">Utilizator</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Încărcare reușită</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Încărcat la</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation type="unfinished"></translation>
@@ -527,10 +542,6 @@ Doriți să continuați?</translation>
         <source>Web error, check console output.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Încărcarea a eșuat</translation>
@@ -539,6 +550,30 @@ Doriți să continuați?</translation>
         <source>Script wrote to StdErr.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -603,14 +638,6 @@ screenshots.</source>
         <source>Image Grabber</source>
         <translation>Acaparator de imagini</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -644,6 +671,14 @@ Change in this option require a ksnip restart.</source>
 when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -787,6 +822,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -884,10 +920,6 @@ and capturing screenshot.</source>
         <source>&amp;Help</source>
         <translation>&amp;Ajutor</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Fișiere cu imagini (*png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Adaugă filigran</translation>
@@ -992,6 +1024,14 @@ and capturing screenshot.</source>
         <source>Rotate Image</source>
         <translation>Rotește imaginea</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation type="unfinished">Acțiuni</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1059,18 +1099,10 @@ and capturing screenshot.</source>
         <source>Image Renamed</source>
         <translation>Imagine redenumită</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Redenumirea imaginii a eșuat</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Redenumește imaginea</translation>
@@ -1079,6 +1111,14 @@ and capturing screenshot.</source>
         <source>New filename:</source>
         <translation>Denumire nouă:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1086,10 +1126,6 @@ and capturing screenshot.</source>
         <source>Save As</source>
         <translation>Salvează ca</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Imagini</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Toate fișierele</translation>
@@ -1103,11 +1139,15 @@ and capturing screenshot.</source>
         <translation>Salvarea imaginii a eșuat</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Salvat în</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
+        <source>Saved to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1269,7 +1309,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Snipping Area</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Zona tăieturii</translation>
     </message>
     <message>
         <source>Tray Icon</source>
@@ -1283,6 +1323,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation>Acțiuni</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1522,10 +1566,6 @@ Modificarea necesită repornire.</translation>
         <source>Tray Icon Settings</source>
         <translation>Configurări pictogramă în tavă</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Afișează notificări în tava de sistem</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Folosește serviciu de notificare specific platformei</translation>
@@ -1536,6 +1576,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Când e activat, se va încerca folosirea serviciului de notificare specific
 platformei, dacă există. Modificarea necesită o repornire pentru a intra în vigoare.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1544,12 +1588,8 @@ platformei, dacă există. Modificarea necesită o repornire pentru a intra în
         <translation>Alege imaginea</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Imagini</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Toate fișierele</translation>
+        <source>Image Files</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1593,6 +1633,10 @@ platformei, dacă există. Modificarea necesită o repornire pentru a intra în
         <source>Uploader</source>
         <translation>Încărcător</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
