@@ -59,7 +59,7 @@
     </message>
     <message>
         <source>Take Capture</source>
-        <translation>Сделать снимок</translation>
+        <translation>Сделать снимок экрана</translation>
     </message>
     <message>
         <source>Include Cursor</source>
@@ -71,11 +71,12 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>с</translation>
     </message>
     <message>
         <source>Capture Mode</source>
-        <translation>Режим снимка</translation>
+        <translation>Режим снимка экрана</translation>
     </message>
     <message>
         <source>Show image in Pin Window</source>
@@ -87,7 +88,7 @@
     </message>
     <message>
         <source>Upload image</source>
-        <translation>Загрузить изображение</translation>
+        <translation>Выгрузить изображение на внешний ресурс</translation>
     </message>
     <message>
         <source>Open image parent directory</source>
@@ -125,7 +126,7 @@
     </message>
     <message>
         <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
-        <translation>Пожалуйста, добавьте изображение водяного знака через Опции &gt; Настройки &gt; Параметры рисования &gt; Установить водянной знак/логотип</translation>
+	<translation>Пожалуйста, добавьте изображение водяного знака через Опции &gt; Настройки &gt; Параметры рисования &gt; Установить водяной знак/логотип</translation>
     </message>
 </context>
 <context>
@@ -158,15 +159,15 @@ make them more smooth.</source>
     </message>
     <message>
         <source>Remember annotation tool selection and load on startup</source>
-        <translation>Запомните выбор инструмента аннотации и запустить при загрузке</translation>
+        <translation>Запомнить выбор инструмента аннотации и запустить его при загрузке</translation>
     </message>
     <message>
         <source>Switch to Select Tool after drawing Item</source>
-        <translation>Переключитесь на выбор инструмента после рисования элемента</translation>
+        <translation>Переключиться на выбор инструмента после рисования элемента</translation>
     </message>
     <message>
         <source>Number Tool Seed change updates all Number Items</source>
-        <translation>Изменение нумератора обновит все номерные элементы</translation>
+        <translation>Изменение нумератора обновит все нумерованные элементы</translation>
     </message>
     <message>
         <source>Disabling this option causes changes of the number tool
@@ -249,7 +250,7 @@ a new start of all instances.</source>
     </message>
     <message>
         <source>Remember Main Window position on move and load on startup</source>
-        <translation>Запомните положение главного окна при перемещении и восстановить при загрузке</translation>
+        <translation>Запомнить положение главного окна при перемещении и восстановить при загрузке</translation>
     </message>
     <message>
         <source>Auto hide Tabs</source>
@@ -262,7 +263,7 @@ a new start of all instances.</source>
     <message>
         <source>On startup hide Toolbar and Annotation Settings.
 Docks visibility can be toggled with the Tab Key.</source>
-        <translation>Скрывать панель инструментов и настройки аннтирования при запуске.
+	<translation>Скрывать панель инструментов и настройки аннотирования при запуске.
 Видимость панелей можно переключать клавишей Tab.</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Автоматически масштабировать главное окно под размер изображения в нём.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Включить отладку</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Включает вывод отладочной информации в консоль.
+Для применения необходим перезапуск ksnip.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Задержка перед масштабированием под содержимое</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Масштабирование под содержимое выполняется с задержкой, позволяя оконному менеджеру
+получить новое содержимое. Увеличение данной задержки может помочь, если главное окно
+автоматически масштабируется под содержимое некорректно.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -358,7 +381,7 @@ Do you want to save it?</source>
     </message>
     <message>
         <source>Uses the screenshot Portal for taking screenshot</source>
-        <translation>Использовать портал скриншота для снимков</translation>
+        <translation>Использовать screenshot Portal для снимков экрана</translation>
     </message>
 </context>
 <context>
@@ -367,29 +390,17 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation>Сообщество</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Если у вас есть общие вопросы, идеи, или вы просто хотите поговорить о ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>присоединяйтесь к нашему </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> серверу.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Сообщения об ошибках</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Пожалуйста, используйте </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Присоединяйтесь к нашим %1 или %2 серверам,&lt;br/&gt; если у вас есть вопросы, идеи, или просто хотите обсудить ksnip.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> для отправки ошибок.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Используйте, пожалуйста, %1 для сообщений об ошибках.</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>здесь</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Также возможно, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Пожертвования всегда приветствуются</translation>
@@ -443,16 +446,20 @@ Do you want to continue?</source>
         <translation>Пожертвование</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Стать спонсором на GitHub</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip&amp;nbsp;&amp;mdash; это некоммерческий проект с открытым исходным кодом, но&lt;br/&gt;проект всё равно требует покрытия некоторых затрат,&lt;br/&gt;таких как оплата домена или инструментов кросс-платформенной поддержки.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip - это некоммерческий проект с открытым исходным кодом, но&lt;br/&gt;проект требует расходов, которые необходимо покрывать,&lt;br/&gt; такие как затраты на домен или инструменты для кросс-платформенной поддержки.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Если вы хотите помочь или просто хотите оценить проделанную работу,&lt;br/&gt;угостив разработчиков пивом или кофе, можете сделать это %1здесь%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Если вы хотите помочь или просто&lt;br/&gt;отблагодарить за проделанную работу,&lt;br/&gt;угостив разработчиков пивом или кофе, вы можете это сделать</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Стать спонсором на GitHub?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Также можете, %1здесь%2.</translation>
     </message>
 </context>
 <context>
@@ -493,23 +500,34 @@ Do you want to continue?</source>
         <translation>Портал скриншота</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Анонимная выгрузка.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Адрес</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Имя пользователя</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Пароль</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Выгрузка на FTP</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
-        <translation>Успешно загружено</translation>
-    </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Скрипт выгрузки </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> успешно завершено.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Загружено на</translation>
+        <translation>Успешно выгружено</translation>
     </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
@@ -537,11 +555,7 @@ Do you want to continue?</source>
     </message>
     <message>
         <source>Web error, check console output.</source>
-        <translation>Ошибка веб, проверьте вывод консоли.</translation>
-    </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Неизвестная ошибка процесса.</translation>
+	<translation>Ошибка сети, проверьте вывод консоли.</translation>
     </message>
     <message>
         <source>Upload Failed</source>
@@ -551,6 +565,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation>Скрипт написал в стандартный вывод ошибок.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>Выгрузка на FTP-сервер успешно завершена.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Неизвестная ошибка.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Ошибка подключения.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Ошибка прав доступа.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>Скрипт выгрузки %1 завершился успешно.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Выгружено на %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -576,7 +614,7 @@ Do you want to continue?</source>
     </message>
     <message>
         <source>Capture Window under Cursor</source>
-        <translation>Снимок под курсором</translation>
+	<translation>Снимок окна под курсором мыши</translation>
     </message>
     <message>
         <source>Global HotKeys</source>
@@ -605,26 +643,18 @@ Disabling this option makes also the action shortcuts ksnip only.</source>
     <name>ImageGrabberSettings</name>
     <message>
         <source>Capture mouse cursor on screenshot</source>
-        <translation>Показывать курсор мыши во время снимка</translation>
+	<translation>Показывать курсор мыши на снимке экрана</translation>
     </message>
     <message>
         <source>Should mouse cursor be visible on
 screenshots.</source>
-        <translation>Отображать курсор мыши 
-во время снимка.</translation>
+        <translation>Должен ли быть виден курсор мыши
+во время снимка экрана.</translation>
     </message>
     <message>
         <source>Image Grabber</source>
         <translation>Настройки захвата</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Форсировать общие скриншоты Wayland</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Масштабировать общие скриншоты Wayland</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -643,15 +673,15 @@ and the Generic XDG-DESKTOP-PORTAL screenshots.
 Enabling this option will force KDE Plasma and
 GNOME to use the XDG-DESKTOP-PORTAL screenshots.
 Change in this option require a ksnip restart.</source>
-        <translation>GNOME и KDE Plasma поддерживают собственные 
-методы скриншотов Wayland через XDG-DESKTOP-PORTAL.
+        <translation>GNOME и KDE Plasma поддерживают собственные методы получения
+скриншотов в Wayland и базовый метод через XDG-DESKTOP-PORTAL.
 Включение этой опции заставит KDE Plasma и GNOME
-использовать метод XDG-DESKTOP-PORTAL.
+использовать базовый метод XDG-DESKTOP-PORTAL.
 Изменение этого параметра требует перезапуска ksnip.</translation>
     </message>
     <message>
         <source>Show Main Window after capturing screenshot</source>
-        <translation>Показать главное окно после захвата скриншота</translation>
+	<translation>Показать главное окно после выполнения снимка экрана</translation>
     </message>
     <message>
         <source>Hide Main Window during screenshot</source>
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Показать основное окно после выполенения снимка,
 если оно было скрыто или свёрнуто.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Использовать для получения скриншота в Wayland базовый метод (xdg-desktop-portal)</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Масштабировать скриншоты, полученные базовым методом Wayland (xdg-desktop-portal)</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -808,10 +846,11 @@ Changing requires restart.</source>
         <source>Delay in seconds between triggering
 and capturing screenshot.</source>
         <translation>Задержка в секундах перед тем,
-как будет сделан скриншот.</translation>
+как будет сделан снимок экрана.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>с</translation>
     </message>
     <message>
@@ -820,7 +859,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Save Screen Capture to file system</source>
-        <translation>Сохранить скриншот в файловой системе</translation>
+	<translation>Сохранить снимок экрана в файловой системе</translation>
     </message>
     <message>
         <source>Copy</source>
@@ -828,7 +867,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Copy Screen Capture to clipboard</source>
-        <translation>Копировать скриншот в буфер обмена</translation>
+	<translation>Копировать снимок экрана в буфер обмена</translation>
     </message>
     <message>
         <source>Tools</source>
@@ -848,7 +887,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Crop Screen Capture</source>
-        <translation>Обрезать снимок</translation>
+	<translation>Обрезать снимок экрана</translation>
     </message>
 </context>
 <context>
@@ -859,7 +898,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Upload</source>
-        <translation>Выгрузить</translation>
+        <translation>Выгрузить на внешний ресурс</translation>
     </message>
     <message>
         <source>Print</source>
@@ -909,13 +948,9 @@ and capturing screenshot.</source>
         <source>&amp;Help</source>
         <translation>&amp;Помощь</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Файлы изображений (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
-        <translation>Добавить водянной знак/логотип</translation>
+	<translation>Добавить водяной знак/логотип</translation>
     </message>
     <message>
         <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
@@ -947,7 +982,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Pin screenshot to foreground in frameless window</source>
-        <translation>Закрепить снимок на переднем плане в безрамочном окне</translation>
+	<translation>Закрепить снимок экрана на переднем плане в безрамочном окне</translation>
     </message>
     <message>
         <source>No image provided but one was expected.</source>
@@ -959,11 +994,11 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Open Directory</source>
-        <translation>Открыть расположение</translation>
+	<translation>Открыть папку с файлом</translation>
     </message>
     <message>
         <source>&amp;View</source>
-        <translation>Просмотр</translation>
+	<translation>&amp;Просмотр</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -991,7 +1026,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Open &amp;Recent</source>
-        <translation>Открыть последний файл</translation>
+	<translation>&amp;Последние файлы</translation>
     </message>
     <message>
         <source>Modify Canvas</source>
@@ -999,7 +1034,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Upload triggerCapture to external source</source>
-        <translation>Загрузить снимок во внешней сервис</translation>
+	<translation>Передать снимок экрана на внешний ресурс</translation>
     </message>
     <message>
         <source>Copy triggerCapture to system clipboard</source>
@@ -1017,6 +1052,14 @@ and capturing screenshot.</source>
         <source>Rotate Image</source>
         <translation>Повернуть изображение</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Действия</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Файлы изображений</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ and capturing screenshot.</source>
         <source>Image Renamed</source>
         <translation>Изображение переименовано</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Успешно переименованное изображение на </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Не удалось переименовать изображение</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Не удалось переименовать изображение в </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Переименовать изображение</translation>
@@ -1104,6 +1139,14 @@ and capturing screenshot.</source>
         <source>New filename:</source>
         <translation>Новое имя файла:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Изображение успешно переименовано в %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Не удалось переименовать изображение в %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ and capturing screenshot.</source>
         <source>Save As</source>
         <translation>Сохранить как</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Изображения</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Все файлы</translation>
@@ -1128,12 +1167,16 @@ and capturing screenshot.</source>
         <translation>Ошибка во время сохранения изображения</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Сохранить в</translation>
+        <source>Image Files</source>
+        <translation>Файлы изображений</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Ошибка во время сохранения изображения</translation>
+        <source>Saved to %1</source>
+        <translation>Сохранено в %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Не удалось сохранить изображение в %1</translation>
     </message>
 </context>
 <context>
@@ -1153,8 +1196,8 @@ and capturing screenshot.</source>
     <message>
         <source>When enabled will overwrite the save directory stored in settings
 with the latest save directory, for every save.</source>
-        <translation>При включении каждый раз будет перезаписываться папка 
-сохранения, указанная в настройках, на последнюю используемую.</translation>
+        <translation>При включении каждый раз будет перезаписываться путь 
+для сохранения, указанный в настройках, на последний используемый.</translation>
     </message>
     <message>
         <source>Capture save location and filename</source>
@@ -1214,8 +1257,8 @@ Not all image formats support the full range, JPEG does.</source>
     <message>
         <source>Path to script that will be called for uploading. During upload the script will be called
 with the path to a temporary png file as a single argument.</source>
-        <translation>Путь к скрипту, вызываемому для загрузки. В процессе загрузки скрипт будет вызван
-с путём к временному PNG-файлу в качестве единственного аргумента.</translation>
+        <translation>Путь к скрипту, вызываемому для выгрузки. В процессе выгрузки скрипт будет вызван
+с путём к временному PNG-файлу, в качестве единственного аргумента.</translation>
     </message>
     <message>
         <source>Browse</source>
@@ -1227,16 +1270,16 @@ with the path to a temporary png file as a single argument.</source>
     </message>
     <message>
         <source>Select Upload Script</source>
-        <translation>Выбрать скрипт загрузки</translation>
+        <translation>Выбрать скрипт выгрузки</translation>
     </message>
     <message>
         <source>Stop when upload script writes to StdErr</source>
-        <translation>Прерваться, если скрипт загрузки напишет в стандартный поток ошибок</translation>
+        <translation>Остановить, если скрипт выгрузки напишет в стандартный поток ошибок</translation>
     </message>
     <message>
         <source>Marks the upload as failed when script writes to StdErr.
 Without this setting errors in the script will be unnoticed.</source>
-        <translation>Отметит загрузку как неудачную, если скрипт напишет в стандартный поток ошибок.
+        <translation>Отметит выгрузку как неудачную, если скрипт напишет в стандартный поток ошибок.
 Без этой опции ошибки скрипта будут проигнорированы.</translation>
     </message>
     <message>
@@ -1278,7 +1321,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>Annotator</source>
-        <translation>Параметры аннотирования</translation>
+        <translation>Параметры рисования</translation>
     </message>
     <message>
         <source>HotKeys</source>
@@ -1316,6 +1359,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation>Действия</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP-загрузчик</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1382,11 +1429,11 @@ snipping area is shown and with the option disabled
 the delay happens after the snipping area is shown.
 This feature is always disabled for Wayland and always
 enabled for MacOs.</source>
-        <translation>При включении - блокирует фон от изменений
-в течении выделение прямоугольной области. 
-Также меняет поведение отложенных снимков 
-экрана, при включенной опции - задержка 
-включается перед отображением зоны 
+        <translation>При включении - блокирует задний фон от изменений
+в процессе выделения области захвата. 
+Также меняет поведение снимков экрана с задержкой, 
+при включенной опции - задержка
+включается до захвата области 
 выбора, при выключенной - после.
 Эта опция всегда отключена для Wayland
 и всегда включена для MacOs.</translation>
@@ -1518,7 +1565,7 @@ Smaller number is more transparent.</source>
     </message>
     <message>
         <source>Add Stickers</source>
-        <translation>Добавить наклейки</translation>
+	<translation>Добавить стикеры</translation>
     </message>
 </context>
 <context>
@@ -1572,10 +1619,6 @@ Change requires restart.</source>
         <source>Tray Icon Settings</source>
         <translation>Настройки значка в трее</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Отображать уведомления значка в трее</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Использовать системную службу уведомлений</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>При включении будет использоваться системная служба уведомлений,
 если таковая существует. Для изменения необходим перезапуск.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Отображать уведомления значка в системном лотке</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,27 +1641,23 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Выбрать изображение</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Изображения</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Все файлы</translation>
+        <source>Image Files</source>
+        <translation>Файлы изображений</translation>
     </message>
 </context>
 <context>
     <name>UploadOperation</name>
     <message>
         <source>Upload Script Required</source>
-        <translation>Необходим скрипт загрузки</translation>
+        <translation>Необходим скрипт выгрузки</translation>
     </message>
     <message>
         <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
-        <translation>Пожалуйста добавьте скрипт загрузки через Опции → Настройки → Скрипт загрузки</translation>
+        <translation>Пожалуйста добавьте скрипт выгрузки через Опции → Настройки → Выгрузка → Выгрузка через скрипт → Скрипт</translation>
     </message>
     <message>
         <source>Capture Upload</source>
-        <translation>Загрузка снимка</translation>
+        <translation>Выгрузка снимка экрана на внешний ресурс</translation>
     </message>
     <message>
         <source>You are about to upload the image to an external destination, do you want to proceed?</source>
@@ -1625,7 +1668,7 @@ service when such exists. Change requires restart to take effect.</source>
     <name>UploaderSettings</name>
     <message>
         <source>Ask for confirmation before uploading</source>
-        <translation>Запрашивать подтверждение перед загрузкой</translation>
+        <translation>Запрашивать подтверждение перед выгрузкой</translation>
     </message>
     <message>
         <source>Uploader Type:</source>
@@ -1641,7 +1684,11 @@ service when such exists. Change requires restart to take effect.</source>
     </message>
     <message>
         <source>Uploader</source>
-        <translation>Выгрузка</translation>
+        <translation>Выгрузка на внешний ресурс</translation>
+    </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
     </message>
 </context>
 <context>
