@@ -17,7 +17,7 @@
     </message>
     <message>
         <source>Author</source>
-        <translation type="unfinished"></translation>
+        <translation>කතෘ</translation>
     </message>
     <message>
         <source>Close</source>
@@ -29,7 +29,7 @@
     </message>
     <message>
         <source>Contact</source>
-        <translation type="unfinished"></translation>
+        <translation>සබඳතාව</translation>
     </message>
 </context>
 <context>
@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>තත්.</translation>
     </message>
     <message>
@@ -83,11 +84,11 @@
     </message>
     <message>
         <source>Copy image to Clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>පසුරුපුවරුවට අනුරුව පිටපත් කරන්න</translation>
     </message>
     <message>
         <source>Upload image</source>
-        <translation type="unfinished"></translation>
+        <translation>උඩුගත කරන්න</translation>
     </message>
     <message>
         <source>Open image parent directory</source>
@@ -95,7 +96,7 @@
     </message>
     <message>
         <source>Save image</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරුව සුරකින්න</translation>
     </message>
     <message>
         <source>Hide Main Window</source>
@@ -261,6 +262,25 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -298,7 +318,7 @@ Docks visibility can be toggled with the Tab Key.</source>
     </message>
     <message>
         <source>The Authors:</source>
-        <translation type="unfinished"></translation>
+        <translation>කතුවරු:</translation>
     </message>
 </context>
 <context>
@@ -354,28 +374,16 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation>ප්‍රජාව</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>ඔබට සාමාන්‍ය ප්‍රශ්න, අදහස් තිබේ නම් හෝ කේස්නිප් ගැන කතා කිරීමට අවශ්‍ය නම්,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>සම්බන්ධ වන්න </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> සේවාදායකය.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Please use </source>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> to report bugs.</source>
+        <source>Please use %1 to report bugs.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -383,11 +391,11 @@ Do you want to save it?</source>
     <name>CopyAsDataUriOperation</name>
     <message>
         <source>Failed to copy to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>පසුරුපුවරුවට පිටපත් වීමට අසමත් විය</translation>
     </message>
     <message>
         <source>Failed to copy to clipboard as base64 encoded image.</source>
-        <translation type="unfinished"></translation>
+        <translation>base64 ආකේතිත අනුරුවක් ලෙස පසුරුපුවරුවට පිටපත් වීමට අසමත් විය.</translation>
     </message>
     <message>
         <source>Copied to clipboard</source>
@@ -395,14 +403,14 @@ Do you want to save it?</source>
     </message>
     <message>
         <source>Copied to clipboard as base64 encoded image.</source>
-        <translation type="unfinished"></translation>
+        <translation>base64 ආකේතිත අනුරුවක් ලෙස පසුරුපුවරුවට පිටපත් විය.</translation>
     </message>
 </context>
 <context>
     <name>DeleteImageOperation</name>
     <message>
         <source>Delete Image</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරුව මකන්න</translation>
     </message>
     <message>
         <source>The item &apos;%1&apos; will be deleted.
@@ -412,14 +420,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>මෙතැන</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>පරිත්‍යාග සැමවිටම පිළිගනු ලැබේ</translation>
@@ -429,15 +429,19 @@ Do you want to continue?</source>
         <translation>පරිත්‍යාග</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>ගිට්හබ් අනුග්‍රාහකයෙකු වන්න</translation>
-    </message>
-    <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Become a GitHub Sponsor?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -452,15 +456,15 @@ Do you want to continue?</source>
     <name>EnumTranslator</name>
     <message>
         <source>Rectangular Area</source>
-        <translation type="unfinished"></translation>
+        <translation>සෘජුකෝණාස්‍ර ප්‍රදේශය</translation>
     </message>
     <message>
         <source>Last Rectangular Area</source>
-        <translation type="unfinished"></translation>
+        <translation>අන්තිම සෘජුකෝණාස්‍ර පෙදෙස</translation>
     </message>
     <message>
         <source>Full Screen (All Monitors)</source>
-        <translation type="unfinished"></translation>
+        <translation>පූර්ණ තිරය (සියළු දර්ශක)</translation>
     </message>
     <message>
         <source>Current Screen</source>
@@ -479,27 +483,38 @@ Do you want to continue?</source>
         <translation>තිරසේයා ද්වාරය</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>බලාත්මක නිර්නාමික උඩුගත කිරීම.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>ඒ.ස.නි.</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>පරිශීලක නාමය</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>මුරපදය</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>උඩුගත වීම සාර්ථකයි</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
-        <translation type="unfinished"></translation>
+        <translation>උඩුගත කිරීමට අනුරුව තාවකාලිකව සුරැකීමට නොහැකියි.</translation>
     </message>
     <message>
         <source>Unable to start process, check path and permissions.</source>
@@ -525,10 +540,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>උඩුගත වීම අසාර්ථකයි</translation>
@@ -537,6 +548,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>සම්බන්ධතාවයේ දෝෂයකි.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>අවසර දෝෂයකි.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>%1 වෙත උඩුගත විය</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -601,14 +636,6 @@ screenshots.</source>
         <source>Image Grabber</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -631,7 +658,7 @@ Change in this option require a ksnip restart.</source>
     </message>
     <message>
         <source>Hide Main Window during screenshot</source>
-        <translation type="unfinished"></translation>
+        <translation>තිරසේයාව අතරතුර ප්‍රධාන කවුළුව සඟවන්න</translation>
     </message>
     <message>
         <source>Hide Main Window when capturing a new screenshot.</source>
@@ -642,6 +669,14 @@ Change in this option require a ksnip restart.</source>
 when the Main Window was hidden or minimize.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -651,7 +686,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Close</source>
-        <translation type="unfinished">වසන්න</translation>
+        <translation>වසන්න</translation>
     </message>
     <message>
         <source>Time Stamp</source>
@@ -663,7 +698,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Delete Link</source>
-        <translation type="unfinished"></translation>
+        <translation>සබැඳිය මකන්න</translation>
     </message>
 </context>
 <context>
@@ -689,7 +724,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Always copy Imgur link to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>සැමවිටම Imgur සබැඳිය පසුරුපුවරුවට පිටපත් කරන්න</translation>
     </message>
     <message>
         <source>Client ID</source>
@@ -717,7 +752,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Imgur History</source>
-        <translation type="unfinished"></translation>
+        <translation>Imgur ඉතිහාසය</translation>
     </message>
     <message>
         <source>Imgur Uploader</source>
@@ -765,18 +800,18 @@ Changing requires restart.</source>
     <name>LoadImageFromFileOperation</name>
     <message>
         <source>Unable to open image</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරුව විවෘත කිරීමට නොහැකියි</translation>
     </message>
     <message>
         <source>Unable to open image from path %1</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 මාර්ගයෙන් අනුරුව විවෘත කිරීමට නොහැකියි</translation>
     </message>
 </context>
 <context>
     <name>MainToolBar</name>
     <message>
         <source>New</source>
-        <translation type="unfinished">නව</translation>
+        <translation>නව</translation>
     </message>
     <message>
         <source>Delay in seconds between triggering
@@ -785,7 +820,8 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>s</source>
-        <translation type="unfinished"></translation>
+        <extracomment>The small letter s stands for seconds.</extracomment>
+        <translation>තත්.</translation>
     </message>
     <message>
         <source>Save</source>
@@ -817,7 +853,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Crop</source>
-        <translation type="unfinished"></translation>
+        <translation>කප්පාදුව</translation>
     </message>
     <message>
         <source>Crop Screen Capture</source>
@@ -828,7 +864,7 @@ and capturing screenshot.</source>
     <name>MainWindow</name>
     <message>
         <source>Unsaved</source>
-        <translation type="unfinished"></translation>
+        <translation>නොසුරැකි</translation>
     </message>
     <message>
         <source>Upload</source>
@@ -864,7 +900,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>&amp;About</source>
-        <translation>පිළිබඳව</translation>
+        <translation>&amp;පිළිබඳව</translation>
     </message>
     <message>
         <source>Open</source>
@@ -872,19 +908,15 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>&amp;Edit</source>
-        <translation>සංස්කරණය</translation>
+        <translation>&amp;සංස්කරණය</translation>
     </message>
     <message>
         <source>&amp;Options</source>
-        <translation>විකල්ප</translation>
+        <translation>&amp;විකල්ප</translation>
     </message>
     <message>
         <source>&amp;Help</source>
-        <translation>උපකාර</translation>
-    </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;උපකාර</translation>
     </message>
     <message>
         <source>Add Watermark</source>
@@ -896,11 +928,11 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>&amp;File</source>
-        <translation>ගොනුව</translation>
+        <translation>&amp;ගොනුව</translation>
     </message>
     <message>
         <source>Unable to show image</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරුව පෙන්වීමට නොහැකියි</translation>
     </message>
     <message>
         <source>Save As...</source>
@@ -912,7 +944,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Paste Embedded</source>
-        <translation type="unfinished"></translation>
+        <translation>එබ්බවූ අලවන්න</translation>
     </message>
     <message>
         <source>Pin</source>
@@ -928,19 +960,19 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Copy Path</source>
-        <translation type="unfinished"></translation>
+        <translation>මාර්ගය පිටපත් කරන්න</translation>
     </message>
     <message>
         <source>Open Directory</source>
-        <translation type="unfinished"></translation>
+        <translation>නාමාවලිය විවෘත කරන්න</translation>
     </message>
     <message>
         <source>&amp;View</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;දැක්ම</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>මකන්න</translation>
     </message>
     <message>
         <source>Rename</source>
@@ -948,7 +980,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Open Images</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරූ විවෘත කරන්න</translation>
     </message>
     <message>
         <source>Show Docks</source>
@@ -964,7 +996,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Open &amp;Recent</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;මෑත දෑ විවෘත කරන්න</translation>
     </message>
     <message>
         <source>Modify Canvas</source>
@@ -984,11 +1016,19 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Rotate</source>
-        <translation type="unfinished"></translation>
+        <translation>කරකවන්න</translation>
     </message>
     <message>
         <source>Rotate Image</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරුව කරකවන්න</translation>
+    </message>
+    <message>
+        <source>Actions</source>
+        <translation>ක්‍රියාමාර්ග</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>අනුරූ ගොනු</translation>
     </message>
 </context>
 <context>
@@ -1003,7 +1043,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Open Directory</source>
-        <translation type="unfinished"></translation>
+        <translation>නාමාවලිය විවෘත කරන්න</translation>
     </message>
     <message>
         <source>Copy</source>
@@ -1015,7 +1055,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>මකන්න</translation>
     </message>
     <message>
         <source>Rename</source>
@@ -1057,26 +1097,26 @@ and capturing screenshot.</source>
         <source>Image Renamed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rename image</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරුව යළි නම් කරන්න</translation>
     </message>
     <message>
         <source>New filename:</source>
         <translation>නව ගොනුනාමය:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1084,28 +1124,28 @@ and capturing screenshot.</source>
         <source>Save As</source>
         <translation>ලෙස සුරකින්න</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>සියලුම ගොනු</translation>
     </message>
     <message>
         <source>Image Saved</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරුව සුරැකිණි</translation>
     </message>
     <message>
         <source>Saving Image Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>අනුරුව සුරැකීමට අසමත් විය</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation type="unfinished"></translation>
+        <source>Image Files</source>
+        <translation>අනුරූ ගොනු</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
+        <source>Saved to %1</source>
+        <translation>%1 වෙත සුරැකිණි</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1153,7 +1193,7 @@ Filename can contain following wildcards:
     </message>
     <message>
         <source>Default</source>
-        <translation type="unfinished"></translation>
+        <translation>පෙරනිමි</translation>
     </message>
     <message>
         <source>Factor</source>
@@ -1281,6 +1321,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation>ක්‍රියාමාර්ග</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1329,7 +1373,7 @@ When omitted, everything is copied.</source>
     </message>
     <message>
         <source>This message can be disabled via settings.</source>
-        <translation type="unfinished"></translation>
+        <translation>සැකසුම් හරහා මෙම පණිවිඩය අබල කළ හැකිය.</translation>
     </message>
 </context>
 <context>
@@ -1472,7 +1516,7 @@ Smaller number is more transparent.</source>
     <name>TrayIcon</name>
     <message>
         <source>Show Editor</source>
-        <translation type="unfinished"></translation>
+        <translation>සංස්කරකය පෙන්වන්න</translation>
     </message>
 </context>
 <context>
@@ -1500,7 +1544,7 @@ Change requires restart.</source>
     </message>
     <message>
         <source>Show Editor</source>
-        <translation type="unfinished"></translation>
+        <translation>සංස්කරකය පෙන්වන්න</translation>
     </message>
     <message>
         <source>Capture</source>
@@ -1518,10 +1562,6 @@ Change requires restart.</source>
         <source>Tray Icon Settings</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation type="unfinished"></translation>
@@ -1531,6 +1571,10 @@ Change requires restart.</source>
 service when such exists. Change requires restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1539,13 +1583,9 @@ service when such exists. Change requires restart to take effect.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Images</source>
+        <source>Image Files</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>All Files</source>
-        <translation>සියලුම ගොනු</translation>
-    </message>
 </context>
 <context>
     <name>UploadOperation</name>
@@ -1588,6 +1628,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
