@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -272,6 +273,28 @@ Dockors synlighet kan växlas med Tab-tangenten.</translation>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Ändra automatiskt storleken på huvudfönstret för att passa bilden.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Aktivera felsökning</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Aktiverar felsökningsutdata i konsolen.
+ksnip måste startas om för att ändringen skall tillämpas.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Ändra storlek till innehållsfördröjning</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Storleksändring till innehåll är en fördröjning för att fönsterhanteraren skall kunna ta emot
+det nya innehållet. Om huvudfönstret inte är korrekt inställt
+till det nya innehållet, kan en ökning av denna fördröjning förbättra beteendet.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -366,29 +389,17 @@ Vill du spara det?</translation>
         <source>Community</source>
         <translation>Gemenskap</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Om du har allmänna frågor, idéer eller bara vill prata om ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>kan du gå med i vår </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> server.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Felrapporter</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Använd </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Om du har allmänna frågor, idéer eller bara vill prata om ksnip,&lt;br/&gt;kan du ansluta till vår %1- eller %2-server.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> för att rapportera fel.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Använd %1 för att rapportera fel.</translation>
     </message>
 </context>
 <context>
@@ -425,14 +436,6 @@ Vill du fortsätta?</translation>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>här</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Också möjligt, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Donationer är alltid välkomna</translation>
@@ -442,16 +445,20 @@ Vill du fortsätta?</translation>
         <translation>Donation</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Bli en GitHub-sponsor</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip är ett icke-vinstdrivande copyleft-projekt för fri programvara, och&lt;br/&gt;har fortfarande vissa kostnader som måste täckas,&lt;br/&gt;som domänkostnader eller hårdvarukostnader för plattformsoberoende stöd.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip är ett icke-lönsamt mjukvaruprojekt, som&lt;br/&gt;fortfarande har vissa kostnader som måste täckas,&lt;br/&gt;som domänkostnader eller hårdvarukostnader för flerplattformsberoende stöd.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Om du vill hjälpa till eller bara uppskatta det arbete som görs&lt;br/&gt;genom att bjuda utvecklarna på en öl eller en kopp kaffe kan du göra det %1här%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Om du vill hjälpa till eller bara&lt;br/&gt;uppskattar det arbete som görs&lt;br/&gt;genom att bjuda utvecklaren på en öl eller kaffe, kan du göra det</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Vill du bli en GitHub-sponsor?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Det är också möjligt, %1här%2.</translation>
     </message>
 </context>
 <context>
@@ -492,24 +499,35 @@ Vill du fortsätta?</translation>
         <translation>Skärmklippsportal</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Tvinga fram anonym uppladdning.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Användarnamn</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Lösenord</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP-uppladdare</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Uppladdning slutförd</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Ladda upp skript </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> har slutförts.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Uppladdat till</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Kan inte spara temporär bild för uppladdning.</translation>
@@ -538,10 +556,6 @@ Vill du fortsätta?</translation>
         <source>Web error, check console output.</source>
         <translation>Webbfel, kontrollera utdata i konsolen.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Okänt processfel.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Uppladdning misslyckades</translation>
@@ -550,6 +564,30 @@ Vill du fortsätta?</translation>
         <source>Script wrote to StdErr.</source>
         <translation>Skript skrev till StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>FTP-uppladdningen har slutförts.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Okänt fel.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Anslutningsfel.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Behörighetsfel.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>Uppladdningsskriptet %1 har slutförts.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Uppladdat till %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -616,14 +654,6 @@ skärmklipp.</translation>
         <source>Image Grabber</source>
         <translation>Områdesklipp</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Framtvinga inbyggt Wayland-skärmklipp</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Skala inbyggt Wayland-skärmklipp</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -666,6 +696,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Visa huvudfönstret efter att ha tagit ett nytt skärmklipp,
 när huvudfönstret var dolt eller minimerat.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Tvinga generisk Wayland (xdg-desktop-portal) Skärmdump</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Skala Generic Wayland (xdg-desktop-portal) Skärmdumpar</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -811,6 +849,7 @@ och själva skärmklippet.</translation>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -908,10 +947,6 @@ och själva skärmklippet.</translation>
         <source>&amp;Help</source>
         <translation>&amp;Hjälp</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Bildfiler (*.png *.jpg *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Lägg till vattenstämpel</translation>
@@ -1016,6 +1051,14 @@ och själva skärmklippet.</translation>
         <source>Rotate Image</source>
         <translation>Rotera bild</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Åtgärder</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>Bildfiler</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1083,18 +1126,10 @@ och själva skärmklippet.</translation>
         <source>Image Renamed</source>
         <translation>Bilden har bytt namn</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Bilden har bytt namn till </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Kunde inte byta namn</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Kunde inte byta namn till </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Byt namn på bilden</translation>
@@ -1103,6 +1138,14 @@ och själva skärmklippet.</translation>
         <source>New filename:</source>
         <translation>Nytt filnamn:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Bildnamnet har ändrats till %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Kunde inte att byta namn på bilden till %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1110,10 +1153,6 @@ och själva skärmklippet.</translation>
         <source>Save As</source>
         <translation>Spara som</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>Bilder</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>Alla filer</translation>
@@ -1127,12 +1166,16 @@ och själva skärmklippet.</translation>
         <translation>Kunde inte spara bilden</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Sparad i</translation>
+        <source>Image Files</source>
+        <translation>Bildfiler</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Kunde inte spara bilden i</translation>
+        <source>Saved to %1</source>
+        <translation>Sparat till %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Kunde inte att spara bilden till %1</translation>
     </message>
 </context>
 <context>
@@ -1315,6 +1358,10 @@ När detta utelämnas kopieras allt.</translation>
         <source>Actions</source>
         <translation>Åtgärder</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP-uppladdare</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1571,10 +1618,6 @@ Change requires restart.</source>
         <source>Tray Icon Settings</source>
         <translation>Inställningar för systemfältsikon</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Visa systemfältsaviseringar</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Använd plattformsspecifik aviseringstjänst</translation>
@@ -1585,6 +1628,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Vid aktivering försöker ksnip använda plattformsspecifik avisering
 när sådan finnes. Ändring kräver omstart för att tillämpas.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Visa systemfältsaviseringar</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1593,12 +1640,8 @@ när sådan finnes. Ändring kräver omstart för att tillämpas.</translation>
         <translation>Välj bild</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>Bilder</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>Alla filer</translation>
+        <source>Image Files</source>
+        <translation>Bildfiler</translation>
     </message>
 </context>
 <context>
@@ -1642,6 +1685,10 @@ när sådan finnes. Ändring kräver omstart för att tillämpas.</translation>
         <source>Uploader</source>
         <translation>Uppladdare</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
