@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>с</translation>
     </message>
     <message>
@@ -274,6 +275,28 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>Автоматично змінювати розміри головного вікна за зображенням-вмістом.</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>Увімкнути діагностику</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>Вмикає діагностичне виведення до консолі.
+Для набуття змінами чинності слід перезапустити ksnip.</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>Затримка зміни розмірів до вмісту</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>Зміна розмірів за вмістом затримується з метою уможливлення для засобу
+керування вікнами отримання нового вмісту. Якщо головне вікно не
+коригується за новим вмістом, збільшення затримки може поліпшити ситуацію.</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -368,29 +391,17 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation>Спільнота</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>Якщо у вас є питання загального характеру, ідеї або ви просто хочете обговорити ksnip,</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>будь ласка, долучайтеся до нашого </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> сервера.</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>Звіти щодо вад</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>Будь ласка, скористайтеся </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>Якщо у вас виникли питання загального характеру, ідеї, або ви просто хочете поговорити про ksnip,&lt;br/&gt;будь ласка, долучайтеся до нашого каналу %1 або нашого сервера %2.</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> для надсилання сповіщень щодо вад.</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>Будь ласка, скористайтеся сторінкою %1 для звітування щодо вад.</translation>
     </message>
 </context>
 <context>
@@ -427,14 +438,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>тут</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>Також можливо, </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>Пожертви завжди вітаються</translation>
@@ -444,16 +447,20 @@ Do you want to continue?</source>
         <translation>Пожертва</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>Стати спонсором на GitHub</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip є неприбутковим вільним відкритим проєктом із розробки програмного забезпечення, але&lt;br/&gt;має певні супутні витрати,&lt;br/&gt;зокрема, має платити за домен та обладнання для підтримки роботи на багатьох апаратних платформах.</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip — проєкт зі створення неприбуткового програмного забезпечення із вільними умовами ліцензування та умовами безкоштовного поширення.&lt;br/&gt;Втім, це не означає, що він не коштує нічого.&lt;br/&gt;Нам доводиться сплачувати за домен та обладнання для підтримання роботи програми на багатьох платформах.</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>Якщо ви хочете допомогти або просто вважаєте за потрібне віддячити за виконану роботу,&lt;br/&gt;надавши розробникам можливість випити пива або кави, ви можете підтримати проєкт %1тут%2.</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>Якщо ви хочете допомогти або просто&lt;br/&gt;віддячити за виконану роботу&lt;br/&gt;келихом пива або чашкою кави для розробників, ви можете це зробити</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>Станете спонсором GitHub?</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>Також можна підтримати %1тут%2.</translation>
     </message>
 </context>
 <context>
@@ -494,24 +501,35 @@ Do you want to continue?</source>
         <translation>Портал знімків вікон</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>Примусове анонімне вивантаження.</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Адреса</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Користувач</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Пароль</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Вивантажувач FTP</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>Успішне вивантаження</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>Скрипт вивантаження </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> успішно завершено.</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>Вивантажено до</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>Не вдалося зберегти тимчасове зображення для вивантаження.</translation>
@@ -540,10 +558,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation>Помилка із мережею, ознайомтеся із виведеними до консолі даними.</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>Невідома помилка обробки.</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>Невдала спроба вивантаження</translation>
@@ -552,6 +566,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation>Скрипт записано до StdErr.</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>Вивантаження на FTP успішно завершено.</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>Невідома помилка.</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>Помилка з&apos;єднання.</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>Помилка із правами доступу.</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>Скрипт вивантаження %1 завершив роботу успішно.</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>Вивантажено до %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -618,14 +656,6 @@ screenshots.</source>
         <source>Image Grabber</source>
         <translation>Захоплення знімків</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>Примусове створення типового знімка Wayland</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>Масштабувати типові знімки у Wayland</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -668,6 +698,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>Показати головне вікно після створення знімка,
 якщо головне вікно було приховано або згорнуто.</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>Примусово типовий знімок вікна Wayland (xdg-desktop-portal)</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>Масштабовані загальні знімки вікон Wayland (xdg-desktop-portal)</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -813,6 +851,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>с</translation>
     </message>
     <message>
@@ -910,10 +949,6 @@ and capturing screenshot.</source>
         <source>&amp;Help</source>
         <translation>&amp;Довідка</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>Файли зображень (*.png, *.jpg, *.bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>Додати водяний знак</translation>
@@ -1018,6 +1053,14 @@ and capturing screenshot.</source>
         <source>Rotate Image</source>
         <translation>Обертати зображення</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>Дії</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>файли зображень</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1085,18 +1128,10 @@ and capturing screenshot.</source>
         <source>Image Renamed</source>
         <translation>Зображення перейменовано</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>Зображення успішно перейменовано на </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>Не вдалося перейменувати зображення</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>Не вдалося перейменувати зображення на </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>Перейменувати зображення</translation>
@@ -1105,6 +1140,14 @@ and capturing screenshot.</source>
         <source>New filename:</source>
         <translation>Нова назва файла:</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>Зображення успішно перейменовано на %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>Не вдалося перейменувати зображення на %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1112,10 +1155,6 @@ and capturing screenshot.</source>
         <source>Save As</source>
         <translation>Зберегти як</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>зображення</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>усі файли</translation>
@@ -1129,12 +1168,16 @@ and capturing screenshot.</source>
         <translation>Не вдалося зберегти зображення</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>Зберегти до</translation>
+        <source>Image Files</source>
+        <translation>файли зображень</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>Не вдалося зберегти зображення до</translation>
+        <source>Saved to %1</source>
+        <translation>Збережено до %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>Не вдалося зберегти зображення до %1</translation>
     </message>
 </context>
 <context>
@@ -1317,6 +1360,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation>Дії</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>Вивантажувач FTP</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1574,10 +1621,6 @@ Change requires restart.</source>
         <source>Tray Icon Settings</source>
         <translation>Параметри піктограми лотка</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>Показувати сповіщення піктограми лотка</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>Скористатися специфічною для платформи службою сповіщень</translation>
@@ -1588,6 +1631,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Якщо увімкнено, програма спробує скористатися специфічною для платформи
 службою сповіщень, якщо така існує. Для набуття чинності змінами програму слід буде перезапустити.</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>Сповіщення з піктограми у лотку</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1596,12 +1643,8 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>Вибрати зображення</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>зображення</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>усі файли</translation>
+        <source>Image Files</source>
+        <translation>файли зображень</translation>
     </message>
 </context>
 <context>
@@ -1645,6 +1688,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation>Вивантажувач</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
