@@ -71,6 +71,7 @@
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>s</translation>
     </message>
     <message>
@@ -273,6 +274,28 @@ Docks visibility can be toggled with the Tab Key.</source>
         <source>Automatically resize Main Window to fit content image.</source>
         <translation>自动调整主窗口的大小以适合内容图像。</translation>
     </message>
+    <message>
+        <source>Enable Debugging</source>
+        <translation>启用调试</translation>
+    </message>
+    <message>
+        <source>Enables debug output written to the console.
+Change requires ksnip restart to take effect.</source>
+        <translation>启用写入控制台的调试输出。
+更改需要 ksnip 重新启动才能生效。</translation>
+    </message>
+    <message>
+        <source>Resize to content delay</source>
+        <translation>调整窗口大小适应内容的延迟</translation>
+    </message>
+    <message>
+        <source>Resizing to content is delay to allow the Window Manager to receive
+the new content. In case that the Main Windows is not adjusted correctly
+to the new content, increasing this delay might improve the behavior.</source>
+        <translation>根据内容大小是允许窗口管理器接收新内容的延迟。
+如果未正确调整主窗口以适应新内容，
+增加延迟可能会改善行为。</translation>
+    </message>
 </context>
 <context>
     <name>AuthorTab</name>
@@ -367,29 +390,17 @@ Do you want to save it?</source>
         <source>Community</source>
         <translation>社区</translation>
     </message>
-    <message>
-        <source>If you have general questions, ideas or just want to talk about ksnip,</source>
-        <translation>如果您有一般性问题，想法或只想谈谈 ksnip，</translation>
-    </message>
-    <message>
-        <source>please join our </source>
-        <translation>请加入我们 </translation>
-    </message>
-    <message>
-        <source> server.</source>
-        <translation> 服务。</translation>
-    </message>
     <message>
         <source>Bug Reports</source>
         <translation>错误报告</translation>
     </message>
     <message>
-        <source>Please use </source>
-        <translation>请使用 </translation>
+        <source>If you have general questions, ideas or just want to talk about ksnip,&lt;br/&gt;please join our %1 or our %2 server.</source>
+        <translation>如果您有常规问题、想法或只想谈谈 ksnip，&lt;br/&gt;请加入我们的 %1 或我们的 %2 服务器。</translation>
     </message>
     <message>
-        <source> to report bugs.</source>
-        <translation> 报告错误。</translation>
+        <source>Please use %1 to report bugs.</source>
+        <translation>请使用 %1 报告故障。</translation>
     </message>
 </context>
 <context>
@@ -426,14 +437,6 @@ Do you want to continue?</source>
 </context>
 <context>
     <name>DonateTab</name>
-    <message>
-        <source>here</source>
-        <translation>这里</translation>
-    </message>
-    <message>
-        <source>Also possible, </source>
-        <translation>也可以 </translation>
-    </message>
     <message>
         <source>Donations are always welcome</source>
         <translation>欢迎捐款</translation>
@@ -443,16 +446,20 @@ Do you want to continue?</source>
         <translation>捐赠</translation>
     </message>
     <message>
-        <source>Become a GitHub Sponsor</source>
-        <translation>成为一名 GitHub 赞助者</translation>
+        <source>ksnip is a non-profitable copyleft libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
+        <translation>ksnip 是一个非盈利的 Copyleft 自由软件项目，并且&lt;br/&gt;仍有一些费用需要支付，&lt;br/&gt;如域名成本或跨平台支持的硬件成本。</translation>
     </message>
     <message>
-        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
-        <translation>ksnip 是一个非盈利的公共版权自由软件项目，&lt;br/&gt; 仍有一些成本需要支付，&lt;br/&gt; 比如域名成本和跨平台支持所需的硬件成本。</translation>
+        <source>If you want to help or just want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that %1here%2.</source>
+        <translation>&lt;br/&gt;如果你想通过请开发者喝啤酒或咖啡提供帮助或只是想赞赏所做的工作，欢迎看看%1这里%2。</translation>
     </message>
     <message>
-        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
-        <translation>如果您想请开发人员喝杯啤酒或咖啡或只是想&lt;br/&gt;欣赏正在完成的工作&lt;br/&gt;，则可以这样做</translation>
+        <source>Become a GitHub Sponsor?</source>
+        <translation>成为 GitHub 赞助者？</translation>
+    </message>
+    <message>
+        <source>Also possible, %1here%2.</source>
+        <translation>也可以在 %1此处%2 捐款。</translation>
     </message>
 </context>
 <context>
@@ -493,24 +500,35 @@ Do you want to continue?</source>
         <translation>截图门户</translation>
     </message>
 </context>
+<context>
+    <name>FtpUploaderSettings</name>
+    <message>
+        <source>Force anonymous upload.</source>
+        <translation>强制匿名上传。</translation>
+    </message>
+    <message>
+        <source>Url</source>
+        <translation>Url</translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>用户名</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>密码</translation>
+    </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP 上传器</translation>
+    </message>
+</context>
 <context>
     <name>HandleUploadResultOperation</name>
     <message>
         <source>Upload Successful</source>
         <translation>上传成功</translation>
     </message>
-    <message>
-        <source>Upload script </source>
-        <translation>上传脚本 </translation>
-    </message>
-    <message>
-        <source> finished successfully.</source>
-        <translation> 已成功完成。</translation>
-    </message>
-    <message>
-        <source>Uploaded to</source>
-        <translation>上传到</translation>
-    </message>
     <message>
         <source>Unable to save temporary image for upload.</source>
         <translation>无法为上传保存临时图像。</translation>
@@ -539,10 +557,6 @@ Do you want to continue?</source>
         <source>Web error, check console output.</source>
         <translation>网络错误，请检查控制台输出。</translation>
     </message>
-    <message>
-        <source>Unknown process error.</source>
-        <translation>未知的处理错误。</translation>
-    </message>
     <message>
         <source>Upload Failed</source>
         <translation>上传失败</translation>
@@ -551,6 +565,30 @@ Do you want to continue?</source>
         <source>Script wrote to StdErr.</source>
         <translation>脚本在标准错误上有输出。</translation>
     </message>
+    <message>
+        <source>FTP Upload finished successfully.</source>
+        <translation>FTP 上传成功完成。</translation>
+    </message>
+    <message>
+        <source>Unknown error.</source>
+        <translation>未知错误。</translation>
+    </message>
+    <message>
+        <source>Connection Error.</source>
+        <translation>连接错误。</translation>
+    </message>
+    <message>
+        <source>Permission Error.</source>
+        <translation>权限错误。</translation>
+    </message>
+    <message>
+        <source>Upload script %1  finished successfully.</source>
+        <translation>脚本 %1 上传成功。</translation>
+    </message>
+    <message>
+        <source>Uploaded to %1</source>
+        <translation>已上传至 %1</translation>
+    </message>
 </context>
 <context>
     <name>HotKeySettings</name>
@@ -617,14 +655,6 @@ screenshots.</source>
         <source>Image Grabber</source>
         <translation>图像采集器</translation>
     </message>
-    <message>
-        <source>Force Generic Wayland Screenshot</source>
-        <translation>强制通用 Wayland 截图</translation>
-    </message>
-    <message>
-        <source>Scale Generic Wayland Screenshots</source>
-        <translation>缩放通用 Wayland 截图</translation>
-    </message>
     <message>
         <source>Generic Wayland implementations that use
 XDG-DESKTOP-PORTAL handle screen scaling
@@ -667,6 +697,14 @@ when the Main Window was hidden or minimize.</source>
         <translation>隐藏或最小化主窗口时在捕获新的
 屏幕快照后显示主窗口。</translation>
     </message>
+    <message>
+        <source>Force Generic Wayland (xdg-desktop-portal) Screenshot</source>
+        <translation>强制 Generic Wayland (xdg-desktop-portal) 截图</translation>
+    </message>
+    <message>
+        <source>Scale Generic Wayland (xdg-desktop-portal) Screenshots</source>
+        <translation>缩放 Generic Wayland (xdg-desktop-portal) 截图</translation>
+    </message>
 </context>
 <context>
     <name>ImgurHistoryDialog</name>
@@ -722,7 +760,7 @@ when the Main Window was hidden or minimize.</source>
     </message>
     <message>
         <source>Client Secret</source>
-        <translation>Client Secret</translation>
+        <translation>客户端 Secret</translation>
     </message>
     <message>
         <source>PIN</source>
@@ -812,6 +850,7 @@ and capturing screenshot.</source>
     </message>
     <message>
         <source>s</source>
+        <extracomment>The small letter s stands for seconds.</extracomment>
         <translation>秒</translation>
     </message>
     <message>
@@ -909,10 +948,6 @@ and capturing screenshot.</source>
         <source>&amp;Help</source>
         <translation>帮助(&amp;H)</translation>
     </message>
-    <message>
-        <source>Image Files (*.png *.jpg *.bmp)</source>
-        <translation>图像文件 (* .png * .jpg * .bmp)</translation>
-    </message>
     <message>
         <source>Add Watermark</source>
         <translation>添加水印</translation>
@@ -1017,6 +1052,14 @@ and capturing screenshot.</source>
         <source>Rotate Image</source>
         <translation>旋转图像</translation>
     </message>
+    <message>
+        <source>Actions</source>
+        <translation>操作</translation>
+    </message>
+    <message>
+        <source>Image Files</source>
+        <translation>图像文件</translation>
+    </message>
 </context>
 <context>
     <name>MultiCaptureHandler</name>
@@ -1084,18 +1127,10 @@ and capturing screenshot.</source>
         <source>Image Renamed</source>
         <translation>图像已重命名</translation>
     </message>
-    <message>
-        <source>Successfully renamed image to </source>
-        <translation>成功重命名图像为 </translation>
-    </message>
     <message>
         <source>Image Rename Failed</source>
         <translation>图像重命名失败</translation>
     </message>
-    <message>
-        <source>Failed to rename image to </source>
-        <translation>无法将图像重命名为 </translation>
-    </message>
     <message>
         <source>Rename image</source>
         <translation>重命名图像</translation>
@@ -1104,6 +1139,14 @@ and capturing screenshot.</source>
         <source>New filename:</source>
         <translation>新文件名：</translation>
     </message>
+    <message>
+        <source>Successfully renamed image to %1</source>
+        <translation>成功将图片重命名为 %1</translation>
+    </message>
+    <message>
+        <source>Failed to rename image to %1</source>
+        <translation>未能将图片重命名为 %1</translation>
+    </message>
 </context>
 <context>
     <name>SaveOperation</name>
@@ -1111,10 +1154,6 @@ and capturing screenshot.</source>
         <source>Save As</source>
         <translation>另存为</translation>
     </message>
-    <message>
-        <source>Images</source>
-        <translation>图像</translation>
-    </message>
     <message>
         <source>All Files</source>
         <translation>所有文件</translation>
@@ -1128,12 +1167,16 @@ and capturing screenshot.</source>
         <translation>保存图像失败</translation>
     </message>
     <message>
-        <source>Saved to</source>
-        <translation>保存到</translation>
+        <source>Image Files</source>
+        <translation>图像文件</translation>
     </message>
     <message>
-        <source>Failed to save image to</source>
-        <translation>无法将图像保存到</translation>
+        <source>Saved to %1</source>
+        <translation>已保存至 %1</translation>
+    </message>
+    <message>
+        <source>Failed to save image to %1</source>
+        <translation>未能将图片保存至 %1</translation>
     </message>
 </context>
 <context>
@@ -1316,6 +1359,10 @@ When omitted, everything is copied.</source>
         <source>Actions</source>
         <translation>操作</translation>
     </message>
+    <message>
+        <source>FTP Uploader</source>
+        <translation>FTP 上传器</translation>
+    </message>
 </context>
 <context>
     <name>SnippingAreaResizerInfoText</name>
@@ -1572,10 +1619,6 @@ Change requires restart.</source>
         <source>Tray Icon Settings</source>
         <translation>托盘图标设置</translation>
     </message>
-    <message>
-        <source>Display Tray icon notifications</source>
-        <translation>显示任务栏图标通知</translation>
-    </message>
     <message>
         <source>Use platform specific notification service</source>
         <translation>使用平台特定的通知服务</translation>
@@ -1586,6 +1629,10 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>启用后将使用尝试使用特定于平台的通知存在时提供服务。
  更改需要重新启动才能生效。</translation>
     </message>
+    <message>
+        <source>Display Tray Icon notifications</source>
+        <translation>显示托盘图标通知</translation>
+    </message>
 </context>
 <context>
     <name>UpdateWatermarkOperation</name>
@@ -1594,12 +1641,8 @@ service when such exists. Change requires restart to take effect.</source>
         <translation>选择图像</translation>
     </message>
     <message>
-        <source>Images</source>
-        <translation>图像</translation>
-    </message>
-    <message>
-        <source>All Files</source>
-        <translation>所有文件</translation>
+        <source>Image Files</source>
+        <translation>图片文件</translation>
     </message>
 </context>
 <context>
@@ -1643,6 +1686,10 @@ service when such exists. Change requires restart to take effect.</source>
         <source>Uploader</source>
         <translation>上传程序</translation>
     </message>
+    <message>
+        <source>FTP</source>
+        <translation>FTP</translation>
+    </message>
 </context>
 <context>
     <name>VersionTab</name>
